{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# NetworkX Visualization Powered by Bokeh\n",
    "\n",
    "<br>\n",
    "### EuroPython 2016 (2016-07-22)\n",
    "\n",
    "###### Björn Meier"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "### Original Objectives:\n",
    "* exploring networks for patterns based on properties like node centrality or clustering\n",
    "* visualization in a browser\n",
    "\n",
    "<br>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "### Original Solution:\n",
    "* generate networks and properties\n",
    "* RESTful Flask app to provide data\n",
    "* D3.js app for browser visualization"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "## Can we solve this easier?"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "### NetworkX + Bokeh\n",
    "\n",
    "* define the visualization in pure python\n",
    "* interact with your network\n",
    "    * change views or change showed properties\n",
    "    * manipulate the network and get an updated plot\n",
    "* possible embedding in a web app"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "#### Now, I will show you how it is done ..."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## Step 0: Example Data"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "<img src=europython-2016-logo-white-bg.png width=400 />"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "<img src=twitter.png width=200 />"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "* tweets during Europython 2016 @europython\n",
    "* author will be linked with users mentioned in a tweet"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## Step 1: Create a Network"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "collapsed": false,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [],
   "source": [
    "import networkx\n",
    "from math import sqrt\n",
    "network = networkx.read_gml('ep2016.gml')\n",
    "\n",
    "layout = networkx.spring_layout(network,\n",
    "                                k=1.1/sqrt(network.number_of_nodes()),\n",
    "                                iterations=100)\n",
    "# https://en.wikipedia.org/wiki/Force-directed_graph_drawing"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "collapsed": false,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "![elastic network](images/elastic_network.png)\n",
    "\n",
    "<sub>Image: https://en.wikipedia.org/wiki/Spring_system</sub>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "notes"
    }
   },
   "source": [
    "* Only nice took look at\n",
    "* Flattened into 2D\n",
    "* Not accurate"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## The Cornerstone is the ColumnDataSource\n",
    "\n",
    "| (id)  | x   | y   | node_name | ... |\n",
    "|:-----:|:---:|:---:|:---------:|:---:|\n",
    "| 0     | 21  | 3   | da_bjoerni| ... |\n",
    "| 1     | 14  | 7   | user47    | ... |\n",
    "| ...   | ... | ... | ...       | ... |\n",
    "\n",
    "* column based data class\n",
    "* columns must be sequences of data e.g. lists, pandas.DataFrame, ...\n",
    "* changes will effect the plot during a rerendering\n",
    "* selection information inside a plot"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "collapsed": false,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [],
   "source": [
    "from bokeh.models import ColumnDataSource\n",
    "\n",
    "nodes, nodes_coordinates = zip(*sorted(layout.items()))\n",
    "nodes_xs, nodes_ys = list(zip(*nodes_coordinates))\n",
    "nodes_source = ColumnDataSource(dict(x=nodes_xs, y=nodes_ys,\n",
    "                                     name=nodes))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## Step 2: Plot a Network"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "collapsed": false,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "outputs": [],
   "source": [
    "from bokeh.plotting import show, figure\n",
    "from bokeh.io import output_notebook\n",
    "from bokeh.models import HoverTool\n",
    "\n",
    "hover = HoverTool(tooltips=[('name', '@name'), ('id', '$index')])\n",
    "plot = figure(plot_width=800, plot_height=400,\n",
    "              tools=['tap', hover, 'box_zoom', 'reset'])\n",
    "r_circles = plot.circle('x', 'y', source=nodes_source, size=10,\n",
    "                        color='blue', level = 'overlay')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "collapsed": false,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "    <div class=\"bk-root\">\n",
       "        <a href=\"http://bokeh.pydata.org\" target=\"_blank\" class=\"bk-logo bk-logo-small bk-logo-notebook\"></a>\n",
       "        <span id=\"3f2d9f7a-0925-454a-b3c6-4d041d899020\">Loading BokehJS ...</span>\n",
       "    </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "\n",
       "(function(global) {\n",
       "  function now() {\n",
       "    return new Date();\n",
       "  }\n",
       "\n",
       "  if (typeof (window._bokeh_onload_callbacks) === \"undefined\") {\n",
       "    window._bokeh_onload_callbacks = [];\n",
       "  }\n",
       "\n",
       "  function run_callbacks() {\n",
       "    window._bokeh_onload_callbacks.forEach(function(callback) { callback() });\n",
       "    delete window._bokeh_onload_callbacks\n",
       "    console.info(\"Bokeh: all callbacks have finished\");\n",
       "  }\n",
       "\n",
       "  function load_libs(js_urls, callback) {\n",
       "    window._bokeh_onload_callbacks.push(callback);\n",
       "    if (window._bokeh_is_loading > 0) {\n",
       "      console.log(\"Bokeh: BokehJS is being loaded, scheduling callback at\", now());\n",
       "      return null;\n",
       "    }\n",
       "    if (js_urls == null || js_urls.length === 0) {\n",
       "      run_callbacks();\n",
       "      return null;\n",
       "    }\n",
       "    console.log(\"Bokeh: BokehJS not loaded, scheduling load and callback at\", now());\n",
       "    window._bokeh_is_loading = js_urls.length;\n",
       "    for (var i = 0; i < js_urls.length; i++) {\n",
       "      var url = js_urls[i];\n",
       "      var s = document.createElement('script');\n",
       "      s.src = url;\n",
       "      s.async = false;\n",
       "      s.onreadystatechange = s.onload = function() {\n",
       "        window._bokeh_is_loading--;\n",
       "        if (window._bokeh_is_loading === 0) {\n",
       "          console.log(\"Bokeh: all BokehJS libraries loaded\");\n",
       "          run_callbacks()\n",
       "        }\n",
       "      };\n",
       "      s.onerror = function() {\n",
       "        console.warn(\"failed to load library \" + url);\n",
       "      };\n",
       "      console.log(\"Bokeh: injecting script tag for BokehJS library: \", url);\n",
       "      document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "    }\n",
       "  };\n",
       "\n",
       "  var js_urls = ['https://cdn.pydata.org/bokeh/release/bokeh-0.12.0.min.js', 'https://cdn.pydata.org/bokeh/release/bokeh-widgets-0.12.0.min.js', 'https://cdn.pydata.org/bokeh/release/bokeh-compiler-0.12.0.min.js'];\n",
       "\n",
       "  var inline_js = [\n",
       "    function(Bokeh) {\n",
       "      Bokeh.set_log_level(\"info\");\n",
       "    },\n",
       "    \n",
       "    function(Bokeh) {\n",
       "      Bokeh.$(\"#3f2d9f7a-0925-454a-b3c6-4d041d899020\").text(\"BokehJS successfully loaded\");\n",
       "    },\n",
       "    function(Bokeh) {\n",
       "      console.log(\"Bokeh: injecting CSS: https://cdn.pydata.org/bokeh/release/bokeh-0.12.0.min.css\");\n",
       "      Bokeh.embed.inject_css(\"https://cdn.pydata.org/bokeh/release/bokeh-0.12.0.min.css\");\n",
       "      console.log(\"Bokeh: injecting CSS: https://cdn.pydata.org/bokeh/release/bokeh-widgets-0.12.0.min.css\");\n",
       "      Bokeh.embed.inject_css(\"https://cdn.pydata.org/bokeh/release/bokeh-widgets-0.12.0.min.css\");\n",
       "    }\n",
       "  ];\n",
       "\n",
       "  function run_inline_js() {\n",
       "    for (var i = 0; i < inline_js.length; i++) {\n",
       "      inline_js[i](window.Bokeh);\n",
       "    }\n",
       "  }\n",
       "\n",
       "  if (window._bokeh_is_loading === 0) {\n",
       "    console.log(\"Bokeh: BokehJS loaded, going straight to plotting\");\n",
       "    run_inline_js();\n",
       "  } else {\n",
       "    load_libs(js_urls, function() {\n",
       "      console.log(\"Bokeh: BokehJS plotting callback run at\", now());\n",
       "      run_inline_js();\n",
       "    });\n",
       "  }\n",
       "}(this));"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "\n",
       "\n",
       "    <div class=\"bk-root\">\n",
       "        <div class=\"plotdiv\" id=\"01e3770c-7cdf-422a-8887-a8335a2dc260\"></div>\n",
       "    </div>\n",
       "<script type=\"text/javascript\">\n",
       "  \n",
       "  (function(global) {\n",
       "    function now() {\n",
       "      return new Date();\n",
       "    }\n",
       "  \n",
       "    if (typeof (window._bokeh_onload_callbacks) === \"undefined\") {\n",
       "      window._bokeh_onload_callbacks = [];\n",
       "    }\n",
       "  \n",
       "    function run_callbacks() {\n",
       "      window._bokeh_onload_callbacks.forEach(function(callback) { callback() });\n",
       "      delete window._bokeh_onload_callbacks\n",
       "      console.info(\"Bokeh: all callbacks have finished\");\n",
       "    }\n",
       "  \n",
       "    function load_libs(js_urls, callback) {\n",
       "      window._bokeh_onload_callbacks.push(callback);\n",
       "      if (window._bokeh_is_loading > 0) {\n",
       "        console.log(\"Bokeh: BokehJS is being loaded, scheduling callback at\", now());\n",
       "        return null;\n",
       "      }\n",
       "      if (js_urls == null || js_urls.length === 0) {\n",
       "        run_callbacks();\n",
       "        return null;\n",
       "      }\n",
       "      console.log(\"Bokeh: BokehJS not loaded, scheduling load and callback at\", now());\n",
       "      window._bokeh_is_loading = js_urls.length;\n",
       "      for (var i = 0; i < js_urls.length; i++) {\n",
       "        var url = js_urls[i];\n",
       "        var s = document.createElement('script');\n",
       "        s.src = url;\n",
       "        s.async = false;\n",
       "        s.onreadystatechange = s.onload = function() {\n",
       "          window._bokeh_is_loading--;\n",
       "          if (window._bokeh_is_loading === 0) {\n",
       "            console.log(\"Bokeh: all BokehJS libraries loaded\");\n",
       "            run_callbacks()\n",
       "          }\n",
       "        };\n",
       "        s.onerror = function() {\n",
       "          console.warn(\"failed to load library \" + url);\n",
       "        };\n",
       "        console.log(\"Bokeh: injecting script tag for BokehJS library: \", url);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      }\n",
       "    };var element = document.getElementById(\"01e3770c-7cdf-422a-8887-a8335a2dc260\");\n",
       "    if (element == null) {\n",
       "      console.log(\"Bokeh: ERROR: autoload.js configured with elementid '01e3770c-7cdf-422a-8887-a8335a2dc260' but no matching script tag was found. \")\n",
       "      return false;\n",
       "    }\n",
       "  \n",
       "    var js_urls = [];\n",
       "  \n",
       "    var inline_js = [\n",
       "      function(Bokeh) {\n",
       "        Bokeh.$(function() {\n",
       "            var docs_json = {\"b865474b-1be9-401e-b030-7ecba4a5be4b\":{\"roots\":{\"references\":[{\"attributes\":{\"callback\":null,\"column_names\":[\"name\",\"x\",\"y\"],\"data\":{\"name\":[\"100Commits\",\"1337bullets\",\"1st1\",\"AartGoossens\",\"AbletonDev\",\"AdaTheShow\",\"AergNuor\",\"AishaXBello\",\"Angel_Cruijff\",\"Angelinux3000\",\"ApacheAirflow\",\"BBC\",\"BBCmicrobit\",\"BYAnalytics_en\",\"BayesianHorse\",\"BetabeersVG\",\"BlueYonderTech\",\"BokehPlots\",\"BorsLTD\",\"CAChemEorg\",\"CIBBVA\",\"Cambolc\",\"Charles_JUDITH\",\"CodingGrace\",\"ContinuumIO\",\"CriteoEng\",\"DRMacIver\",\"DaniBot_\",\"DanielDomeneL\",\"DaryaChyzhyk\",\"DasIstHerrKuska\",\"DavidjMarkey\",\"DeborahTaos12\",\"DigitYasuhara\",\"DjangoGirlsDUB\",\"DjangoGirlsEP16\",\"DjangoGirlsEc\",\"EPfestival\",\"ElnexoMarit\",\"EnCuKou\",\"EnriquetaSo\",\"EntropyFarmer\",\"Eurocentrique\",\"EventGeekie\",\"FAECTA_\",\"FernanMilla\",\"Foxinsock\",\"GMLudo\",\"Garrosa\",\"GinnyGhezzo\",\"GlaciarBlue\",\"Glenio_Oliveira\",\"GrandsCru\",\"GsBitBalear\",\"Gtzl\",\"HashtagLaToya\",\"HelloML9\",\"HokstadConsult\",\"HugoHerter\",\"IKERGUNE\",\"ITCrowdsource\",\"IcanadasM\",\"IldikoVancsa\",\"ImaneElAzlouk\",\"InspirefestHQ\",\"JOANNALETIZIA\",\"JancaStroma\",\"JasmineMcTigue\",\"Jaysinhp\",\"JohaPrime\",\"JoseOpposite\",\"JuliaDrBa\",\"KoehlerKerstin\",\"LIGO\",\"LaetitiaCarquet\",\"LatitudeFest\",\"Limejump\",\"Luen\",\"MBonell\",\"Macario8\",\"MakingLyst\",\"MarcoBasic\",\"MariaDehn\",\"MartaUhlirova\",\"MassHaste\",\"MaxBenChrist\",\"Miau_DB\",\"MiloslavPojman\",\"MirkoDziadzka\",\"MissPhilbin\",\"MongoDB\",\"MrsCaroline_C\",\"N4h_H4N\",\"NaomiCeder\",\"NegoBide\",\"NeuroSky\",\"NotANormalNerd\",\"NowLivecodingtv\",\"OReillyMedia\",\"OpenAtWE\",\"OpenStack\",\"PCalcao\",\"Patjouk\",\"Pazqo\",\"PiusNyongesa\",\"Polyconseiltech\",\"Ppuji1Ppuji\",\"PyCharm_edu\",\"PyConUK\",\"PyLadiesDub\",\"PythonEggs\",\"PythonIreland\",\"PythonSV\",\"RLerallut\",\"RTFMCelia\",\"RealPython\",\"RedHatNews\",\"Rhapsody_Girl\",\"Rico858\",\"SEReuskadi\",\"STajbakhsh\",\"SalamancaPeral\",\"SaltStack\",\"SaltStackInc\",\"SancasDev\",\"Sesivany\",\"Sophie_Talent\",\"Spanarchie\",\"SparkyCZ\",\"SrNilsson\",\"StefanTuralski\",\"StephLKim\",\"Sustatu\",\"TFConsult\",\"TeX4Publication\",\"ThePSF\",\"ThomasJWaldmann\",\"Transition\",\"Twitteze\",\"Ukerzel\",\"VictorStinner\",\"Vince92100\",\"ViniciusPach\",\"WickFelix\",\"WillingCarol\",\"WillyFrog_\",\"WuShell\",\"_JamesRG\",\"__amol__\",\"__katatonia\",\"__pamaron__\",\"_joac\",\"aRkadeFR\",\"a_soldatenko\",\"abelgvidal\",\"aborttrap6\",\"achimdomma\",\"acollard\",\"acpyss\",\"adambcn\",\"aitzol\",\"ajolo\",\"alabarga\",\"alba_caon\",\"alepernin\",\"alex_savio\",\"alison985\",\"almu_hs\",\"aloctavodia\",\"amleczko\",\"andrew_svetlov\",\"angineering\",\"angvp\",\"aniawsz\",\"aniiimaginary\",\"apueblago\",\"argenpython\",\"argonemyth\",\"asendecka\",\"asereteresa23\",\"astrojuanlu\",\"avillamarink\",\"b1n0anb\",\"b_smoke\",\"barakamediatv\",\"bayerdi\",\"bazkennedy\",\"bbc_microbit\",\"bbva\",\"ben_nuttall\",\"bilbaochess\",\"blckdt\",\"bmispelon\",\"bobcatwilson\",\"boiagames\",\"calvinhp\",\"carlosperate\",\"carohadad\",\"ccdesales\",\"cemnova\",\"ch_doig\",\"christianbarra\",\"clinker\",\"coala_analyzer\",\"cobe\",\"cobeio\",\"codekee\",\"codesyntax\",\"codingquark\",\"colmharrington\",\"connctBunker\",\"cool_python\",\"cris_calvo\",\"ctrebing\",\"d0ugal\",\"dArignac\",\"da_bjoerni\",\"dajoffe\",\"daniel7773121\",\"data_hope\",\"dbra\",\"deblike\",\"deshipu\",\"devbootcamp\",\"dfflanders\",\"diegor\",\"djangocon\",\"djangogirls\",\"docker\",\"doriczapari\",\"doughellmann\",\"douglasandrade\",\"drgarcia1986\",\"drridolfo\",\"drvinceknight\",\"dynamitts\",\"dzen\",\"eastigarraga\",\"echorand\",\"edu2b\",\"eitbAlbisteak\",\"eitbNoticias\",\"eladyonas\",\"eliasmoli\",\"eliasthorpet\",\"elmundoempresa\",\"emergya\",\"eolo999\",\"er1p\",\"erralin\",\"esletweets\",\"euro_ii\",\"europython\",\"euskalencounter\",\"evildmp\",\"exaeducation\",\"facebook\",\"facundobatista\",\"fbuontempo\",\"fedeteotini\",\"fergleiser\",\"fintxuarregi\",\"fishnets88\",\"fleioapp\",\"flubdevork\",\"flyingcircusio\",\"fmasanori\",\"freakboy3742\",\"free_control\",\"fuelex\",\"g16n\",\"gaceta_tec\",\"galindale\",\"gdsteam\",\"georgebernhard\",\"getGNU\",\"getbynder\",\"gherranzc\",\"giovannibajo\",\"globalmikem\",\"godlike64\",\"golangweekly\",\"google\",\"grupospri\",\"gwoptics\",\"hackebrot\",\"hanasulc\",\"hawkieowl\",\"helenst\",\"hendorf\",\"hpk42\",\"hundredrooms\",\"hydarscouser\",\"i4ssecurity\",\"iElectric\",\"iamtontann\",\"iferminm\",\"ifosch\",\"ikarantan\",\"iliebana\",\"imkaushalparikh\",\"indizen_corp\",\"int_lcd\",\"intel\",\"ioggstream\",\"iwangulenko\",\"j_zar21\",\"javier_arilos\",\"jbkamaraj\",\"jcoscia\",\"jdrumgoole\",\"jedux\",\"jesushdz_\",\"jimthree\",\"jirikuncar\",\"jjvie\",\"jmaurola\",\"jmkaluzka\",\"jmortegac\",\"josethegeek93\",\"kaleidomkt\",\"kantrn\",\"kanumankalwa\",\"kerma_dj\",\"kjam\",\"kkvie\",\"laceynwilliams\",\"ladybiss\",\"lehinevych\",\"leriomaggio\",\"lethal_guitar\",\"librecon\",\"linuxchixar\",\"loooorenanicole\",\"lucaotta\",\"lugensaDE\",\"luistxo\",\"lunkwill42\",\"lusantala\",\"m3ntaal\",\"m4rpl4t3ns3\",\"maidotgimenez\",\"malemburg\",\"marchingMarcin\",\"mariog5tw\",\"matrixise\",\"med_vector\",\"mesic_ivan\",\"methauser\",\"micktwomey\",\"micropython\",\"miguelsr1987\",\"mikilinchu\",\"minglis\",\"miravallesm\",\"mircea_zetea\",\"mishunika\",\"moaiamorfo\",\"moderndev_org\",\"moreati\",\"mstuchli\",\"mtomwing\",\"mumak\",\"mutetella\",\"ncoghlan_dev\",\"nerdearla\",\"neuralhacker\",\"nodejstweet\",\"notsolonecoder\",\"ntigc\",\"ntoll\",\"olasitarska\",\"oleiade\",\"palimarium\",\"patrick91\",\"patrickwiener\",\"paulhildebrandt\",\"pauloxnet\",\"pdenapo\",\"pepuchoZ\",\"peterhoffmann\",\"philipp_kalweit\",\"piquadrat_ch\",\"porelmorro\",\"postenterprise\",\"pranavs18\",\"ps_python\",\"pvergain\",\"pyacademy\",\"pycologne\",\"pydatacarolinas\",\"pydatait\",\"pyladies\",\"pyladiesblore\",\"pythonsummit\",\"qba73\",\"radhios\",\"rafaorga\",\"ramalhoorg\",\"rcarrillocruz\",\"rciorba\",\"regiguren\",\"rembish\",\"renatolrr\",\"renedudfield\",\"rmarianoa\",\"rmistaken\",\"rodesia\",\"rodynnz\",\"roguelynn\",\"russel_winder\",\"rwillmer\",\"scas\",\"scott_triglia\",\"sealth\",\"sebineubauer\",\"secretsauceguys\",\"sectest9\",\"seznam_cz\",\"simbasso\",\"simondolle\",\"sirtoothbrush\",\"sjwrenlewis\",\"slavek_k\",\"slothy\",\"sprintworks\",\"strusberg\",\"swintgs\",\"sysarmy\",\"talideon\",\"tanyaschlusser\",\"tcarrez\",\"teach_python\",\"the_compiler\",\"thebenlove\",\"tjguk\",\"tmuxbee\",\"toptalllc\",\"travelperk\",\"tsatt_team\",\"ubnu42\",\"ulysseas\",\"unbit\",\"urbanskudnik\",\"uweziegenhagen\",\"vhardion\",\"victornc83\",\"vkmc\",\"vpettorino\",\"vvatsa\",\"whosbacon\",\"whykay\",\"yamila_moreno\",\"zamarrowski\",\"zeth0\",\"zuriich92\"],\"x\":[0.32937314578834825,0.34948677156023716,0.8882892913147034,0.4562184002572107,0.6293972386035256,0.5267863645195076,0.8420677510419282,0.17512726011751575,0.7998254358498652,0.4850450724209578,0.6074710587608619,0.6080051629526841,0.49944412323518156,0.6268508164927742,0.5895173731766337,0.01491152415878895,0.6107355293327792,0.4907090195063411,0.2753690782443153,0.7004173260385501,0.7560820530487513,0.8929393822206129,0.40731554504571377,0.5447150666945445,0.47738724885640027,0.3738634677907164,0.19425256693751614,0.34599043477666275,0.5529824335702461,0.5350126454523644,0.6183173145362721,0.5966708414632891,0.40997393568107054,0.559419831092162,0.5946504680499989,0.26121459320914797,0.5359688794021277,0.5987207378759382,0.38710514416806735,0.834430925358825,0.4977382956718392,0.2526976678148345,0.42295945765243814,0.6154578014735469,0.7749704651885716,0.723708267997975,0.5169218248929459,0.7344383643704192,0.7483810189890286,0.8639999622738026,0.8438595465067269,0.4449409251161033,0.46608893696390463,0.1893636514025236,0.6403023207536772,0.5413675166391315,0.36329127930353833,0.42677214100651073,0.40801296993013914,0.03387804922264454,0.40167020169332,0.8245584052983008,0.5113462489571763,0.339490529991326,0.5458348865235372,0.8429349676089558,0.841436009225072,0.49425476008554386,0.24092592363167847,0.7415379765400981,0.6824933772230014,0.7866984440999546,0.6986026475011937,0.6861337059886096,0.8999153118864638,0.46562646714640893,0.5961847279537155,0.3094196801466035,0.5503692923694219,0.40246340244580703,0.812997251330952,0.4536149058326496,0.43136066141760676,0.2408523952121474,0.7328624564696022,0.680297843895486,0.869789378211215,0.2284611938858925,0.596605921943523,0.01734191341632451,0.2949650517770683,0.32306974830188095,0.43175051267272974,0.4189157068812568,0.7935304655073256,0.2984755496377469,0.6433428028976722,0.7409999722997533,0.16720049055701025,0.2991927802544625,0.46725188988062477,0.7872166262798496,0.0666376520597208,0.5790707889827418,0.4962091998987209,0.32725306453715725,0.8105537647772262,0.05119568519436346,0.19349604237479048,0.5649709653000902,0.6968954957038507,0.6250611858264904,0.6080309874401345,0.3962128954605851,0.22319313083257478,0.6781321865441622,0.3354796280607799,0.5124618527636177,0.48393231337562054,0.761224114805333,0.4715396132256285,0.7516747463259655,0.39436003118292895,0.36366893746276097,0.726770167517955,0.9677721505314865,0.2580476450823534,0.5276767715252405,0.5277819773456729,0.8189600654341986,0.24820547587082087,0.8324764569733091,0.5972718337639362,0.761813628266647,0.8168057606613124,0.2668432841062252,0.8931697215832224,0.10861525817488801,0.45401224027153125,0.7243670816727983,0.7138964428690399,0.35594095814264237,0.23564451833165584,0.7167019153870717,0.3258229314629499,0.4460363754868059,0.2340754405001311,0.6518500628476263,0.6473208358041451,0.5475352476810662,0.5448191465475354,0.6717153141828879,0.8628547242807124,0.7680466001592029,0.4232741731428999,0.28258678170836293,0.7761786220296911,0.22900430309695666,0.46232631932681983,0.7042899634519145,0.3679874628262692,0.28437605693851287,0.761656859121696,0.4322559884048272,0.29952075887699614,0.49592377787927816,0.28311721776637655,0.6685489782327163,0.8556121857527282,0.7916796401593695,0.7847822765559535,0.5071638873750163,0.48632283686369515,0.271838772675641,0.18531482750887057,0.6649554871730126,0.567920962016376,0.7859863180590075,0.1608098361767725,0.4077105934103404,0.5819844791493612,0.5217992519770993,0.8366710372490394,0.4864261770589082,0.5659837781046475,0.396558598150051,0.5505241768390209,0.7266454077620865,0.3474967582324662,0.3696102306509866,0.07346649337272483,0.877096902978967,0.05440411351733689,0.6768329005466855,0.7791414891415637,0.8560536118270783,0.6329493711757243,0.4133296998103043,0.19650212578825868,0.5250628515459467,0.430521278698538,0.4529860888516215,0.34790904717371385,0.6122920872296445,0.20442646732631017,0.39925818847095174,0.3350585537496382,0.5096609465005195,0.2941857964504337,0.6924426591714892,0.627272250059462,0.3661621372044959,0.7037922615792445,0.6591189655369051,0.4184581518441556,0.48540992073820394,0.5992223660595205,0.8263847481724219,0.2879879844646292,0.5761766725749653,0.1322454057651943,0.46301048244358173,0.3296525707818188,0.27087086409615146,0.4530764629204581,0.4239438713479811,0.15719524760500456,0.3130781698377906,0.1843789805922721,0.38529607741643523,0.012345996632333186,0.7452906139267168,0.2358727100151212,0.5313109656023342,0.2570141524214476,0.6831222541558417,0.29134409322657606,0.6277876734099467,0.7946978866221922,0.7052668737315834,0.7404431308269849,0.7131000611151268,0.33634272929883396,0.8345012133036179,0.7675582807520264,0.6925271287281928,0.7388205894069465,0.7272638538465169,0.2743397678659176,0.3959163596851933,0.6520292797891475,0.6401117262934481,0.5273702911813317,0.003015380849707185,0.21718748780794514,0.2981618960890701,0.18139172755563043,0.6527603423114108,0.14722407149633063,0.47242041926269346,0.4082859360018825,0.46741740038951296,0.5560658847433289,0.4765462912646269,0.7814198436314305,0.7994834301821617,0.3093605027419721,0.018422355054930853,0.25536819436085423,0.166819139529403,0.6167832479852217,0.28602282595682754,0.1517748264614068,0.6629041068383162,0.544539004263694,0.44931378564384283,0.8790374985140805,0.3898214122008547,0.6675537786814328,0.5085355089048774,0.4454174987254497,0.006266469508740191,0.7180429321977851,0.7670459256438553,0.651783556975088,0.6565697794292283,0.5376504568319638,0.4574369736626141,0.28638920473736407,0.5028661165493689,0.8326603424290081,0.17952403456861613,0.7274773978033486,0.42859586363905927,0.7085157545233863,0.20568856869292532,0.5693465742587844,0.5034422420528094,0.9009080692474105,0.13777514371507615,0.4871078639740247,0.2170270862194745,0.6690835875483784,0.3835366836923065,0.5260875552648081,0.7145665609164941,0.7622356439433351,0.256898169164969,0.5167072560318462,0.37238772853881913,0.21176849404182965,0.3570884139781243,0.7928027598163593,0.2632069130739772,0.5638629012589974,0.62667991174485,0.35660111712708964,0.337805765625278,0.5768091365055497,0.4658322959020708,0.7754670377276417,0.7871751446700895,0.39509450781332645,0.42703531786246235,0.6856612640188375,0.5593387736680957,0.12861167176615745,0.651284678747614,0.8867889565968607,0.5594875154588832,0.4326081736583103,0.6788475874745815,0.510636052227933,0.3859002352702982,0.43758201921451484,0.8550325710422679,0.5907137988525875,0.42179931848929575,0.6182294553862728,0.21728377584402567,0.31671444199530546,0.2622240439629714,0.3883046727706779,0.4523018886875211,0.8182375006568635,0.43309367370941704,0.07356067020449042,0.8764029275146705,0.6707908271840203,0.5878329508692572,0.23434494729439112,0.25876633382212216,0.5332561504933538,0.6505706726576815,0.6978388426777503,0.8751765679775968,0.6964366138893624,0.49714673323819925,0.4390134984338319,0.3706081060186885,0.6338609228657242,0.7618397943634078,0.44810173436769446,0.32466549841724035,0.014738104337967814,0.34822187064016563,0.6180153563450871,0.25937843210368355,0.24043984372654761,0.3451810016352063,0.30337140564146303,0.17699789901213275,0.6051882508374126,0.37507348473355595,0.7495572849740229,0.7106268413894079,0.4850507051728439,0.8514221020669225,0.5048020132447048,0.17743396243185067,0.6301227041720708,0.6200866052863462,0.1956204643491215,0.7710731504157251,0.8458135821758563,0.5985644739547227,0.37686218083089046,0.5008342945444857,0.7249121824073669,0.6277656575160098,0.9564087420034828,0.42091930483654755,0.6268218014615353,0.8834912863072185,0.0004072719444873302,0.642911896564152,0.5329057104081123,0.4021407240331482,0.4016712656772196,0.8074746819308689,0.8953123919280528,0.717088586823395,0.3185649993242489,0.6899260224655718,0.7362508636476812,0.36833004578891965,0.8010814415715746,0.21808878860540684,0.4409991471742692,0.653308244231644,0.5200235387316209,0.5018163516447947,0.5735981203934972,0.8109428641580553,0.28620078997995535,0.5855843530952799,0.09238113774550924,0.31086305052919483,0.10831624645503504,0.6757251420711579,0.3767405480752065,0.12481825518894532,0.0,0.6593906549121756,0.3337395622473997,0.27913978746429013,0.8636362988904436,0.4630528834970288,0.44135240790243374,0.6522806171755322,0.27905603083075564,0.010924079583337212,0.024692388236573402,0.7125408561767473,0.8045028091519743,0.8392903505932183,0.5988334756269038,0.9359267969716011,0.7531227867440443,0.7469397426983816,0.8934477193344548,0.3567440019403381,0.8907052237673692,0.8144674872146741,0.8199222308019513,0.8673087402297465,0.49699675212891453,0.4797842514091308,0.6423456766982111,0.6010403923593373,0.43197377845479096,0.5760663534786334,0.37618345634908607,0.3707113270994126,0.20315850054990733,0.5177148447912643],\"y\":[0.28967045807142405,0.49321589761667906,0.6114884559743814,0.28765897036398186,0.42038396057478256,0.24488037792617978,0.6555924748004226,0.637701616562345,0.40775345452754036,0.816696387794036,0.6386468337920613,0.08710036054342263,0.0,0.9830068707539786,0.1331731863459878,0.3756071601170002,0.5716356784561741,0.2678319918497413,0.7444164662901014,0.4710846877627917,0.46463118186664565,0.4049271448617068,0.18444928769237487,0.27420827225574895,0.30604823057945385,0.18221201116375585,0.5452245805654169,0.5756934843630539,0.5371251862374531,0.35537686614228586,0.691886326565762,0.24086342723742865,0.7890076050183971,0.7321686807058896,0.16173073020245696,0.9379828427440832,0.6085669803114362,0.012014781810010287,0.8321147999922618,0.5332065483951346,0.5633846671937589,0.2669192248469852,0.41747798898431937,0.16036723110733567,0.24484892440599748,0.19584745008425958,0.39723488268211155,0.5476713970682007,0.74877366793852,0.6355438452819554,0.45567894400574516,0.8129565908543038,0.7193167344323413,0.42664086597482787,0.6191203260359933,0.10224652605134109,0.16016274624505258,0.7995760532528451,0.12389046732526335,0.6831448909424619,0.7089756923612295,0.6026806938089542,0.7310000899182425,0.16852785115334742,0.13366888995334028,0.48090941535909565,0.42687603977834965,0.7164114852181838,0.5803926327104053,0.4388313367196233,0.7726065575391908,0.444027353342111,0.6017510295555455,0.09014206234609701,0.4393404746789394,0.002798961435541578,0.44720670796608125,0.15065641730078955,0.7088679714710461,0.5634640869349782,0.24019339361525108,0.3784550836111945,0.7452829125960218,0.24375376247989744,0.5140240042309399,0.6624697707834359,0.5283913703426419,0.3788913931950467,0.3698943178774708,0.5655243837424004,0.6177264302342022,0.18969589121840597,0.6958513172750607,0.4598101669700343,0.6586521543222597,0.5862690940697507,0.3744413623546023,0.2197776096402575,0.3642910540840711,0.7119263878031391,0.6904226612863027,0.38789225754056694,0.7462947759422153,0.8480644043231941,0.2030813546636055,0.6819393646825664,0.6210846640660135,0.27779010446024777,0.3872220465602767,0.2576482912815104,0.6797349754383587,0.20963739924688715,0.48453723694984574,0.15869576594179613,0.5354332583594661,0.1486026017777609,0.660432871437816,0.6318110145695137,0.15968467616016585,0.7345271082885712,0.36705657941491054,0.7045574966363791,0.657086202431473,0.8078391955329095,0.7595767097293317,0.32811574748523936,0.35091370069078043,0.15419286639427188,0.19933334488961252,0.6399926936563858,0.7357940507538124,0.5091876625107056,0.6745803882193274,0.5059293859544223,0.5704206344468208,0.468087975974438,0.532079273991722,0.24383610004311296,0.7474388513889462,0.608632763773559,0.5392331611303647,0.19731172210428197,0.6074850831813735,0.6383001874738673,0.35319012821601903,0.1680352984790842,0.637727285059424,0.3393929547320893,0.2694545569779559,0.7504090640510136,0.39651518609686176,0.5999866263324974,0.40258749171673497,0.5884439725024153,0.15031846957277747,0.4198032904377029,0.7612193446686886,0.4507684163240844,0.45250458946179123,0.8086494090192747,0.6279263550325983,0.831282443778007,0.18497468648403095,0.5457359122517992,0.24740263237564292,0.4030728953171881,0.35372947827716217,0.30898003112970135,0.3011411395091858,0.3461691993004907,0.5661247818553705,0.08797376753696164,0.6424909535271728,0.23966908896035619,0.4935214922361755,0.5681739762661152,0.5671348921371102,0.7117538031098491,0.630801416528471,0.5411998098354136,0.42047350559793945,0.12164262906037887,0.2851408486858898,0.3694577704292969,0.5197629058866543,0.4977491277771893,0.20835868980238664,0.05477044416658729,0.5464994824749025,0.4415399262979149,0.42462563666944586,0.4281253663696925,0.7237466047750631,0.4285635536904042,0.32830933898901904,0.37938243566997665,0.31595608407855186,0.7334027682174646,0.45743011437986236,0.7527254406328888,0.2500794065488848,0.48046567508521565,0.321680047850924,0.3951994930091709,0.1081767734249794,0.31762800862395507,0.5940705956617384,0.5782368882477646,0.18417900132468612,0.40545765038305975,0.7923960630635131,0.46542373082288824,0.7641417465286434,0.7113211289585225,0.6156320944435291,0.105211734290933,0.7392730165959559,0.30899557178097814,0.5586600444464479,0.5835240296844172,0.4525379216453794,0.6162626818062846,0.4926392468174273,0.32625936365022923,0.8830079150374622,0.48979672257253865,0.5269626819567745,0.9633874721979587,0.8682780812412808,0.35354765901276075,0.5342409109794203,0.6244488551073897,0.30113802493274033,0.7217819685043624,0.3811804114215997,0.6314946864402609,0.7580853182147079,0.6429307396691056,0.19715153275207803,0.13627939091125882,0.16969556638132585,0.7371297618622412,0.7976637782492555,0.25983621371186605,0.21223921744449123,0.5514117581134003,0.2545198557999168,0.29959065960548625,0.4435919918519365,0.479491914506478,0.649129723689199,0.6946543424032136,0.4644265933240915,0.4385303799398052,0.2866761446724974,0.32903756454915417,0.3248285503180051,0.5381327218855235,0.8554334126061353,0.1323325629683591,0.6852702632643184,0.5324797516965024,0.9970655067320642,0.7423330343043048,0.2717753269630601,0.5116991430043761,0.3015005471981137,0.6015546785961549,0.6598473043084586,0.5934927805921262,0.3377009970768298,0.20913385755198127,0.7487474820814098,0.9722576374189348,0.8528721121156967,0.7900187994632909,0.34976785016864254,0.4607304950314831,0.3814101792614075,0.8134193274559792,0.6034712410443259,0.4164583046415229,0.9463574822795291,0.628402889749191,0.17145904021242891,0.7879215815685586,0.8023112618661227,0.10182279050687786,0.30163224913901937,0.3682142606449557,0.8731475419437271,0.4665701285897894,0.3961863164628086,0.5146859906287252,0.4412738654608661,0.5973150253917375,0.11577436713543154,0.2961160615424195,0.4722671490732712,0.41254406548995315,0.7941581650806059,0.5644052729302718,0.19594640773543653,0.10193544041342725,0.33055713136062487,0.16408292422416088,0.35124935361294507,0.42195595902769334,0.7968717860750494,0.6580949110185261,0.6762104750895189,0.7146508825410139,0.22863153884520127,0.6855416614287914,0.3073870265835071,0.8370998501953743,0.7621605629428484,0.25737918638708507,0.33843500925763914,0.8045534864851885,0.6797909978021992,0.8223984231829917,0.7311120412458607,0.3054425167881268,0.4876032944294878,0.4633349136726842,0.21154712567125186,0.4452292275739381,0.37719691319932325,0.388417647624072,0.1125462696946161,0.2394744818775305,0.5993878107889014,0.41569664957548513,0.224994162377506,0.5943727764857878,0.70196767347563,0.5855399018260025,0.2627189451238526,0.3292708222451807,0.2242436061445224,0.060307632698421966,0.43293099809978064,0.32060758787424637,0.6741822813624635,0.40944090394725324,0.23747688018632296,0.45955818521324665,0.6865036503447209,0.08155316871340108,0.923372596923963,0.21337252010202712,0.6355543158364171,0.8315177459730111,0.20490598362692178,0.49224398292360866,0.3756304159096863,0.2402041690827045,0.7211525475839037,0.3560301340694253,0.7519820126003876,0.4058441348357288,0.13857379959444122,0.76402195296293,0.582176442627514,0.6980098944564919,0.5145525649499937,0.6344026112713228,0.5071788679257944,0.22008850143988615,0.5007766899277777,0.6535846371981258,0.30365752381793865,0.7002219082501343,0.290973142510098,0.6594916630702127,0.33364665792653025,0.35602008500293675,0.6891849194688708,0.29026007298482365,0.5750826143843594,0.13291619607318123,0.5162309872640686,0.3076447431098306,0.1394052277779232,0.798598861653098,0.3850658234158584,0.13390310266931893,0.4889075870448013,0.45967477884167124,0.7034586032808088,0.37439611908434434,0.04536084763174147,0.5586561342032628,0.5051474678294182,0.0839364307451562,0.6861984278986488,0.5191506485901891,0.24532755355273295,0.697774703423627,0.5034199838939876,0.22637531395393293,0.4081364148795204,0.17837135328717482,0.579640533495896,0.27007728591199187,0.3662196950547806,0.4806671826599098,0.5204616184970776,0.02602260530775652,0.8557571722218559,1.0,0.15956168335173848,0.27328737251276447,0.527730855490007,0.5505574055447559,0.2877245275031935,0.5435332140153116,0.3512865619336758,0.3529082566550165,0.13741285746048232,0.7131321290633202,0.47425440150618353,0.7455202993113186,0.1324193910282083,0.6713688656097923,0.5696401069015957,0.23709655038122238,0.6500322109180686,0.13948597135490573,0.3836060316311979,0.5552044611623879,0.6237727305021749,0.27600443680581555,0.4812389911319088,0.3336401440765844,0.5936053922055856,0.7332106471142972,0.9312095100973454,0.32365947792215594,0.20246350467293522,0.3975901164304786,0.6929474037593202,0.43351085519853894,0.5478678495498374,0.32447229181159315,0.7510563490127009,0.6143159256020416,0.48867307066228693,0.19792836219983753,0.3574758276477921,0.268006552837604,0.611776552412223,0.5351326715500055,0.4056395478047269,0.5210969333616969]}},\"id\":\"3f023844-1e56-4428-a551-094d91501d03\",\"type\":\"ColumnDataSource\"},{\"attributes\":{},\"id\":\"9720aeca-f949-4a69-a0d8-7d5eed928666\",\"type\":\"BasicTicker\"},{\"attributes\":{\"dimension\":1,\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"20197a57-7180-4dba-a3f8-12a57f1aedd1\",\"type\":\"BasicTicker\"}},\"id\":\"6f9bf602-63a5-4def-a45d-b8d7d5517b4e\",\"type\":\"Grid\"},{\"attributes\":{\"callback\":null},\"id\":\"1921560f-a905-489e-b6cf-761048d9142d\",\"type\":\"DataRange1d\"},{\"attributes\":{},\"id\":\"7dcaa794-a580-402c-992d-7e817bb11318\",\"type\":\"ToolEvents\"},{\"attributes\":{\"bottom_units\":\"screen\",\"fill_alpha\":{\"value\":0.5},\"fill_color\":{\"value\":\"lightgrey\"},\"left_units\":\"screen\",\"level\":\"overlay\",\"line_alpha\":{\"value\":1.0},\"line_color\":{\"value\":\"black\"},\"line_dash\":[4,4],\"line_width\":{\"value\":2},\"plot\":null,\"render_mode\":\"css\",\"right_units\":\"screen\",\"top_units\":\"screen\"},\"id\":\"e291121b-79c6-40c5-b081-7371926c685a\",\"type\":\"BoxAnnotation\"},{\"attributes\":{},\"id\":\"f26e124b-b0b4-493f-b007-5e80685078a5\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"callback\":null},\"id\":\"ab1e5802-a479-4dbc-958f-520d5c45c00b\",\"type\":\"DataRange1d\"},{\"attributes\":{\"active_drag\":\"auto\",\"active_scroll\":\"auto\",\"active_tap\":\"auto\",\"tools\":[{\"id\":\"145c024b-5fa5-4086-871c-cd25f1d1ac7a\",\"type\":\"HoverTool\"},{\"id\":\"dee07948-35c4-4872-a632-62aedee74dcf\",\"type\":\"TapTool\"},{\"id\":\"60156367-73d9-4892-8324-eaa5c2ee576f\",\"type\":\"BoxZoomTool\"},{\"id\":\"5adc6f1b-6f56-486a-9aee-20ea3f45dd55\",\"type\":\"ResetTool\"}]},\"id\":\"f8b07d79-31cc-41d8-87c7-02367bbe3be0\",\"type\":\"Toolbar\"},{\"attributes\":{\"below\":[{\"id\":\"e43c1d7a-7174-4725-a05c-aecb2ecf6c29\",\"type\":\"LinearAxis\"}],\"left\":[{\"id\":\"c82cd6a8-c815-4d2a-848e-1e6052945a3c\",\"type\":\"LinearAxis\"}],\"plot_height\":400,\"plot_width\":800,\"renderers\":[{\"id\":\"e43c1d7a-7174-4725-a05c-aecb2ecf6c29\",\"type\":\"LinearAxis\"},{\"id\":\"7cddbcbd-7485-449e-9f4f-5bd9d4f56156\",\"type\":\"Grid\"},{\"id\":\"c82cd6a8-c815-4d2a-848e-1e6052945a3c\",\"type\":\"LinearAxis\"},{\"id\":\"6f9bf602-63a5-4def-a45d-b8d7d5517b4e\",\"type\":\"Grid\"},{\"id\":\"e291121b-79c6-40c5-b081-7371926c685a\",\"type\":\"BoxAnnotation\"},{\"id\":\"05c6bf18-f6a1-476c-b604-f3a5412b4df2\",\"type\":\"GlyphRenderer\"}],\"title\":{\"id\":\"800ff3d4-6e8f-4a0b-87a3-6bc5122f7678\",\"type\":\"Title\"},\"tool_events\":{\"id\":\"7dcaa794-a580-402c-992d-7e817bb11318\",\"type\":\"ToolEvents\"},\"toolbar\":{\"id\":\"f8b07d79-31cc-41d8-87c7-02367bbe3be0\",\"type\":\"Toolbar\"},\"x_range\":{\"id\":\"ab1e5802-a479-4dbc-958f-520d5c45c00b\",\"type\":\"DataRange1d\"},\"y_range\":{\"id\":\"1921560f-a905-489e-b6cf-761048d9142d\",\"type\":\"DataRange1d\"}},\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{\"fill_color\":{\"value\":\"blue\"},\"line_color\":{\"value\":\"blue\"},\"size\":{\"units\":\"screen\",\"value\":10},\"x\":{\"field\":\"x\"},\"y\":{\"field\":\"y\"}},\"id\":\"3d9732c3-0763-417f-86b3-6c19897b1851\",\"type\":\"Circle\"},{\"attributes\":{},\"id\":\"20197a57-7180-4dba-a3f8-12a57f1aedd1\",\"type\":\"BasicTicker\"},{\"attributes\":{\"data_source\":{\"id\":\"3f023844-1e56-4428-a551-094d91501d03\",\"type\":\"ColumnDataSource\"},\"glyph\":{\"id\":\"3d9732c3-0763-417f-86b3-6c19897b1851\",\"type\":\"Circle\"},\"hover_glyph\":null,\"level\":\"overlay\",\"nonselection_glyph\":{\"id\":\"a911e458-c64f-494c-8954-4b6214d3349f\",\"type\":\"Circle\"},\"selection_glyph\":null},\"id\":\"05c6bf18-f6a1-476c-b604-f3a5412b4df2\",\"type\":\"GlyphRenderer\"},{\"attributes\":{\"fill_alpha\":{\"value\":0.1},\"fill_color\":{\"value\":\"#1f77b4\"},\"line_alpha\":{\"value\":0.1},\"line_color\":{\"value\":\"#1f77b4\"},\"size\":{\"units\":\"screen\",\"value\":10},\"x\":{\"field\":\"x\"},\"y\":{\"field\":\"y\"}},\"id\":\"a911e458-c64f-494c-8954-4b6214d3349f\",\"type\":\"Circle\"},{\"attributes\":{\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"}},\"id\":\"5adc6f1b-6f56-486a-9aee-20ea3f45dd55\",\"type\":\"ResetTool\"},{\"attributes\":{},\"id\":\"11e0143f-ef0b-4d47-9e99-898ba2130987\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"plot\":null,\"text\":null},\"id\":\"800ff3d4-6e8f-4a0b-87a3-6bc5122f7678\",\"type\":\"Title\"},{\"attributes\":{\"formatter\":{\"id\":\"f26e124b-b0b4-493f-b007-5e80685078a5\",\"type\":\"BasicTickFormatter\"},\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"9720aeca-f949-4a69-a0d8-7d5eed928666\",\"type\":\"BasicTicker\"}},\"id\":\"e43c1d7a-7174-4725-a05c-aecb2ecf6c29\",\"type\":\"LinearAxis\"},{\"attributes\":{\"callback\":null,\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"}},\"id\":\"dee07948-35c4-4872-a632-62aedee74dcf\",\"type\":\"TapTool\"},{\"attributes\":{\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"9720aeca-f949-4a69-a0d8-7d5eed928666\",\"type\":\"BasicTicker\"}},\"id\":\"7cddbcbd-7485-449e-9f4f-5bd9d4f56156\",\"type\":\"Grid\"},{\"attributes\":{\"overlay\":{\"id\":\"e291121b-79c6-40c5-b081-7371926c685a\",\"type\":\"BoxAnnotation\"},\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"}},\"id\":\"60156367-73d9-4892-8324-eaa5c2ee576f\",\"type\":\"BoxZoomTool\"},{\"attributes\":{\"formatter\":{\"id\":\"11e0143f-ef0b-4d47-9e99-898ba2130987\",\"type\":\"BasicTickFormatter\"},\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"20197a57-7180-4dba-a3f8-12a57f1aedd1\",\"type\":\"BasicTicker\"}},\"id\":\"c82cd6a8-c815-4d2a-848e-1e6052945a3c\",\"type\":\"LinearAxis\"},{\"attributes\":{\"callback\":null,\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"tooltips\":[[\"name\",\"@name\"],[\"id\",\"$index\"]]},\"id\":\"145c024b-5fa5-4086-871c-cd25f1d1ac7a\",\"type\":\"HoverTool\"}],\"root_ids\":[\"5d5b7b93-ed51-44de-a816-c29d492b70ab\"]},\"title\":\"Bokeh Application\",\"version\":\"0.12.0\"}};\n",
       "            var render_items = [{\"docid\":\"b865474b-1be9-401e-b030-7ecba4a5be4b\",\"elementid\":\"01e3770c-7cdf-422a-8887-a8335a2dc260\",\"modelid\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"notebook_comms_target\":\"0353d78e-9b87-426f-8932-041c883a7c48\"}];\n",
       "            \n",
       "            Bokeh.embed.embed_items(docs_json, render_items);\n",
       "        });\n",
       "      },\n",
       "      function(Bokeh) {\n",
       "      }\n",
       "    ];\n",
       "  \n",
       "    function run_inline_js() {\n",
       "      for (var i = 0; i < inline_js.length; i++) {\n",
       "        inline_js[i](window.Bokeh);\n",
       "      }\n",
       "    }\n",
       "  \n",
       "    if (window._bokeh_is_loading === 0) {\n",
       "      console.log(\"Bokeh: BokehJS loaded, going straight to plotting\");\n",
       "      run_inline_js();\n",
       "    } else {\n",
       "      load_libs(js_urls, function() {\n",
       "        console.log(\"Bokeh: BokehJS plotting callback run at\", now());\n",
       "        run_inline_js();\n",
       "      });\n",
       "    }\n",
       "  }(this));\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<p><code>&lt;Bokeh Notebook handle for <strong>In[4]</strong>&gt;</code></p>"
      ],
      "text/plain": [
       "<bokeh.io._CommsHandle at 0x1063277b8>"
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "output_notebook(); show(plot)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# Step 3: Add the edges\n",
    "\n",
    "### Prepare the networkX edges"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "collapsed": false,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [],
   "source": [
    "def get_edges_specs(_network, _layout):\n",
    "    d = dict(xs=[], ys=[], alphas=[])\n",
    "    weights = [d['weight'] for u, v, d in _network.edges(data=True)]\n",
    "    max_weight = max(weights)\n",
    "    calc_alpha = lambda h: 0.1 + 0.6 * (h / max_weight)\n",
    "\n",
    "    # example: { ..., ('user47', 'da_bjoerni', {'weight': 3}), ... }\n",
    "    for u, v, data in _network.edges(data=True):\n",
    "        d['xs'].append([_layout[u][0], _layout[v][0]])\n",
    "        d['ys'].append([_layout[u][1], _layout[v][1]])\n",
    "        d['alphas'].append(calc_alpha(data['weight']))\n",
    "    return d"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "### Create a ColumnDataSource for the edges"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "collapsed": false,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [],
   "source": [
    "lines_source = ColumnDataSource(get_edges_specs(network, layout))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "collapsed": false,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "\n",
       "    <div class=\"bk-root\">\n",
       "        <div class=\"plotdiv\" id=\"6ed1c7a1-119e-4d72-9657-d5d894380eb3\"></div>\n",
       "    </div>\n",
       "<script type=\"text/javascript\">\n",
       "  \n",
       "  (function(global) {\n",
       "    function now() {\n",
       "      return new Date();\n",
       "    }\n",
       "  \n",
       "    if (typeof (window._bokeh_onload_callbacks) === \"undefined\") {\n",
       "      window._bokeh_onload_callbacks = [];\n",
       "    }\n",
       "  \n",
       "    function run_callbacks() {\n",
       "      window._bokeh_onload_callbacks.forEach(function(callback) { callback() });\n",
       "      delete window._bokeh_onload_callbacks\n",
       "      console.info(\"Bokeh: all callbacks have finished\");\n",
       "    }\n",
       "  \n",
       "    function load_libs(js_urls, callback) {\n",
       "      window._bokeh_onload_callbacks.push(callback);\n",
       "      if (window._bokeh_is_loading > 0) {\n",
       "        console.log(\"Bokeh: BokehJS is being loaded, scheduling callback at\", now());\n",
       "        return null;\n",
       "      }\n",
       "      if (js_urls == null || js_urls.length === 0) {\n",
       "        run_callbacks();\n",
       "        return null;\n",
       "      }\n",
       "      console.log(\"Bokeh: BokehJS not loaded, scheduling load and callback at\", now());\n",
       "      window._bokeh_is_loading = js_urls.length;\n",
       "      for (var i = 0; i < js_urls.length; i++) {\n",
       "        var url = js_urls[i];\n",
       "        var s = document.createElement('script');\n",
       "        s.src = url;\n",
       "        s.async = false;\n",
       "        s.onreadystatechange = s.onload = function() {\n",
       "          window._bokeh_is_loading--;\n",
       "          if (window._bokeh_is_loading === 0) {\n",
       "            console.log(\"Bokeh: all BokehJS libraries loaded\");\n",
       "            run_callbacks()\n",
       "          }\n",
       "        };\n",
       "        s.onerror = function() {\n",
       "          console.warn(\"failed to load library \" + url);\n",
       "        };\n",
       "        console.log(\"Bokeh: injecting script tag for BokehJS library: \", url);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      }\n",
       "    };var element = document.getElementById(\"6ed1c7a1-119e-4d72-9657-d5d894380eb3\");\n",
       "    if (element == null) {\n",
       "      console.log(\"Bokeh: ERROR: autoload.js configured with elementid '6ed1c7a1-119e-4d72-9657-d5d894380eb3' but no matching script tag was found. \")\n",
       "      return false;\n",
       "    }\n",
       "  \n",
       "    var js_urls = [];\n",
       "  \n",
       "    var inline_js = [\n",
       "      function(Bokeh) {\n",
       "        Bokeh.$(function() {\n",
       "            var docs_json = {\"652e6c5c-946c-49cb-80d4-2d945130ba16\":{\"roots\":{\"references\":[{\"attributes\":{\"callback\":null,\"column_names\":[\"name\",\"x\",\"y\"],\"data\":{\"name\":[\"100Commits\",\"1337bullets\",\"1st1\",\"AartGoossens\",\"AbletonDev\",\"AdaTheShow\",\"AergNuor\",\"AishaXBello\",\"Angel_Cruijff\",\"Angelinux3000\",\"ApacheAirflow\",\"BBC\",\"BBCmicrobit\",\"BYAnalytics_en\",\"BayesianHorse\",\"BetabeersVG\",\"BlueYonderTech\",\"BokehPlots\",\"BorsLTD\",\"CAChemEorg\",\"CIBBVA\",\"Cambolc\",\"Charles_JUDITH\",\"CodingGrace\",\"ContinuumIO\",\"CriteoEng\",\"DRMacIver\",\"DaniBot_\",\"DanielDomeneL\",\"DaryaChyzhyk\",\"DasIstHerrKuska\",\"DavidjMarkey\",\"DeborahTaos12\",\"DigitYasuhara\",\"DjangoGirlsDUB\",\"DjangoGirlsEP16\",\"DjangoGirlsEc\",\"EPfestival\",\"ElnexoMarit\",\"EnCuKou\",\"EnriquetaSo\",\"EntropyFarmer\",\"Eurocentrique\",\"EventGeekie\",\"FAECTA_\",\"FernanMilla\",\"Foxinsock\",\"GMLudo\",\"Garrosa\",\"GinnyGhezzo\",\"GlaciarBlue\",\"Glenio_Oliveira\",\"GrandsCru\",\"GsBitBalear\",\"Gtzl\",\"HashtagLaToya\",\"HelloML9\",\"HokstadConsult\",\"HugoHerter\",\"IKERGUNE\",\"ITCrowdsource\",\"IcanadasM\",\"IldikoVancsa\",\"ImaneElAzlouk\",\"InspirefestHQ\",\"JOANNALETIZIA\",\"JancaStroma\",\"JasmineMcTigue\",\"Jaysinhp\",\"JohaPrime\",\"JoseOpposite\",\"JuliaDrBa\",\"KoehlerKerstin\",\"LIGO\",\"LaetitiaCarquet\",\"LatitudeFest\",\"Limejump\",\"Luen\",\"MBonell\",\"Macario8\",\"MakingLyst\",\"MarcoBasic\",\"MariaDehn\",\"MartaUhlirova\",\"MassHaste\",\"MaxBenChrist\",\"Miau_DB\",\"MiloslavPojman\",\"MirkoDziadzka\",\"MissPhilbin\",\"MongoDB\",\"MrsCaroline_C\",\"N4h_H4N\",\"NaomiCeder\",\"NegoBide\",\"NeuroSky\",\"NotANormalNerd\",\"NowLivecodingtv\",\"OReillyMedia\",\"OpenAtWE\",\"OpenStack\",\"PCalcao\",\"Patjouk\",\"Pazqo\",\"PiusNyongesa\",\"Polyconseiltech\",\"Ppuji1Ppuji\",\"PyCharm_edu\",\"PyConUK\",\"PyLadiesDub\",\"PythonEggs\",\"PythonIreland\",\"PythonSV\",\"RLerallut\",\"RTFMCelia\",\"RealPython\",\"RedHatNews\",\"Rhapsody_Girl\",\"Rico858\",\"SEReuskadi\",\"STajbakhsh\",\"SalamancaPeral\",\"SaltStack\",\"SaltStackInc\",\"SancasDev\",\"Sesivany\",\"Sophie_Talent\",\"Spanarchie\",\"SparkyCZ\",\"SrNilsson\",\"StefanTuralski\",\"StephLKim\",\"Sustatu\",\"TFConsult\",\"TeX4Publication\",\"ThePSF\",\"ThomasJWaldmann\",\"Transition\",\"Twitteze\",\"Ukerzel\",\"VictorStinner\",\"Vince92100\",\"ViniciusPach\",\"WickFelix\",\"WillingCarol\",\"WillyFrog_\",\"WuShell\",\"_JamesRG\",\"__amol__\",\"__katatonia\",\"__pamaron__\",\"_joac\",\"aRkadeFR\",\"a_soldatenko\",\"abelgvidal\",\"aborttrap6\",\"achimdomma\",\"acollard\",\"acpyss\",\"adambcn\",\"aitzol\",\"ajolo\",\"alabarga\",\"alba_caon\",\"alepernin\",\"alex_savio\",\"alison985\",\"almu_hs\",\"aloctavodia\",\"amleczko\",\"andrew_svetlov\",\"angineering\",\"angvp\",\"aniawsz\",\"aniiimaginary\",\"apueblago\",\"argenpython\",\"argonemyth\",\"asendecka\",\"asereteresa23\",\"astrojuanlu\",\"avillamarink\",\"b1n0anb\",\"b_smoke\",\"barakamediatv\",\"bayerdi\",\"bazkennedy\",\"bbc_microbit\",\"bbva\",\"ben_nuttall\",\"bilbaochess\",\"blckdt\",\"bmispelon\",\"bobcatwilson\",\"boiagames\",\"calvinhp\",\"carlosperate\",\"carohadad\",\"ccdesales\",\"cemnova\",\"ch_doig\",\"christianbarra\",\"clinker\",\"coala_analyzer\",\"cobe\",\"cobeio\",\"codekee\",\"codesyntax\",\"codingquark\",\"colmharrington\",\"connctBunker\",\"cool_python\",\"cris_calvo\",\"ctrebing\",\"d0ugal\",\"dArignac\",\"da_bjoerni\",\"dajoffe\",\"daniel7773121\",\"data_hope\",\"dbra\",\"deblike\",\"deshipu\",\"devbootcamp\",\"dfflanders\",\"diegor\",\"djangocon\",\"djangogirls\",\"docker\",\"doriczapari\",\"doughellmann\",\"douglasandrade\",\"drgarcia1986\",\"drridolfo\",\"drvinceknight\",\"dynamitts\",\"dzen\",\"eastigarraga\",\"echorand\",\"edu2b\",\"eitbAlbisteak\",\"eitbNoticias\",\"eladyonas\",\"eliasmoli\",\"eliasthorpet\",\"elmundoempresa\",\"emergya\",\"eolo999\",\"er1p\",\"erralin\",\"esletweets\",\"euro_ii\",\"europython\",\"euskalencounter\",\"evildmp\",\"exaeducation\",\"facebook\",\"facundobatista\",\"fbuontempo\",\"fedeteotini\",\"fergleiser\",\"fintxuarregi\",\"fishnets88\",\"fleioapp\",\"flubdevork\",\"flyingcircusio\",\"fmasanori\",\"freakboy3742\",\"free_control\",\"fuelex\",\"g16n\",\"gaceta_tec\",\"galindale\",\"gdsteam\",\"georgebernhard\",\"getGNU\",\"getbynder\",\"gherranzc\",\"giovannibajo\",\"globalmikem\",\"godlike64\",\"golangweekly\",\"google\",\"grupospri\",\"gwoptics\",\"hackebrot\",\"hanasulc\",\"hawkieowl\",\"helenst\",\"hendorf\",\"hpk42\",\"hundredrooms\",\"hydarscouser\",\"i4ssecurity\",\"iElectric\",\"iamtontann\",\"iferminm\",\"ifosch\",\"ikarantan\",\"iliebana\",\"imkaushalparikh\",\"indizen_corp\",\"int_lcd\",\"intel\",\"ioggstream\",\"iwangulenko\",\"j_zar21\",\"javier_arilos\",\"jbkamaraj\",\"jcoscia\",\"jdrumgoole\",\"jedux\",\"jesushdz_\",\"jimthree\",\"jirikuncar\",\"jjvie\",\"jmaurola\",\"jmkaluzka\",\"jmortegac\",\"josethegeek93\",\"kaleidomkt\",\"kantrn\",\"kanumankalwa\",\"kerma_dj\",\"kjam\",\"kkvie\",\"laceynwilliams\",\"ladybiss\",\"lehinevych\",\"leriomaggio\",\"lethal_guitar\",\"librecon\",\"linuxchixar\",\"loooorenanicole\",\"lucaotta\",\"lugensaDE\",\"luistxo\",\"lunkwill42\",\"lusantala\",\"m3ntaal\",\"m4rpl4t3ns3\",\"maidotgimenez\",\"malemburg\",\"marchingMarcin\",\"mariog5tw\",\"matrixise\",\"med_vector\",\"mesic_ivan\",\"methauser\",\"micktwomey\",\"micropython\",\"miguelsr1987\",\"mikilinchu\",\"minglis\",\"miravallesm\",\"mircea_zetea\",\"mishunika\",\"moaiamorfo\",\"moderndev_org\",\"moreati\",\"mstuchli\",\"mtomwing\",\"mumak\",\"mutetella\",\"ncoghlan_dev\",\"nerdearla\",\"neuralhacker\",\"nodejstweet\",\"notsolonecoder\",\"ntigc\",\"ntoll\",\"olasitarska\",\"oleiade\",\"palimarium\",\"patrick91\",\"patrickwiener\",\"paulhildebrandt\",\"pauloxnet\",\"pdenapo\",\"pepuchoZ\",\"peterhoffmann\",\"philipp_kalweit\",\"piquadrat_ch\",\"porelmorro\",\"postenterprise\",\"pranavs18\",\"ps_python\",\"pvergain\",\"pyacademy\",\"pycologne\",\"pydatacarolinas\",\"pydatait\",\"pyladies\",\"pyladiesblore\",\"pythonsummit\",\"qba73\",\"radhios\",\"rafaorga\",\"ramalhoorg\",\"rcarrillocruz\",\"rciorba\",\"regiguren\",\"rembish\",\"renatolrr\",\"renedudfield\",\"rmarianoa\",\"rmistaken\",\"rodesia\",\"rodynnz\",\"roguelynn\",\"russel_winder\",\"rwillmer\",\"scas\",\"scott_triglia\",\"sealth\",\"sebineubauer\",\"secretsauceguys\",\"sectest9\",\"seznam_cz\",\"simbasso\",\"simondolle\",\"sirtoothbrush\",\"sjwrenlewis\",\"slavek_k\",\"slothy\",\"sprintworks\",\"strusberg\",\"swintgs\",\"sysarmy\",\"talideon\",\"tanyaschlusser\",\"tcarrez\",\"teach_python\",\"the_compiler\",\"thebenlove\",\"tjguk\",\"tmuxbee\",\"toptalllc\",\"travelperk\",\"tsatt_team\",\"ubnu42\",\"ulysseas\",\"unbit\",\"urbanskudnik\",\"uweziegenhagen\",\"vhardion\",\"victornc83\",\"vkmc\",\"vpettorino\",\"vvatsa\",\"whosbacon\",\"whykay\",\"yamila_moreno\",\"zamarrowski\",\"zeth0\",\"zuriich92\"],\"x\":[0.32937314578834825,0.34948677156023716,0.8882892913147034,0.4562184002572107,0.6293972386035256,0.5267863645195076,0.8420677510419282,0.17512726011751575,0.7998254358498652,0.4850450724209578,0.6074710587608619,0.6080051629526841,0.49944412323518156,0.6268508164927742,0.5895173731766337,0.01491152415878895,0.6107355293327792,0.4907090195063411,0.2753690782443153,0.7004173260385501,0.7560820530487513,0.8929393822206129,0.40731554504571377,0.5447150666945445,0.47738724885640027,0.3738634677907164,0.19425256693751614,0.34599043477666275,0.5529824335702461,0.5350126454523644,0.6183173145362721,0.5966708414632891,0.40997393568107054,0.559419831092162,0.5946504680499989,0.26121459320914797,0.5359688794021277,0.5987207378759382,0.38710514416806735,0.834430925358825,0.4977382956718392,0.2526976678148345,0.42295945765243814,0.6154578014735469,0.7749704651885716,0.723708267997975,0.5169218248929459,0.7344383643704192,0.7483810189890286,0.8639999622738026,0.8438595465067269,0.4449409251161033,0.46608893696390463,0.1893636514025236,0.6403023207536772,0.5413675166391315,0.36329127930353833,0.42677214100651073,0.40801296993013914,0.03387804922264454,0.40167020169332,0.8245584052983008,0.5113462489571763,0.339490529991326,0.5458348865235372,0.8429349676089558,0.841436009225072,0.49425476008554386,0.24092592363167847,0.7415379765400981,0.6824933772230014,0.7866984440999546,0.6986026475011937,0.6861337059886096,0.8999153118864638,0.46562646714640893,0.5961847279537155,0.3094196801466035,0.5503692923694219,0.40246340244580703,0.812997251330952,0.4536149058326496,0.43136066141760676,0.2408523952121474,0.7328624564696022,0.680297843895486,0.869789378211215,0.2284611938858925,0.596605921943523,0.01734191341632451,0.2949650517770683,0.32306974830188095,0.43175051267272974,0.4189157068812568,0.7935304655073256,0.2984755496377469,0.6433428028976722,0.7409999722997533,0.16720049055701025,0.2991927802544625,0.46725188988062477,0.7872166262798496,0.0666376520597208,0.5790707889827418,0.4962091998987209,0.32725306453715725,0.8105537647772262,0.05119568519436346,0.19349604237479048,0.5649709653000902,0.6968954957038507,0.6250611858264904,0.6080309874401345,0.3962128954605851,0.22319313083257478,0.6781321865441622,0.3354796280607799,0.5124618527636177,0.48393231337562054,0.761224114805333,0.4715396132256285,0.7516747463259655,0.39436003118292895,0.36366893746276097,0.726770167517955,0.9677721505314865,0.2580476450823534,0.5276767715252405,0.5277819773456729,0.8189600654341986,0.24820547587082087,0.8324764569733091,0.5972718337639362,0.761813628266647,0.8168057606613124,0.2668432841062252,0.8931697215832224,0.10861525817488801,0.45401224027153125,0.7243670816727983,0.7138964428690399,0.35594095814264237,0.23564451833165584,0.7167019153870717,0.3258229314629499,0.4460363754868059,0.2340754405001311,0.6518500628476263,0.6473208358041451,0.5475352476810662,0.5448191465475354,0.6717153141828879,0.8628547242807124,0.7680466001592029,0.4232741731428999,0.28258678170836293,0.7761786220296911,0.22900430309695666,0.46232631932681983,0.7042899634519145,0.3679874628262692,0.28437605693851287,0.761656859121696,0.4322559884048272,0.29952075887699614,0.49592377787927816,0.28311721776637655,0.6685489782327163,0.8556121857527282,0.7916796401593695,0.7847822765559535,0.5071638873750163,0.48632283686369515,0.271838772675641,0.18531482750887057,0.6649554871730126,0.567920962016376,0.7859863180590075,0.1608098361767725,0.4077105934103404,0.5819844791493612,0.5217992519770993,0.8366710372490394,0.4864261770589082,0.5659837781046475,0.396558598150051,0.5505241768390209,0.7266454077620865,0.3474967582324662,0.3696102306509866,0.07346649337272483,0.877096902978967,0.05440411351733689,0.6768329005466855,0.7791414891415637,0.8560536118270783,0.6329493711757243,0.4133296998103043,0.19650212578825868,0.5250628515459467,0.430521278698538,0.4529860888516215,0.34790904717371385,0.6122920872296445,0.20442646732631017,0.39925818847095174,0.3350585537496382,0.5096609465005195,0.2941857964504337,0.6924426591714892,0.627272250059462,0.3661621372044959,0.7037922615792445,0.6591189655369051,0.4184581518441556,0.48540992073820394,0.5992223660595205,0.8263847481724219,0.2879879844646292,0.5761766725749653,0.1322454057651943,0.46301048244358173,0.3296525707818188,0.27087086409615146,0.4530764629204581,0.4239438713479811,0.15719524760500456,0.3130781698377906,0.1843789805922721,0.38529607741643523,0.012345996632333186,0.7452906139267168,0.2358727100151212,0.5313109656023342,0.2570141524214476,0.6831222541558417,0.29134409322657606,0.6277876734099467,0.7946978866221922,0.7052668737315834,0.7404431308269849,0.7131000611151268,0.33634272929883396,0.8345012133036179,0.7675582807520264,0.6925271287281928,0.7388205894069465,0.7272638538465169,0.2743397678659176,0.3959163596851933,0.6520292797891475,0.6401117262934481,0.5273702911813317,0.003015380849707185,0.21718748780794514,0.2981618960890701,0.18139172755563043,0.6527603423114108,0.14722407149633063,0.47242041926269346,0.4082859360018825,0.46741740038951296,0.5560658847433289,0.4765462912646269,0.7814198436314305,0.7994834301821617,0.3093605027419721,0.018422355054930853,0.25536819436085423,0.166819139529403,0.6167832479852217,0.28602282595682754,0.1517748264614068,0.6629041068383162,0.544539004263694,0.44931378564384283,0.8790374985140805,0.3898214122008547,0.6675537786814328,0.5085355089048774,0.4454174987254497,0.006266469508740191,0.7180429321977851,0.7670459256438553,0.651783556975088,0.6565697794292283,0.5376504568319638,0.4574369736626141,0.28638920473736407,0.5028661165493689,0.8326603424290081,0.17952403456861613,0.7274773978033486,0.42859586363905927,0.7085157545233863,0.20568856869292532,0.5693465742587844,0.5034422420528094,0.9009080692474105,0.13777514371507615,0.4871078639740247,0.2170270862194745,0.6690835875483784,0.3835366836923065,0.5260875552648081,0.7145665609164941,0.7622356439433351,0.256898169164969,0.5167072560318462,0.37238772853881913,0.21176849404182965,0.3570884139781243,0.7928027598163593,0.2632069130739772,0.5638629012589974,0.62667991174485,0.35660111712708964,0.337805765625278,0.5768091365055497,0.4658322959020708,0.7754670377276417,0.7871751446700895,0.39509450781332645,0.42703531786246235,0.6856612640188375,0.5593387736680957,0.12861167176615745,0.651284678747614,0.8867889565968607,0.5594875154588832,0.4326081736583103,0.6788475874745815,0.510636052227933,0.3859002352702982,0.43758201921451484,0.8550325710422679,0.5907137988525875,0.42179931848929575,0.6182294553862728,0.21728377584402567,0.31671444199530546,0.2622240439629714,0.3883046727706779,0.4523018886875211,0.8182375006568635,0.43309367370941704,0.07356067020449042,0.8764029275146705,0.6707908271840203,0.5878329508692572,0.23434494729439112,0.25876633382212216,0.5332561504933538,0.6505706726576815,0.6978388426777503,0.8751765679775968,0.6964366138893624,0.49714673323819925,0.4390134984338319,0.3706081060186885,0.6338609228657242,0.7618397943634078,0.44810173436769446,0.32466549841724035,0.014738104337967814,0.34822187064016563,0.6180153563450871,0.25937843210368355,0.24043984372654761,0.3451810016352063,0.30337140564146303,0.17699789901213275,0.6051882508374126,0.37507348473355595,0.7495572849740229,0.7106268413894079,0.4850507051728439,0.8514221020669225,0.5048020132447048,0.17743396243185067,0.6301227041720708,0.6200866052863462,0.1956204643491215,0.7710731504157251,0.8458135821758563,0.5985644739547227,0.37686218083089046,0.5008342945444857,0.7249121824073669,0.6277656575160098,0.9564087420034828,0.42091930483654755,0.6268218014615353,0.8834912863072185,0.0004072719444873302,0.642911896564152,0.5329057104081123,0.4021407240331482,0.4016712656772196,0.8074746819308689,0.8953123919280528,0.717088586823395,0.3185649993242489,0.6899260224655718,0.7362508636476812,0.36833004578891965,0.8010814415715746,0.21808878860540684,0.4409991471742692,0.653308244231644,0.5200235387316209,0.5018163516447947,0.5735981203934972,0.8109428641580553,0.28620078997995535,0.5855843530952799,0.09238113774550924,0.31086305052919483,0.10831624645503504,0.6757251420711579,0.3767405480752065,0.12481825518894532,0.0,0.6593906549121756,0.3337395622473997,0.27913978746429013,0.8636362988904436,0.4630528834970288,0.44135240790243374,0.6522806171755322,0.27905603083075564,0.010924079583337212,0.024692388236573402,0.7125408561767473,0.8045028091519743,0.8392903505932183,0.5988334756269038,0.9359267969716011,0.7531227867440443,0.7469397426983816,0.8934477193344548,0.3567440019403381,0.8907052237673692,0.8144674872146741,0.8199222308019513,0.8673087402297465,0.49699675212891453,0.4797842514091308,0.6423456766982111,0.6010403923593373,0.43197377845479096,0.5760663534786334,0.37618345634908607,0.3707113270994126,0.20315850054990733,0.5177148447912643],\"y\":[0.28967045807142405,0.49321589761667906,0.6114884559743814,0.28765897036398186,0.42038396057478256,0.24488037792617978,0.6555924748004226,0.637701616562345,0.40775345452754036,0.816696387794036,0.6386468337920613,0.08710036054342263,0.0,0.9830068707539786,0.1331731863459878,0.3756071601170002,0.5716356784561741,0.2678319918497413,0.7444164662901014,0.4710846877627917,0.46463118186664565,0.4049271448617068,0.18444928769237487,0.27420827225574895,0.30604823057945385,0.18221201116375585,0.5452245805654169,0.5756934843630539,0.5371251862374531,0.35537686614228586,0.691886326565762,0.24086342723742865,0.7890076050183971,0.7321686807058896,0.16173073020245696,0.9379828427440832,0.6085669803114362,0.012014781810010287,0.8321147999922618,0.5332065483951346,0.5633846671937589,0.2669192248469852,0.41747798898431937,0.16036723110733567,0.24484892440599748,0.19584745008425958,0.39723488268211155,0.5476713970682007,0.74877366793852,0.6355438452819554,0.45567894400574516,0.8129565908543038,0.7193167344323413,0.42664086597482787,0.6191203260359933,0.10224652605134109,0.16016274624505258,0.7995760532528451,0.12389046732526335,0.6831448909424619,0.7089756923612295,0.6026806938089542,0.7310000899182425,0.16852785115334742,0.13366888995334028,0.48090941535909565,0.42687603977834965,0.7164114852181838,0.5803926327104053,0.4388313367196233,0.7726065575391908,0.444027353342111,0.6017510295555455,0.09014206234609701,0.4393404746789394,0.002798961435541578,0.44720670796608125,0.15065641730078955,0.7088679714710461,0.5634640869349782,0.24019339361525108,0.3784550836111945,0.7452829125960218,0.24375376247989744,0.5140240042309399,0.6624697707834359,0.5283913703426419,0.3788913931950467,0.3698943178774708,0.5655243837424004,0.6177264302342022,0.18969589121840597,0.6958513172750607,0.4598101669700343,0.6586521543222597,0.5862690940697507,0.3744413623546023,0.2197776096402575,0.3642910540840711,0.7119263878031391,0.6904226612863027,0.38789225754056694,0.7462947759422153,0.8480644043231941,0.2030813546636055,0.6819393646825664,0.6210846640660135,0.27779010446024777,0.3872220465602767,0.2576482912815104,0.6797349754383587,0.20963739924688715,0.48453723694984574,0.15869576594179613,0.5354332583594661,0.1486026017777609,0.660432871437816,0.6318110145695137,0.15968467616016585,0.7345271082885712,0.36705657941491054,0.7045574966363791,0.657086202431473,0.8078391955329095,0.7595767097293317,0.32811574748523936,0.35091370069078043,0.15419286639427188,0.19933334488961252,0.6399926936563858,0.7357940507538124,0.5091876625107056,0.6745803882193274,0.5059293859544223,0.5704206344468208,0.468087975974438,0.532079273991722,0.24383610004311296,0.7474388513889462,0.608632763773559,0.5392331611303647,0.19731172210428197,0.6074850831813735,0.6383001874738673,0.35319012821601903,0.1680352984790842,0.637727285059424,0.3393929547320893,0.2694545569779559,0.7504090640510136,0.39651518609686176,0.5999866263324974,0.40258749171673497,0.5884439725024153,0.15031846957277747,0.4198032904377029,0.7612193446686886,0.4507684163240844,0.45250458946179123,0.8086494090192747,0.6279263550325983,0.831282443778007,0.18497468648403095,0.5457359122517992,0.24740263237564292,0.4030728953171881,0.35372947827716217,0.30898003112970135,0.3011411395091858,0.3461691993004907,0.5661247818553705,0.08797376753696164,0.6424909535271728,0.23966908896035619,0.4935214922361755,0.5681739762661152,0.5671348921371102,0.7117538031098491,0.630801416528471,0.5411998098354136,0.42047350559793945,0.12164262906037887,0.2851408486858898,0.3694577704292969,0.5197629058866543,0.4977491277771893,0.20835868980238664,0.05477044416658729,0.5464994824749025,0.4415399262979149,0.42462563666944586,0.4281253663696925,0.7237466047750631,0.4285635536904042,0.32830933898901904,0.37938243566997665,0.31595608407855186,0.7334027682174646,0.45743011437986236,0.7527254406328888,0.2500794065488848,0.48046567508521565,0.321680047850924,0.3951994930091709,0.1081767734249794,0.31762800862395507,0.5940705956617384,0.5782368882477646,0.18417900132468612,0.40545765038305975,0.7923960630635131,0.46542373082288824,0.7641417465286434,0.7113211289585225,0.6156320944435291,0.105211734290933,0.7392730165959559,0.30899557178097814,0.5586600444464479,0.5835240296844172,0.4525379216453794,0.6162626818062846,0.4926392468174273,0.32625936365022923,0.8830079150374622,0.48979672257253865,0.5269626819567745,0.9633874721979587,0.8682780812412808,0.35354765901276075,0.5342409109794203,0.6244488551073897,0.30113802493274033,0.7217819685043624,0.3811804114215997,0.6314946864402609,0.7580853182147079,0.6429307396691056,0.19715153275207803,0.13627939091125882,0.16969556638132585,0.7371297618622412,0.7976637782492555,0.25983621371186605,0.21223921744449123,0.5514117581134003,0.2545198557999168,0.29959065960548625,0.4435919918519365,0.479491914506478,0.649129723689199,0.6946543424032136,0.4644265933240915,0.4385303799398052,0.2866761446724974,0.32903756454915417,0.3248285503180051,0.5381327218855235,0.8554334126061353,0.1323325629683591,0.6852702632643184,0.5324797516965024,0.9970655067320642,0.7423330343043048,0.2717753269630601,0.5116991430043761,0.3015005471981137,0.6015546785961549,0.6598473043084586,0.5934927805921262,0.3377009970768298,0.20913385755198127,0.7487474820814098,0.9722576374189348,0.8528721121156967,0.7900187994632909,0.34976785016864254,0.4607304950314831,0.3814101792614075,0.8134193274559792,0.6034712410443259,0.4164583046415229,0.9463574822795291,0.628402889749191,0.17145904021242891,0.7879215815685586,0.8023112618661227,0.10182279050687786,0.30163224913901937,0.3682142606449557,0.8731475419437271,0.4665701285897894,0.3961863164628086,0.5146859906287252,0.4412738654608661,0.5973150253917375,0.11577436713543154,0.2961160615424195,0.4722671490732712,0.41254406548995315,0.7941581650806059,0.5644052729302718,0.19594640773543653,0.10193544041342725,0.33055713136062487,0.16408292422416088,0.35124935361294507,0.42195595902769334,0.7968717860750494,0.6580949110185261,0.6762104750895189,0.7146508825410139,0.22863153884520127,0.6855416614287914,0.3073870265835071,0.8370998501953743,0.7621605629428484,0.25737918638708507,0.33843500925763914,0.8045534864851885,0.6797909978021992,0.8223984231829917,0.7311120412458607,0.3054425167881268,0.4876032944294878,0.4633349136726842,0.21154712567125186,0.4452292275739381,0.37719691319932325,0.388417647624072,0.1125462696946161,0.2394744818775305,0.5993878107889014,0.41569664957548513,0.224994162377506,0.5943727764857878,0.70196767347563,0.5855399018260025,0.2627189451238526,0.3292708222451807,0.2242436061445224,0.060307632698421966,0.43293099809978064,0.32060758787424637,0.6741822813624635,0.40944090394725324,0.23747688018632296,0.45955818521324665,0.6865036503447209,0.08155316871340108,0.923372596923963,0.21337252010202712,0.6355543158364171,0.8315177459730111,0.20490598362692178,0.49224398292360866,0.3756304159096863,0.2402041690827045,0.7211525475839037,0.3560301340694253,0.7519820126003876,0.4058441348357288,0.13857379959444122,0.76402195296293,0.582176442627514,0.6980098944564919,0.5145525649499937,0.6344026112713228,0.5071788679257944,0.22008850143988615,0.5007766899277777,0.6535846371981258,0.30365752381793865,0.7002219082501343,0.290973142510098,0.6594916630702127,0.33364665792653025,0.35602008500293675,0.6891849194688708,0.29026007298482365,0.5750826143843594,0.13291619607318123,0.5162309872640686,0.3076447431098306,0.1394052277779232,0.798598861653098,0.3850658234158584,0.13390310266931893,0.4889075870448013,0.45967477884167124,0.7034586032808088,0.37439611908434434,0.04536084763174147,0.5586561342032628,0.5051474678294182,0.0839364307451562,0.6861984278986488,0.5191506485901891,0.24532755355273295,0.697774703423627,0.5034199838939876,0.22637531395393293,0.4081364148795204,0.17837135328717482,0.579640533495896,0.27007728591199187,0.3662196950547806,0.4806671826599098,0.5204616184970776,0.02602260530775652,0.8557571722218559,1.0,0.15956168335173848,0.27328737251276447,0.527730855490007,0.5505574055447559,0.2877245275031935,0.5435332140153116,0.3512865619336758,0.3529082566550165,0.13741285746048232,0.7131321290633202,0.47425440150618353,0.7455202993113186,0.1324193910282083,0.6713688656097923,0.5696401069015957,0.23709655038122238,0.6500322109180686,0.13948597135490573,0.3836060316311979,0.5552044611623879,0.6237727305021749,0.27600443680581555,0.4812389911319088,0.3336401440765844,0.5936053922055856,0.7332106471142972,0.9312095100973454,0.32365947792215594,0.20246350467293522,0.3975901164304786,0.6929474037593202,0.43351085519853894,0.5478678495498374,0.32447229181159315,0.7510563490127009,0.6143159256020416,0.48867307066228693,0.19792836219983753,0.3574758276477921,0.268006552837604,0.611776552412223,0.5351326715500055,0.4056395478047269,0.5210969333616969]}},\"id\":\"3f023844-1e56-4428-a551-094d91501d03\",\"type\":\"ColumnDataSource\"},{\"attributes\":{},\"id\":\"9720aeca-f949-4a69-a0d8-7d5eed928666\",\"type\":\"BasicTicker\"},{\"attributes\":{\"dimension\":1,\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"20197a57-7180-4dba-a3f8-12a57f1aedd1\",\"type\":\"BasicTicker\"}},\"id\":\"6f9bf602-63a5-4def-a45d-b8d7d5517b4e\",\"type\":\"Grid\"},{\"attributes\":{\"callback\":null},\"id\":\"1921560f-a905-489e-b6cf-761048d9142d\",\"type\":\"DataRange1d\"},{\"attributes\":{},\"id\":\"7dcaa794-a580-402c-992d-7e817bb11318\",\"type\":\"ToolEvents\"},{\"attributes\":{\"bottom_units\":\"screen\",\"fill_alpha\":{\"value\":0.5},\"fill_color\":{\"value\":\"lightgrey\"},\"left_units\":\"screen\",\"level\":\"overlay\",\"line_alpha\":{\"value\":1.0},\"line_color\":{\"value\":\"black\"},\"line_dash\":[4,4],\"line_width\":{\"value\":2},\"plot\":null,\"render_mode\":\"css\",\"right_units\":\"screen\",\"top_units\":\"screen\"},\"id\":\"e291121b-79c6-40c5-b081-7371926c685a\",\"type\":\"BoxAnnotation\"},{\"attributes\":{},\"id\":\"f26e124b-b0b4-493f-b007-5e80685078a5\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"callback\":null},\"id\":\"ab1e5802-a479-4dbc-958f-520d5c45c00b\",\"type\":\"DataRange1d\"},{\"attributes\":{\"data_source\":{\"id\":\"ab0d71df-1008-4bd0-8ee8-b60394cda912\",\"type\":\"ColumnDataSource\"},\"glyph\":{\"id\":\"48a529e0-49c1-4985-8d95-028503b36abd\",\"type\":\"MultiLine\"},\"hover_glyph\":null,\"nonselection_glyph\":{\"id\":\"1a1f89ff-65f0-49a4-a490-2938aca9f648\",\"type\":\"MultiLine\"},\"selection_glyph\":null},\"id\":\"e3d2f80f-e634-437c-966b-6896c28eaf44\",\"type\":\"GlyphRenderer\"},{\"attributes\":{\"active_drag\":\"auto\",\"active_scroll\":\"auto\",\"active_tap\":\"auto\",\"tools\":[{\"id\":\"145c024b-5fa5-4086-871c-cd25f1d1ac7a\",\"type\":\"HoverTool\"},{\"id\":\"dee07948-35c4-4872-a632-62aedee74dcf\",\"type\":\"TapTool\"},{\"id\":\"60156367-73d9-4892-8324-eaa5c2ee576f\",\"type\":\"BoxZoomTool\"},{\"id\":\"5adc6f1b-6f56-486a-9aee-20ea3f45dd55\",\"type\":\"ResetTool\"}]},\"id\":\"f8b07d79-31cc-41d8-87c7-02367bbe3be0\",\"type\":\"Toolbar\"},{\"attributes\":{\"below\":[{\"id\":\"e43c1d7a-7174-4725-a05c-aecb2ecf6c29\",\"type\":\"LinearAxis\"}],\"left\":[{\"id\":\"c82cd6a8-c815-4d2a-848e-1e6052945a3c\",\"type\":\"LinearAxis\"}],\"plot_height\":400,\"plot_width\":800,\"renderers\":[{\"id\":\"e43c1d7a-7174-4725-a05c-aecb2ecf6c29\",\"type\":\"LinearAxis\"},{\"id\":\"7cddbcbd-7485-449e-9f4f-5bd9d4f56156\",\"type\":\"Grid\"},{\"id\":\"c82cd6a8-c815-4d2a-848e-1e6052945a3c\",\"type\":\"LinearAxis\"},{\"id\":\"6f9bf602-63a5-4def-a45d-b8d7d5517b4e\",\"type\":\"Grid\"},{\"id\":\"e291121b-79c6-40c5-b081-7371926c685a\",\"type\":\"BoxAnnotation\"},{\"id\":\"05c6bf18-f6a1-476c-b604-f3a5412b4df2\",\"type\":\"GlyphRenderer\"},{\"id\":\"e3d2f80f-e634-437c-966b-6896c28eaf44\",\"type\":\"GlyphRenderer\"}],\"title\":{\"id\":\"800ff3d4-6e8f-4a0b-87a3-6bc5122f7678\",\"type\":\"Title\"},\"tool_events\":{\"id\":\"7dcaa794-a580-402c-992d-7e817bb11318\",\"type\":\"ToolEvents\"},\"toolbar\":{\"id\":\"f8b07d79-31cc-41d8-87c7-02367bbe3be0\",\"type\":\"Toolbar\"},\"x_range\":{\"id\":\"ab1e5802-a479-4dbc-958f-520d5c45c00b\",\"type\":\"DataRange1d\"},\"y_range\":{\"id\":\"1921560f-a905-489e-b6cf-761048d9142d\",\"type\":\"DataRange1d\"}},\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{\"fill_color\":{\"value\":\"blue\"},\"line_color\":{\"value\":\"blue\"},\"size\":{\"units\":\"screen\",\"value\":10},\"x\":{\"field\":\"x\"},\"y\":{\"field\":\"y\"}},\"id\":\"3d9732c3-0763-417f-86b3-6c19897b1851\",\"type\":\"Circle\"},{\"attributes\":{},\"id\":\"20197a57-7180-4dba-a3f8-12a57f1aedd1\",\"type\":\"BasicTicker\"},{\"attributes\":{\"data_source\":{\"id\":\"3f023844-1e56-4428-a551-094d91501d03\",\"type\":\"ColumnDataSource\"},\"glyph\":{\"id\":\"3d9732c3-0763-417f-86b3-6c19897b1851\",\"type\":\"Circle\"},\"hover_glyph\":null,\"level\":\"overlay\",\"nonselection_glyph\":{\"id\":\"a911e458-c64f-494c-8954-4b6214d3349f\",\"type\":\"Circle\"},\"selection_glyph\":null},\"id\":\"05c6bf18-f6a1-476c-b604-f3a5412b4df2\",\"type\":\"GlyphRenderer\"},{\"attributes\":{\"fill_alpha\":{\"value\":0.1},\"fill_color\":{\"value\":\"#1f77b4\"},\"line_alpha\":{\"value\":0.1},\"line_color\":{\"value\":\"#1f77b4\"},\"size\":{\"units\":\"screen\",\"value\":10},\"x\":{\"field\":\"x\"},\"y\":{\"field\":\"y\"}},\"id\":\"a911e458-c64f-494c-8954-4b6214d3349f\",\"type\":\"Circle\"},{\"attributes\":{\"callback\":null,\"column_names\":[\"ys\",\"alphas\",\"xs\"],\"data\":{\"alphas\":[0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.22,0.12000000000000001,0.2,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.18,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.22,0.16,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.3,0.12000000000000001,0.22,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.45999999999999996,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.18,0.18,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.24,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.24,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.18,0.12000000000000001,0.14,0.16,0.24,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.31999999999999995,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.2,0.12000000000000001,0.14,0.2,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.14,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.22,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.16,0.12000000000000001,0.16,0.12000000000000001,0.16,0.14,0.16,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.26,0.2,0.26,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.24,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.7,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.18,0.12000000000000001,0.16,0.12000000000000001,0.36,0.36,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.16,0.14,0.16,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.16,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.18,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.26,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.64,0.12000000000000001,0.14,0.12000000000000001,0.26,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.33999999999999997,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.2,0.18,0.14,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.16,0.12000000000000001,0.18,0.14,0.12000000000000001,0.16,0.12000000000000001,0.14,0.14,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.22,0.12000000000000001,0.16,0.12000000000000001,0.18,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.26,0.18,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.16,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.22,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.14,0.18,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.18,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.22,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.28,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.33999999999999997,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.14,0.12000000000000001,0.18,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.24,0.12000000000000001,0.18,0.12000000000000001,0.14,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.22,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.38,0.22,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.31999999999999995,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.2,0.14,0.16,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.22,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.16,0.14,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.33999999999999997,0.14,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.14,0.3,0.12000000000000001,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.22,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.28,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001],\"xs\":[[0.3354796280607799,0.37238772853881913],[0.3354796280607799,0.4529860888516215],[0.3354796280607799,0.4454174987254497],[0.3354796280607799,0.4184581518441556],[0.3354796280607799,0.4797842514091308],[0.8345012133036179,0.5273702911813317],[0.9359267969716011,0.8420677510419282],[0.9359267969716011,0.7680466001592029],[0.10861525817488801,0.3859002352702982],[0.5638629012589974,0.5273702911813317],[0.5638629012589974,0.5260875552648081],[0.27913978746429013,0.21176849404182965],[0.27913978746429013,0.2949650517770683],[0.27913978746429013,0.5273702911813317],[0.7145665609164941,0.5273702911813317],[0.3696102306509866,0.3859002352702982],[0.3696102306509866,0.30337140564146303],[0.3696102306509866,0.19349604237479048],[0.3696102306509866,0.5273702911813317],[0.3696102306509866,0.2668432841062252],[0.3696102306509866,0.3883046727706779],[0.3696102306509866,0.3696102306509866],[0.5992223660595205,0.5273702911813317],[0.5992223660595205,0.6591189655369051],[0.5992223660595205,0.6268508164927742],[0.6010403923593373,0.5273702911813317],[0.6010403923593373,0.5760663534786334],[0.6010403923593373,0.5966708414632891],[0.6010403923593373,0.642911896564152],[0.19349604237479048,0.3883046727706779],[0.4326081736583103,0.5273702911813317],[0.6051882508374126,0.6182294553862728],[0.6051882508374126,0.5273702911813317],[0.1843789805922721,0.2753690782443153],[0.1843789805922721,0.29134409322657606],[0.1843789805922721,0.32725306453715725],[0.31086305052919483,0.42859586363905927],[0.31086305052919483,0.5273702911813317],[0.31086305052919483,0.4021407240331482],[0.337805765625278,0.5273702911813317],[0.337805765625278,0.38529607741643523],[0.3296525707818188,0.3859002352702982],[0.3296525707818188,0.28258678170836293],[0.3296525707818188,0.2743397678659176],[0.3296525707818188,0.5177148447912643],[0.3296525707818188,0.4797842514091308],[0.8420677510419282,0.7680466001592029],[0.8420677510419282,0.5273702911813317],[0.38529607741643523,0.3859002352702982],[0.38529607741643523,0.21718748780794514],[0.38529607741643523,0.5273702911813317],[0.17743396243185067,0.05119568519436346],[0.17743396243185067,0.07356067020449042],[0.17743396243185067,0.5273702911813317],[0.8953123919280528,0.8751765679775968],[0.8953123919280528,0.5273702911813317],[0.006266469508740191,0.1322454057651943],[0.31671444199530546,0.36833004578891965],[0.31671444199530546,0.5273702911813317],[0.2984755496377469,0.42859586363905927],[0.2984755496377469,0.4409991471742692],[0.2984755496377469,0.3707113270994126],[0.2984755496377469,0.4077105934103404],[0.5735981203934972,0.5760663534786334],[0.5735981203934972,0.6080051629526841],[0.5735981203934972,0.5273702911813317],[0.5735981203934972,0.5878329508692572],[0.3185649993242489,0.10831624645503504],[0.3185649993242489,0.5273702911813317],[0.3185649993242489,0.2284611938858925],[0.4765462912646269,0.46725188988062477],[0.4765462912646269,0.5273702911813317],[0.4765462912646269,0.4797842514091308],[0.2991927802544625,0.5273702911813317],[0.5018163516447947,0.5200235387316209],[0.5018163516447947,0.544539004263694],[0.4630528834970288,0.47738724885640027],[0.4630528834970288,0.4907090195063411],[0.4630528834970288,0.4864261770589082],[0.4630528834970288,0.5273702911813317],[0.3959163596851933,0.07346649337272483],[0.3959163596851933,0.5096609465005195],[0.3959163596851933,0.5273702911813317],[0.3959163596851933,0.46232631932681983],[0.3959163596851933,0.396558598150051],[0.3959163596851933,0.4077105934103404],[0.43758201921451484,0.4864261770589082],[0.43758201921451484,0.5273702911813317],[0.28437605693851287,0.34822187064016563],[0.28437605693851287,0.4454174987254497],[0.28437605693851287,0.3570884139781243],[0.6473208358041451,0.5273702911813317],[0.6473208358041451,0.5448191465475354],[0.6690835875483784,0.6788475874745815],[0.6690835875483784,0.5273702911813317],[0.22900430309695666,0.30337140564146303],[0.22900430309695666,0.5273702911813317],[0.6338609228657242,0.6183173145362721],[0.6338609228657242,0.5273702911813317],[0.6338609228657242,0.6593906549121756],[0.8560536118270783,0.5273702911813317],[0.43309367370941704,0.3859002352702982],[0.43309367370941704,0.4864261770589082],[0.43309367370941704,0.5273702911813317],[0.43309367370941704,0.43197377845479096],[0.43309367370941704,0.3258229314629499],[0.43309367370941704,0.43309367370941704],[0.43309367370941704,0.34790904717371385],[0.43309367370941704,0.4239438713479811],[0.7404431308269849,0.5273702911813317],[0.7998254358498652,0.7618397943634078],[0.7998254358498652,0.6768329005466855],[0.7998254358498652,0.5273702911813317],[0.6154578014735469,0.5760663534786334],[0.6154578014735469,0.6080051629526841],[0.6154578014735469,0.5273702911813317],[0.6154578014735469,0.5878329508692572],[0.49425476008554386,0.46725188988062477],[0.49425476008554386,0.5273702911813317],[0.49425476008554386,0.4797842514091308],[0.45401224027153125,0.46725188988062477],[0.45401224027153125,0.5273702911813317],[0.45401224027153125,0.4797842514091308],[0.5008342945444857,0.5273702911813317],[0.6107355293327792,0.5988334756269038],[0.6107355293327792,0.6107355293327792],[0.6107355293327792,0.5273702911813317],[0.6107355293327792,0.6301227041720708],[0.6107355293327792,0.6986026475011937],[0.6107355293327792,0.6831222541558417],[0.6107355293327792,0.5855843530952799],[0.6107355293327792,0.6074710587608619],[0.6107355293327792,0.6591189655369051],[0.5819844791493612,0.3859002352702982],[0.5819844791493612,0.7560820530487513],[0.5819844791493612,0.5273702911813317],[0.3679874628262692,0.5096609465005195],[0.3679874628262692,0.5273702911813317],[0.3679874628262692,0.4077105934103404],[0.8199222308019513,0.5273702911813317],[0.8199222308019513,0.7328624564696022],[0.24820547587082087,0.14722407149633063],[0.24820547587082087,0.5273702911813317],[0.3835366836923065,0.47738724885640027],[0.3835366836923065,0.4864261770589082],[0.6505706726576815,0.5273702911813317],[0.6505706726576815,0.6629041068383162],[0.6505706726576815,0.62667991174485],[0.8168057606613124,0.5273702911813317],[0.8168057606613124,0.7328624564696022],[0.17952403456861613,0.18531482750887057],[0.17952403456861613,0.1893636514025236],[0.17952403456861613,0.5273702911813317],[0.8882892913147034,0.7847822765559535],[0.8882892913147034,0.7680466001592029],[0.8882892913147034,0.7344383643704192],[0.8882892913147034,0.7138964428690399],[0.5790707889827418,0.5273702911813317],[0.5790707889827418,0.5560658847433289],[0.27905603083075564,0.3859002352702982],[0.27905603083075564,0.16720049055701025],[0.27905603083075564,0.5273702911813317],[0.6423456766982111,0.5273702911813317],[0.4449409251161033,0.4530764629204581],[0.4449409251161033,0.46725188988062477],[0.4449409251161033,0.5273702911813317],[0.4322559884048272,0.4409991471742692],[0.4322559884048272,0.34599043477666275],[0.4322559884048272,0.5273702911813317],[0.4322559884048272,0.4077105934103404],[0.4322559884048272,0.42859586363905927],[0.4322559884048272,0.46741740038951296],[0.4322559884048272,0.3474967582324662],[0.4322559884048272,0.4021407240331482],[0.3707113270994126,0.42859586363905927],[0.3707113270994126,0.5273702911813317],[0.3707113270994126,0.4077105934103404],[0.6433428028976722,0.7125408561767473],[0.6433428028976722,0.8934477193344548],[0.6433428028976722,0.5273702911813317],[0.4460363754868059,0.5273702911813317],[0.4460363754868059,0.4232741731428999],[0.4562184002572107,0.5273702911813317],[0.30337140564146303,0.24043984372654761],[0.30337140564146303,0.42091930483654755],[0.30337140564146303,0.4189157068812568],[0.30337140564146303,0.42295945765243814],[0.30337140564146303,0.30337140564146303],[0.30337140564146303,0.014738104337967814],[0.30337140564146303,0.018422355054930853],[0.30337140564146303,0.5273702911813317],[0.30337140564146303,0.024692388236573402],[0.30337140564146303,0.01734191341632451],[0.30337140564146303,0.3883046727706779],[0.5277819773456729,0.5273702911813317],[0.5277819773456729,0.5260875552648081],[0.46562646714640893,0.5267863645195076],[0.7037922615792445,0.7131000611151268],[0.7037922615792445,0.5273702911813317],[0.43197377845479096,0.3859002352702982],[0.43197377845479096,0.36833004578891965],[0.43197377845479096,0.5273702911813317],[0.5972718337639362,0.6277876734099467],[0.5972718337639362,0.5096609465005195],[0.5972718337639362,0.5273702911813317],[0.5972718337639362,0.5972718337639362],[0.5972718337639362,0.6403023207536772],[0.5972718337639362,0.5907137988525875],[0.4797842514091308,0.46301048244358173],[0.4797842514091308,0.4797842514091308],[0.4797842514091308,0.37238772853881913],[0.4797842514091308,0.5332561504933538],[0.4797842514091308,0.4977382956718392],[0.4797842514091308,0.4454174987254497],[0.4797842514091308,0.39509450781332645],[0.4797842514091308,0.49699675212891453],[0.4797842514091308,0.44135240790243374],[0.4797842514091308,0.4390134984338319],[0.4797842514091308,0.5503692923694219],[0.4797842514091308,0.5048020132447048],[0.4797842514091308,0.510636052227933],[0.4797842514091308,0.559419831092162],[0.4797842514091308,0.4082859360018825],[0.4797842514091308,0.4133296998103043],[0.4797842514091308,0.5124618527636177],[0.4797842514091308,0.3859002352702982],[0.4797842514091308,0.567920962016376],[0.4797842514091308,0.5359688794021277],[0.4797842514091308,0.46608893696390463],[0.4797842514091308,0.40167020169332],[0.4797842514091308,0.48632283686369515],[0.4797842514091308,0.43136066141760676],[0.4797842514091308,0.5250628515459467],[0.4797842514091308,0.5475352476810662],[0.4797842514091308,0.5329057104081123],[0.4797842514091308,0.4184581518441556],[0.4797842514091308,0.5113462489571763],[0.4797842514091308,0.46725188988062477],[0.4797842514091308,0.5313109656023342],[0.4797842514091308,0.43175051267272974],[0.4797842514091308,0.5273702911813317],[0.42677214100651073,0.4530764629204581],[0.42677214100651073,0.46725188988062477],[0.42677214100651073,0.5273702911813317],[0.6788475874745815,0.717088586823395],[0.6788475874745815,0.7409999722997533],[0.6788475874745815,0.5273702911813317],[0.6788475874745815,0.6899260224655718],[0.6788475874745815,0.723708267997975],[0.6788475874745815,0.6978388426777503],[0.6788475874745815,0.5768091365055497],[0.6788475874745815,0.6685489782327163],[0.761224114805333,0.6277876734099467],[0.761224114805333,0.6649554871730126],[0.761224114805333,0.6403023207536772],[0.723708267997975,0.5273702911813317],[0.37686218083089046,0.3859002352702982],[0.37686218083089046,0.37686218083089046],[0.37686218083089046,0.5273702911813317],[0.37686218083089046,0.3567440019403381],[0.40246340244580703,0.42859586363905927],[0.40246340244580703,0.46741740038951296],[0.40246340244580703,0.5273702911813317],[0.40246340244580703,0.4077105934103404],[0.841436009225072,0.7560820530487513],[0.841436009225072,0.5273702911813317],[0.46301048244358173,0.36366893746276097],[0.46301048244358173,0.5273702911813317],[0.46301048244358173,0.5359688794021277],[0.46301048244358173,0.510636052227933],[0.46301048244358173,0.46725188988062477],[0.46301048244358173,0.4454174987254497],[0.46301048244358173,0.44135240790243374],[0.47242041926269346,0.5273702911813317],[0.8144674872146741,0.5273702911813317],[0.8144674872146741,0.7085157545233863],[0.4133296998103043,0.46725188988062477],[0.4133296998103043,0.5273702911813317],[0.8907052237673692,0.6649554871730126],[0.8907052237673692,0.7362508636476812],[0.4189157068812568,0.2668432841062252],[0.4189157068812568,0.5273702911813317],[0.6856612640188375,0.6080309874401345],[0.6856612640188375,0.6277656575160098],[0.6856612640188375,0.8045028091519743],[0.6856612640188375,0.5273702911813317],[0.18531482750887057,0.5273702911813317],[0.834430925358825,0.5273702911813317],[0.834430925358825,0.7328624564696022],[0.7409999722997533,0.5273702911813317],[0.6707908271840203,0.5855843530952799],[0.6707908271840203,0.5273702911813317],[0.7249121824073669,0.5273702911813317],[0.7249121824073669,0.7994834301821617],[0.4850450724209578,0.4530764629204581],[0.4850450724209578,0.46725188988062477],[0.4850450724209578,0.5273702911813317],[0.651783556975088,0.6182294553862728],[0.651783556975088,0.6861337059886096],[0.651783556975088,0.5273702911813317],[0.8245584052983008,0.7670459256438553],[0.8245584052983008,0.5273702911813317],[0.0,0.1322454057651943],[0.680297843895486,0.5855843530952799],[0.680297843895486,0.5273702911813317],[0.7749704651885716,0.5273702911813317],[0.7749704651885716,0.7388205894069465],[0.32725306453715725,0.2753690782443153],[0.32725306453715725,0.5273702911813317],[0.32725306453715725,0.29134409322657606],[0.8931697215832224,0.5273702911813317],[0.18139172755563043,0.3859002352702982],[0.18139172755563043,0.3567440019403381],[0.6277876734099467,0.5096609465005195],[0.6277876734099467,0.5273702911813317],[0.6277876734099467,0.6403023207536772],[0.6277876734099467,0.6649554871730126],[0.6277876734099467,0.5907137988525875],[0.6277876734099467,0.6520292797891475],[0.6277876734099467,0.7483810189890286],[0.717088586823395,0.5273702911813317],[0.8834912863072185,0.5273702911813317],[0.46608893696390463,0.46725188988062477],[0.46608893696390463,0.5273702911813317],[0.12861167176615745,0.3859002352702982],[0.7791414891415637,0.5273702911813317],[0.7791414891415637,0.6675537786814328],[0.37507348473355595,0.46725188988062477],[0.37507348473355595,0.5273702911813317],[0.37507348473355595,0.23434494729439112],[0.17512726011751575,0.0666376520597208],[0.17512726011751575,0.15719524760500456],[0.17512726011751575,0.1608098361767725],[0.17512726011751575,0.5273702911813317],[0.17512726011751575,0.17699789901213275],[0.17512726011751575,0.05440411351733689],[0.2408523952121474,0.5273702911813317],[0.6250611858264904,0.5649709653000902],[0.6250611858264904,0.5273702911813317],[0.6250611858264904,0.5966708414632891],[0.6250611858264904,0.5760663534786334],[0.4977382956718392,0.510636052227933],[0.4977382956718392,0.46725188988062477],[0.4977382956718392,0.5273702911813317],[0.4574369736626141,0.5273702911813317],[0.7274773978033486,0.9677721505314865],[0.7274773978033486,0.5273702911813317],[0.7274773978033486,0.6964366138893624],[0.4239438713479811,0.3859002352702982],[0.4239438713479811,0.4864261770589082],[0.4239438713479811,0.5273702911813317],[0.4239438713479811,0.2668432841062252],[0.4239438713479811,0.21176849404182965],[0.4239438713479811,0.2949650517770683],[0.4239438713479811,0.6675537786814328],[0.39925818847095174,0.20442646732631017],[0.39925818847095174,0.5273702911813317],[0.5988334756269038,0.5855843530952799],[0.5988334756269038,0.6074710587608619],[0.5988334756269038,0.5273702911813317],[0.5988334756269038,0.6591189655369051],[0.5761766725749653,0.5273702911813317],[0.5761766725749653,0.5177148447912643],[0.5761766725749653,0.5855843530952799],[0.5761766725749653,0.6074710587608619],[0.5761766725749653,0.6591189655369051],[0.5761766725749653,0.5529824335702461],[0.20568856869292532,0.46725188988062477],[0.20568856869292532,0.012345996632333186],[0.20568856869292532,0.5273702911813317],[0.20568856869292532,0.010924079583337212],[0.6861337059886096,0.6182294553862728],[0.6861337059886096,0.5760663534786334],[0.6899260224655718,0.5273702911813317],[0.22319313083257478,0.5273702911813317],[0.34948677156023716,0.5273702911813317],[0.6183173145362721,0.6593906549121756],[0.6183173145362721,0.5273702911813317],[0.6183173145362721,0.7180429321977851],[0.7761786220296911,0.8326603424290081],[0.7761786220296911,0.5273702911813317],[0.6329493711757243,0.5273702911813317],[0.812997251330952,0.812997251330952],[0.812997251330952,0.7928027598163593],[0.812997251330952,0.5273702911813317],[0.1608098361767725,0.0666376520597208],[0.1608098361767725,0.15719524760500456],[0.1608098361767725,0.5273702911813317],[0.1608098361767725,0.17699789901213275],[0.1608098361767725,0.05440411351733689],[0.5217992519770993,0.5273702911813317],[0.8751765679775968,0.5273702911813317],[0.32306974830188095,0.3738634677907164],[0.32306974830188095,0.5273702911813317],[0.642911896564152,0.5760663534786334],[0.642911896564152,0.5966708414632891],[0.16720049055701025,0.3859002352702982],[0.16720049055701025,0.3898214122008547],[0.4409991471742692,0.4409991471742692],[0.4409991471742692,0.34599043477666275],[0.4409991471742692,0.5273702911813317],[0.4409991471742692,0.4077105934103404],[0.4409991471742692,0.42859586363905927],[0.4409991471742692,0.46741740038951296],[0.4409991471742692,0.3474967582324662],[0.4409991471742692,0.4021407240331482],[0.24092592363167847,0.5273702911813317],[0.653308244231644,0.5760663534786334],[0.27087086409615146,0.3859002352702982],[0.27087086409615146,0.5273702911813317],[0.5376504568319638,0.4530764629204581],[0.5376504568319638,0.46725188988062477],[0.5376504568319638,0.5273702911813317],[0.3859002352702982,0.15719524760500456],[0.3859002352702982,0.2580476450823534],[0.3859002352702982,0.2570141524214476],[0.3859002352702982,0.34790904717371385],[0.3859002352702982,0.09238113774550924],[0.3859002352702982,0.21718748780794514],[0.3859002352702982,0.3258229314629499],[0.3859002352702982,0.4715396132256285],[0.3859002352702982,0.28258678170836293],[0.3859002352702982,0.5177148447912643],[0.3859002352702982,0.37618345634908607],[0.3859002352702982,0.2981618960890701],[0.3859002352702982,0.3567440019403381],[0.3859002352702982,0.42295945765243814],[0.3859002352702982,0.28311721776637655],[0.3859002352702982,0.32937314578834825],[0.3859002352702982,0.5169218248929459],[0.3859002352702982,0.5273702911813317],[0.3859002352702982,0.2743397678659176],[0.3859002352702982,0.3093605027419721],[0.3859002352702982,0.28638920473736407],[0.2941857964504337,0.5273702911813317],[0.4077105934103404,0.396558598150051],[0.4077105934103404,0.5096609465005195],[0.4077105934103404,0.3474967582324662],[0.4077105934103404,0.34599043477666275],[0.4077105934103404,0.3898214122008547],[0.4077105934103404,0.1517748264614068],[0.4077105934103404,0.42859586363905927],[0.4077105934103404,0.5273702911813317],[0.4077105934103404,0.46741740038951296],[0.4077105934103404,0.12481825518894532],[0.2570141524214476,0.5273702911813317],[0.271838772675641,0.5273702911813317],[0.7680466001592029,0.7847822765559535],[0.7680466001592029,0.5273702911813317],[0.7680466001592029,0.7344383643704192],[0.7680466001592029,0.7138964428690399],[0.4021407240331482,0.42859586363905927],[0.4021407240331482,0.5273702911813317],[0.4021407240331482,0.396558598150051],[0.3474967582324662,0.3898214122008547],[0.3474967582324662,0.2879879844646292],[0.3474967582324662,0.42859586363905927],[0.3474967582324662,0.28620078997995535],[0.42703531786246235,0.5273702911813317],[0.62667991174485,0.5273702911813317],[0.62667991174485,0.6629041068383162],[0.559419831092162,0.46725188988062477],[0.559419831092162,0.5273702911813317],[0.6527603423114108,0.7452906139267168],[0.6527603423114108,0.6717153141828879],[0.6527603423114108,0.5273702911813317],[0.6527603423114108,0.6527603423114108],[0.6527603423114108,0.7560820530487513],[0.6527603423114108,0.567920962016376],[0.2981618960890701,0.5273702911813317],[0.8438595465067269,0.7560820530487513],[0.8438595465067269,0.5273702911813317],[0.8392903505932183,0.5273702911813317],[0.8324764569733091,0.5273702911813317],[0.8324764569733091,0.7328624564696022],[0.7916796401593695,0.5273702911813317],[0.7916796401593695,0.6675537786814328],[0.3350585537496382,0.21176849404182965],[0.3350585537496382,0.2949650517770683],[0.3350585537496382,0.5273702911813317],[0.6403023207536772,0.7670459256438553],[0.6403023207536772,0.5096609465005195],[0.6403023207536772,0.5273702911813317],[0.6403023207536772,0.6520292797891475],[0.6403023207536772,0.6649554871730126],[0.6403023207536772,0.7483810189890286],[0.430521278698538,0.47738724885640027],[0.430521278698538,0.4864261770589082],[0.430521278698538,0.5273702911813317],[0.39436003118292895,0.4454174987254497],[0.39436003118292895,0.39436003118292895],[0.39436003118292895,0.5273702911813317],[0.48540992073820394,0.5273702911813317],[0.5475352476810662,0.46725188988062477],[0.5475352476810662,0.5273702911813317],[0.4184581518441556,0.4184581518441556],[0.4184581518441556,0.4454174987254497],[0.4184581518441556,0.37238772853881913],[0.4184581518441556,0.5273702911813317],[0.8639999622738026,0.5273702911813317],[0.8639999622738026,0.9564087420034828],[0.6675537786814328,0.5594875154588832],[0.6675537786814328,0.7622356439433351],[0.6675537786814328,0.6649554871730126],[0.6675537786814328,0.5260875552648081],[0.6675537786814328,0.7710731504157251],[0.6675537786814328,0.651284678747614],[0.6675537786814328,0.7469397426983816],[0.6675537786814328,0.8010814415715746],[0.6675537786814328,0.6757251420711579],[0.6675537786814328,0.7272638538465169],[0.6675537786814328,0.7495572849740229],[0.6675537786814328,0.5448191465475354],[0.6675537786814328,0.5273702911813317],[0.7928027598163593,0.5273702911813317],[0.7531227867440443,0.7042899634519145],[0.7622356439433351,0.5273702911813317],[0.34790904717371385,0.5273702911813317],[0.8366710372490394,0.5273702911813317],[0.4530764629204581,0.5167072560318462],[0.4530764629204581,0.44931378564384283],[0.4530764629204581,0.40997393568107054],[0.4530764629204581,0.4658322959020708],[0.4530764629204581,0.4871078639740247],[0.4530764629204581,0.46725188988062477],[0.4530764629204581,0.5085355089048774],[0.877096902978967,0.5273702911813317],[0.3738634677907164,0.3962128954605851],[0.3738634677907164,0.40731554504571377],[0.3738634677907164,0.35594095814264237],[0.3738634677907164,0.36329127930353833],[0.3738634677907164,0.339490529991326],[0.3738634677907164,0.3767405480752065],[0.3738634677907164,0.5273702911813317],[0.8550325710422679,0.5273702911813317],[0.5855843530952799,0.6401117262934481],[0.5855843530952799,0.6968954957038507],[0.5855843530952799,0.7167019153870717],[0.5855843530952799,0.6831222541558417],[0.5855843530952799,0.7871751446700895],[0.5855843530952799,0.7106268413894079],[0.5855843530952799,0.5594875154588832],[0.5855843530952799,0.6180153563450871],[0.5855843530952799,0.6301227041720708],[0.5855843530952799,0.5177148447912643],[0.5855843530952799,0.6986026475011937],[0.5855843530952799,0.6649554871730126],[0.5855843530952799,0.7243670816727983],[0.5855843530952799,0.4864261770589082],[0.5855843530952799,0.5273702911813317],[0.5855843530952799,0.46725188988062477],[0.5855843530952799,0.6074710587608619],[0.5855843530952799,0.6591189655369051],[0.5855843530952799,0.5529824335702461],[0.4715396132256285,0.5273702911813317],[0.4715396132256285,0.5768091365055497],[0.7483810189890286,0.6649554871730126],[0.7670459256438553,0.8189600654341986],[0.7670459256438553,0.6925271287281928],[0.7670459256438553,0.5273702911813317],[0.7670459256438553,0.7935304655073256],[0.7670459256438553,0.8105537647772262],[0.7670459256438553,0.7754670377276417],[0.6182294553862728,0.5273702911813317],[0.6182294553862728,0.5760663534786334],[0.8182375006568635,0.5273702911813317],[0.5200235387316209,0.544539004263694],[0.5200235387316209,0.5273702911813317],[0.396558598150051,0.5273702911813317],[0.396558598150051,0.46232631932681983],[0.396558598150051,0.42859586363905927],[0.8999153118864638,0.5273702911813317],[0.40167020169332,0.46725188988062477],[0.40167020169332,0.5273702911813317],[0.5760663534786334,0.5649709653000902],[0.5760663534786334,0.4864261770589082],[0.5760663534786334,0.5946504680499989],[0.5760663534786334,0.5169218248929459],[0.5760663534786334,0.5878329508692572],[0.5760663534786334,0.5966708414632891],[0.5760663534786334,0.5447150666945445],[0.5760663534786334,0.4850507051728439],[0.5760663534786334,0.6080051629526841],[0.5760663534786334,0.5273702911813317],[0.5760663534786334,0.5987207378759382],[0.5760663534786334,0.6268218014615353],[0.36366893746276097,0.4454174987254497],[0.36366893746276097,0.44135240790243374],[0.5028661165493689,0.5594875154588832],[0.5028661165493689,0.4864261770589082],[0.5028661165493689,0.49714673323819925],[0.5028661165493689,0.49592377787927816],[0.5028661165493689,0.5273702911813317],[0.5028661165493689,0.46232631932681983],[0.5028661165493689,0.5034422420528094],[0.5028661165493689,0.5260875552648081],[0.5028661165493689,0.42091930483654755],[0.339490529991326,0.5273702911813317],[0.43175051267272974,0.46725188988062477],[0.43175051267272974,0.44135240790243374],[0.43175051267272974,0.5273702911813317],[0.44931378564384283,0.46725188988062477],[0.44931378564384283,0.5273702911813317],[0.5034422420528094,0.5594875154588832],[0.5034422420528094,0.49714673323819925],[0.5034422420528094,0.5273702911813317],[0.5034422420528094,0.5260875552648081],[0.5034422420528094,0.42091930483654755],[0.10831624645503504,0.2284611938858925],[0.40731554504571377,0.5273702911813317],[0.6964366138893624,0.5273702911813317],[0.5768091365055497,0.5273702911813317],[0.651284678747614,0.7866984440999546],[0.651284678747614,0.5273702911813317],[0.5350126454523644,0.4864261770589082],[0.5350126454523644,0.4850507051728439],[0.5350126454523644,0.5273702911813317],[0.003015380849707185,0.13777514371507615],[0.6167832479852217,0.596605921943523],[0.6167832479852217,0.5273702911813317],[0.6122920872296445,0.5273702911813317],[0.28258678170836293,0.5273702911813317],[0.21728377584402567,0.5273702911813317],[0.7495572849740229,0.5273702911813317],[0.7847822765559535,0.7847822765559535],[0.7847822765559535,0.5273702911813317],[0.7847822765559535,0.7344383643704192],[0.7847822765559535,0.7138964428690399],[0.24043984372654761,0.5273702911813317],[0.8929393822206129,0.5273702911813317],[0.37618345634908607,0.32466549841724035],[0.37618345634908607,0.33634272929883396],[0.37618345634908607,0.5273702911813317],[0.6831222541558417,0.5273702911813317],[0.5447150666945445,0.5447150666945445],[0.5447150666945445,0.5267863645195076],[0.5447150666945445,0.6080051629526841],[0.5447150666945445,0.5458348865235372],[0.5447150666945445,0.5878329508692572],[0.5447150666945445,0.5260875552648081],[0.5447150666945445,0.5505241768390209],[0.5447150666945445,0.5273702911813317],[0.2526976678148345,0.5273702911813317],[0.5313109656023342,0.46725188988062477],[0.5313109656023342,0.5273702911813317],[0.7415379765400981,0.6277656575160098],[0.7415379765400981,0.5273702911813317],[0.8105537647772262,0.5273702911813317],[0.7388205894069465,0.5273702911813317],[0.7388205894069465,0.6685489782327163],[0.46725188988062477,0.4871078639740247],[0.46725188988062477,0.4658322959020708],[0.46725188988062477,0.510636052227933],[0.46725188988062477,0.5503692923694219],[0.46725188988062477,0.5048020132447048],[0.46725188988062477,0.4082859360018825],[0.46725188988062477,0.5124618527636177],[0.46725188988062477,0.5085355089048774],[0.46725188988062477,0.5332561504933538],[0.46725188988062477,0.43136066141760676],[0.46725188988062477,0.5250628515459467],[0.46725188988062477,0.5273702911813317],[0.46725188988062477,0.5113462489571763],[0.46725188988062477,0.39509450781332645],[0.46725188988062477,0.49699675212891453],[0.46725188988062477,0.4454174987254497],[0.46725188988062477,0.44135240790243374],[0.46725188988062477,0.40997393568107054],[0.46725188988062477,0.4390134984338319],[0.46725188988062477,0.48632283686369515],[0.46725188988062477,0.5329057104081123],[0.46725188988062477,0.5167072560318462],[0.7946978866221922,0.8458135821758563],[0.7946978866221922,0.5273702911813317],[0.7814198436314305,0.7125408561767473],[0.7814198436314305,0.5273702911813317],[0.5529824335702461,0.5273702911813317],[0.5529824335702461,0.5177148447912643],[0.5529824335702461,0.5529824335702461],[0.5649709653000902,0.6080051629526841],[0.5649709653000902,0.5273702911813317],[0.5649709653000902,0.5260875552648081],[0.5649709653000902,0.5878329508692572],[0.8263847481724219,0.5273702911813317],[0.5267863645195076,0.5505241768390209],[0.5267863645195076,0.5273702911813317],[0.5267863645195076,0.5260875552648081],[0.5267863645195076,0.5458348865235372],[0.761656859121696,0.5273702911813317],[0.7872166262798496,0.7618397943634078],[0.7872166262798496,0.5273702911813317],[0.7872166262798496,0.6768329005466855],[0.29952075887699614,0.36833004578891965],[0.29952075887699614,0.5273702911813317],[0.4082859360018825,0.44135240790243374],[0.4082859360018825,0.5273702911813317],[0.19650212578825868,0.0004072719444873302],[0.19650212578825868,0.3883046727706779],[0.19650212578825868,0.5273702911813317],[0.42091930483654755,0.5260875552648081],[0.42091930483654755,0.5273702911813317],[0.42295945765243814,0.5273702911813317],[0.42295945765243814,0.5260875552648081],[0.6080051629526841,0.5946504680499989],[0.5260875552648081,0.5594875154588832],[0.5260875552648081,0.4962091998987209],[0.5260875552648081,0.49714673323819925],[0.5260875552648081,0.5273702911813317],[0.5260875552648081,0.4864261770589082],[0.5260875552648081,0.5505241768390209],[0.7362508636476812,0.5273702911813317],[0.761813628266647,0.6080309874401345],[0.761813628266647,0.5273702911813317],[0.7452906139267168,0.6717153141828879],[0.7452906139267168,0.5273702911813317],[0.2580476450823534,0.5273702911813317],[0.5693465742587844,0.5273702911813317],[0.3567440019403381,0.5273702911813317],[0.4907090195063411,0.47738724885640027],[0.4907090195063411,0.4864261770589082],[0.4907090195063411,0.5273702911813317],[0.4907090195063411,0.5448191465475354],[0.7866984440999546,0.5273702911813317],[0.8109428641580553,0.5273702911813317],[0.7710731504157251,0.5273702911813317],[0.6593906549121756,0.5273702911813317],[0.17699789901213275,0.0666376520597208],[0.17699789901213275,0.15719524760500456],[0.17699789901213275,0.5273702911813317],[0.17699789901213275,0.17699789901213275],[0.17699789901213275,0.05440411351733689],[0.40997393568107054,0.5273702911813317],[0.5071638873750163,0.5273702911813317],[0.5071638873750163,0.49944412323518156],[0.6757251420711579,0.5273702911813317],[0.3258229314629499,0.5273702911813317],[0.3451810016352063,0.36833004578891965],[0.3451810016352063,0.5273702911813317],[0.7138964428690399,0.5273702911813317],[0.7138964428690399,0.7344383643704192],[0.7138964428690399,0.7138964428690399],[0.5946504680499989,0.5273702911813317],[0.5946504680499989,0.5878329508692572],[0.6180153563450871,0.5273702911813317],[0.567920962016376,0.6717153141828879],[0.567920962016376,0.5273702911813317],[0.567920962016376,0.5359688794021277],[0.567920962016376,0.510636052227933],[0.6565697794292283,0.5273702911813317],[0.8556121857527282,0.5273702911813317],[0.33634272929883396,0.5273702911813317],[0.33634272929883396,0.3130781698377906],[0.33634272929883396,0.26121459320914797],[0.6768329005466855,0.7618397943634078],[0.6768329005466855,0.5273702911813317],[0.4232741731428999,0.5273702911813317],[0.6200866052863462,0.5895173731766337],[0.6200866052863462,0.5273702911813317],[0.6717153141828879,0.5273702911813317],[0.3898214122008547,0.42859586363905927],[0.3898214122008547,0.256898169164969],[0.3898214122008547,0.5273702911813317],[0.7935304655073256,0.5273702911813317],[0.28620078997995535,0.42859586363905927],[0.28620078997995535,0.5273702911813317],[0.3337395622473997,0.5273702911813317],[0.3337395622473997,0.2622240439629714],[0.3337395622473997,0.3094196801466035],[0.6968954957038507,0.5273702911813317],[0.8189600654341986,0.5273702911813317],[0.5593387736680957,0.5273702911813317],[0.7085157545233863,0.6277656575160098],[0.7085157545233863,0.5273702911813317],[0.48393231337562054,0.5273702911813317],[0.7675582807520264,0.5273702911813317],[0.7344383643704192,0.5273702911813317],[0.7344383643704192,0.7328624564696022],[0.7344383643704192,0.7344383643704192],[0.4523018886875211,0.4864261770589082],[0.4523018886875211,0.4850507051728439],[0.4523018886875211,0.5273702911813317],[0.3094196801466035,0.5273702911813317],[0.3094196801466035,0.2622240439629714],[0.5048020132447048,0.510636052227933],[0.5048020132447048,0.5273702911813317],[0.2632069130739772,0.21176849404182965],[0.2632069130739772,0.2949650517770683],[0.2632069130739772,0.5273702911813317],[0.7859863180590075,0.5273702911813317],[0.7004173260385501,0.5273702911813317],[0.7004173260385501,0.7328624564696022],[0.6520292797891475,0.5659837781046475],[0.6520292797891475,0.5273702911813317],[0.2668432841062252,0.3661621372044959],[0.2668432841062252,0.3883046727706779],[0.2668432841062252,0.21808878860540684],[0.8673087402297465,0.5273702911813317],[0.21176849404182965,0.2949650517770683],[0.21176849404182965,0.25937843210368355],[0.21176849404182965,0.25536819436085423],[0.4850507051728439,0.4864261770589082],[0.4850507051728439,0.4850507051728439],[0.4850507051728439,0.5273702911813317],[0.4850507051728439,0.3883046727706779],[0.49714673323819925,0.5273702911813317],[0.2170270862194745,0.5273702911813317],[0.3661621372044959,0.5273702911813317],[0.8045028091519743,0.5273702911813317],[0.4454174987254497,0.4454174987254497],[0.4454174987254497,0.3570884139781243],[0.4454174987254497,0.34822187064016563],[0.4454174987254497,0.37238772853881913],[0.4454174987254497,0.44135240790243374],[0.4454174987254497,0.510636052227933],[0.4454174987254497,0.42179931848929575],[0.4454174987254497,0.5273702911813317],[0.6978388426777503,0.5273702911813317],[0.9009080692474105,0.5273702911813317],[0.19425256693751614,0.5273702911813317],[0.7266454077620865,0.7052668737315834],[0.3130781698377906,0.38710514416806735],[0.15719524760500456,0.1956204643491215],[0.5276767715252405,0.5273702911813317],[0.510636052227933,0.5359688794021277],[0.510636052227933,0.5332561504933538],[0.510636052227933,0.5329057104081123],[0.510636052227933,0.5273702911813317],[0.510636052227933,0.510636052227933],[0.510636052227933,0.5124618527636177],[0.5124618527636177,0.5273702911813317],[0.5124618527636177,0.5359688794021277],[0.627272250059462,0.5273702911813317],[0.8429349676089558,0.7560820530487513],[0.8429349676089558,0.5273702911813317],[0.42179931848929575,0.5273702911813317],[0.6824933772230014,0.7131000611151268],[0.6824933772230014,0.5273702911813317],[0.7243670816727983,0.5273702911813317],[0.7516747463259655,0.5273702911813317],[0.5329057104081123,0.5273702911813317],[0.46232631932681983,0.4864261770589082],[0.46232631932681983,0.5096609465005195],[0.46232631932681983,0.5273702911813317],[0.46232631932681983,0.46232631932681983],[0.166819139529403,0.03387804922264454],[0.166819139529403,0.5273702911813317],[0.34822187064016563,0.34822187064016563],[0.34822187064016563,0.5273702911813317],[0.34822187064016563,0.3570884139781243],[0.25536819436085423,0.2949650517770683],[0.25536819436085423,0.5273702911813317],[0.8010814415715746,0.5273702911813317],[0.6401117262934481,0.5273702911813317],[0.13777514371507615,0.01491152415878895],[0.13777514371507615,0.5273702911813317],[0.5659837781046475,0.46741740038951296],[0.5659837781046475,0.5273702911813317],[0.4536149058326496,0.36833004578891965],[0.4536149058326496,0.5273702911813317],[0.7052668737315834,0.5273702911813317],[0.5332561504933538,0.5273702911813317],[0.7042899634519145,0.5273702911813317],[0.5961847279537155,0.5273702911813317],[0.2753690782443153,0.5273702911813317],[0.4658322959020708,0.5273702911813317],[0.8636362988904436,0.5273702911813317],[0.29134409322657606,0.5273702911813317],[0.8764029275146705,0.5273702911813317],[0.869789378211215,0.5273702911813317],[0.7106268413894079,0.5273702911813317],[0.5907137988525875,0.5096609465005195],[0.5907137988525875,0.5273702911813317],[0.28602282595682754,0.5273702911813317],[0.2284611938858925,0.5273702911813317],[0.5985644739547227,0.5273702911813317],[0.6649554871730126,0.5273702911813317],[0.6649554871730126,0.6080309874401345],[0.25937843210368355,0.2949650517770683],[0.25937843210368355,0.5273702911813317],[0.2358727100151212,0.5273702911813317],[0.8790374985140805,0.5273702911813317],[0.44810173436769446,0.5273702911813317],[0.5250628515459467,0.5273702911813317],[0.256898169164969,0.5273702911813317],[0.39509450781332645,0.5273702911813317],[0.2949650517770683,0.5273702911813317],[0.3883046727706779,0.4864261770589082],[0.3883046727706779,0.5273702911813317],[0.6781321865441622,0.5273702911813317],[0.7167019153870717,0.5273702911813317],[0.5966708414632891,0.5273702911813317],[0.44135240790243374,0.5273702911813317],[0.44135240790243374,0.48632283686369515],[0.6518500628476263,0.5273702911813317],[0.42859586363905927,0.2879879844646292],[0.42859586363905927,0.5096609465005195],[0.42859586363905927,0.5273702911813317],[0.42859586363905927,0.42859586363905927],[0.42859586363905927,0.46741740038951296],[0.7131000611151268,0.726770167517955],[0.7131000611151268,0.5273702911813317],[0.5085355089048774,0.5273702911813317],[0.35660111712708964,0.5273702911813317],[0.5113462489571763,0.5273702911813317],[0.726770167517955,0.5273702911813317],[0.6080309874401345,0.6277656575160098],[0.6080309874401345,0.5273702911813317],[0.6080309874401345,0.7328624564696022],[0.2340754405001311,0.5273702911813317],[0.7754670377276417,0.5273702911813317],[0.47738724885640027,0.5594875154588832],[0.47738724885640027,0.4864261770589082],[0.47738724885640027,0.47738724885640027],[0.47738724885640027,0.5273702911813317],[0.8628547242807124,0.5273702911813317],[0.6925271287281928,0.6925271287281928],[0.6925271287281928,0.5273702911813317],[0.23564451833165584,0.5273702911813317],[0.20315850054990733,0.5273702911813317],[0.5359688794021277,0.5273702911813317],[0.36329127930353833,0.5273702911813317],[0.6986026475011937,0.5273702911813317],[0.7560820530487513,0.5273702911813317],[0.35594095814264237,0.5273702911813317],[0.28311721776637655,0.5273702911813317],[0.4962091998987209,0.5273702911813317],[0.2879879844646292,0.5273702911813317],[0.49699675212891453,0.5273702911813317],[0.5167072560318462,0.5273702911813317],[0.26121459320914797,0.32466549841724035],[0.4529860888516215,0.4864261770589082],[0.4529860888516215,0.5273702911813317],[0.4529860888516215,0.5448191465475354],[0.4016712656772196,0.4864261770589082],[0.4016712656772196,0.5273702911813317],[0.4871078639740247,0.5273702911813317],[0.5169218248929459,0.5273702911813317],[0.596605921943523,0.5273702911813317],[0.5413675166391315,0.5273702911813317],[0.37238772853881913,0.5273702911813317],[0.21808878860540684,0.5273702911813317],[0.38710514416806735,0.5273702911813317],[0.3962128954605851,0.5273702911813317],[0.3706081060186885,0.5273702911813317],[0.5503692923694219,0.5273702911813317],[0.46741740038951296,0.5273702911813317],[0.46741740038951296,0.46741740038951296],[0.1893636514025236,0.5273702911813317],[0.40801296993013914,0.5273702911813317],[0.4864261770589082,0.49592377787927816],[0.4864261770589082,0.5594875154588832],[0.4864261770589082,0.4864261770589082],[0.4864261770589082,0.5273702911813317],[0.4864261770589082,0.5448191465475354],[0.5895173731766337,0.5273702911813317],[0.6685489782327163,0.5273702911813317],[0.6301227041720708,0.5273702911813317],[0.36833004578891965,0.5273702911813317],[0.43136066141760676,0.5273702911813317],[0.32937314578834825,0.5273702911813317],[0.34599043477666275,0.5273702911813317],[0.2743397678659176,0.5273702911813317],[0.5273702911813317,0.7272638538465169],[0.5273702911813317,0.6074710587608619],[0.5273702911813317,0.6293972386035256],[0.5273702911813317,0.7994834301821617],[0.5273702911813317,0.8074746819308689],[0.5273702911813317,0.6924426591714892],[0.5273702911813317,0.5273702911813317],[0.5273702911813317,0.25876633382212216],[0.5273702911813317,0.7328624564696022],[0.5273702911813317,0.4390134984338319],[0.5273702911813317,0.5096609465005195],[0.5273702911813317,0.5505241768390209],[0.5273702911813317,0.28638920473736407],[0.5273702911813317,0.1322454057651943],[0.5273702911813317,0.3767405480752065],[0.5273702911813317,0.49592377787927816],[0.5273702911813317,0.32466549841724035],[0.5273702911813317,0.6277656575160098],[0.5273702911813317,0.7469397426983816],[0.5273702911813317,0.1956204643491215],[0.5273702911813317,0.7125408561767473],[0.5273702911813317,0.5594875154588832],[0.5273702911813317,0.8867889565968607],[0.5273702911813317,0.3570884139781243],[0.5273702911813317,0.5177148447912643],[0.5273702911813317,0.7618397943634078],[0.5273702911813317,0.544539004263694],[0.5273702911813317,0.48632283686369515],[0.5273702911813317,0.6522806171755322],[0.5273702911813317,0.3093605027419721],[0.5273702911813317,0.5448191465475354],[0.5273702911813317,0.8514221020669225],[0.5096609465005195,0.5096609465005195],[0.5505241768390209,0.5458348865235372],[0.6277656575160098,0.6277656575160098],[0.6591189655369051,0.6074710587608619],[0.5177148447912643,0.5177148447912643],[0.6074710587608619,0.6074710587608619],[0.7618397943634078,0.7618397943634078]],\"ys\":[[0.660432871437816,0.6580949110185261],[0.660432871437816,0.48046567508521565],[0.660432871437816,0.6034712410443259],[0.660432871437816,0.6156320944435291],[0.660432871437816,0.6143159256020416],[0.25983621371186605,0.4644265933240915],[0.7332106471142972,0.6555924748004226],[0.7332106471142972,0.5884439725024153],[0.24383610004311296,0.41569664957548513],[0.3073870265835071,0.4644265933240915],[0.3073870265835071,0.33055713136062487],[0.6713688656097923,0.6762104750895189],[0.6713688656097923,0.6177264302342022],[0.6713688656097923,0.4644265933240915],[0.16408292422416088,0.4644265933240915],[0.4415399262979149,0.41569664957548513],[0.4415399262979149,0.5007766899277777],[0.4415399262979149,0.3872220465602767],[0.4415399262979149,0.4644265933240915],[0.4415399262979149,0.468087975974438],[0.4415399262979149,0.43293099809978064],[0.4415399262979149,0.4415399262979149],[0.7392730165959559,0.4644265933240915],[0.7392730165959559,0.7113211289585225],[0.7392730165959559,0.9830068707539786],[0.19792836219983753,0.4644265933240915],[0.19792836219983753,0.268006552837604],[0.19792836219983753,0.24086342723742865],[0.19792836219983753,0.0839364307451562],[0.3872220465602767,0.43293099809978064],[0.1125462696946161,0.4644265933240915],[0.30365752381793865,0.2627189451238526],[0.30365752381793865,0.4644265933240915],[0.8682780812412808,0.7444164662901014],[0.8682780812412808,0.7580853182147079],[0.8682780812412808,0.6819393646825664],[0.5435332140153116,0.5146859906287252],[0.5435332140153116,0.4644265933240915],[0.5435332140153116,0.5191506485901891],[0.25737918638708507,0.4644265933240915],[0.25737918638708507,0.35354765901276075],[0.4926392468174273,0.41569664957548513],[0.4926392468174273,0.4198032904377029],[0.4926392468174273,0.4435919918519365],[0.4926392468174273,0.5210969333616969],[0.4926392468174273,0.6143159256020416],[0.6555924748004226,0.5884439725024153],[0.6555924748004226,0.4644265933240915],[0.35354765901276075,0.41569664957548513],[0.35354765901276075,0.2866761446724974],[0.35354765901276075,0.4644265933240915],[0.29026007298482365,0.27779010446024777],[0.29026007298482365,0.23747688018632296],[0.29026007298482365,0.4644265933240915],[0.5034199838939876,0.49224398292360866],[0.5034199838939876,0.4644265933240915],[0.4164583046415229,0.4525379216453794],[0.2242436061445224,0.27007728591199187],[0.2242436061445224,0.4644265933240915],[0.5862690940697507,0.5146859906287252],[0.5862690940697507,0.5204616184970776],[0.5862690940697507,0.5351326715500055],[0.5862690940697507,0.5411998098354136],[0.15956168335173848,0.268006552837604],[0.15956168335173848,0.08710036054342263],[0.15956168335173848,0.4644265933240915],[0.15956168335173848,0.08155316871340108],[0.4081364148795204,0.3512865619336758],[0.4081364148795204,0.4644265933240915],[0.4081364148795204,0.3788913931950467],[0.7423330343043048,0.6904226612863027],[0.7423330343043048,0.4644265933240915],[0.7423330343043048,0.6143159256020416],[0.7119263878031391,0.4644265933240915],[1.0,0.8557571722218559],[1.0,0.8528721121156967],[0.23709655038122238,0.30604823057945385],[0.23709655038122238,0.2678319918497413],[0.23709655038122238,0.3694577704292969],[0.23709655038122238,0.4644265933240915],[0.479491914506478,0.42462563666944586],[0.479491914506478,0.5782368882477646],[0.479491914506478,0.4644265933240915],[0.479491914506478,0.45250458946179123],[0.479491914506478,0.4977491277771893],[0.479491914506478,0.5411998098354136],[0.224994162377506,0.3694577704292969],[0.224994162377506,0.4644265933240915],[0.831282443778007,0.6980098944564919],[0.831282443778007,0.6034712410443259],[0.831282443778007,0.7146508825410139],[0.2694545569779559,0.4644265933240915],[0.2694545569779559,0.39651518609686176],[0.19594640773543653,0.2394744818775305],[0.19594640773543653,0.4644265933240915],[0.4507684163240844,0.5007766899277777],[0.4507684163240844,0.4644265933240915],[0.7519820126003876,0.691886326565762],[0.7519820126003876,0.4644265933240915],[0.7519820126003876,0.7455202993113186],[0.37938243566997665,0.4644265933240915],[0.40944090394725324,0.41569664957548513],[0.40944090394725324,0.3694577704292969],[0.40944090394725324,0.4644265933240915],[0.40944090394725324,0.3574758276477921],[0.40944090394725324,0.35319012821601903],[0.40944090394725324,0.40944090394725324],[0.40944090394725324,0.321680047850924],[0.40944090394725324,0.48979672257253865],[0.16969556638132585,0.4644265933240915],[0.40775345452754036,0.4058441348357288],[0.40775345452754036,0.4285635536904042],[0.40775345452754036,0.4644265933240915],[0.16036723110733567,0.268006552837604],[0.16036723110733567,0.08710036054342263],[0.16036723110733567,0.4644265933240915],[0.16036723110733567,0.08155316871340108],[0.7164114852181838,0.6904226612863027],[0.7164114852181838,0.4644265933240915],[0.7164114852181838,0.6143159256020416],[0.7474388513889462,0.6904226612863027],[0.7474388513889462,0.4644265933240915],[0.7474388513889462,0.6143159256020416],[0.13390310266931893,0.4644265933240915],[0.5716356784561741,0.5936053922055856],[0.5716356784561741,0.5716356784561741],[0.5716356784561741,0.4644265933240915],[0.5716356784561741,0.5750826143843594],[0.5716356784561741,0.6017510295555455],[0.5716356784561741,0.6314946864402609],[0.5716356784561741,0.5505574055447559],[0.5716356784561741,0.6386468337920613],[0.5716356784561741,0.7113211289585225],[0.42047350559793945,0.41569664957548513],[0.42047350559793945,0.46463118186664565],[0.42047350559793945,0.4644265933240915],[0.6279263550325983,0.5782368882477646],[0.6279263550325983,0.4644265933240915],[0.6279263550325983,0.5411998098354136],[0.5478678495498374,0.4644265933240915],[0.5478678495498374,0.5140240042309399],[0.7357940507538124,0.8554334126061353],[0.7357940507538124,0.4644265933240915],[0.10193544041342725,0.30604823057945385],[0.10193544041342725,0.3694577704292969],[0.8315177459730111,0.4644265933240915],[0.8315177459730111,0.9722576374189348],[0.8315177459730111,0.8370998501953743],[0.5704206344468208,0.4644265933240915],[0.5704206344468208,0.5140240042309399],[0.4665701285897894,0.4935214922361755],[0.4665701285897894,0.42664086597482787],[0.4665701285897894,0.4644265933240915],[0.6114884559743814,0.5661247818553705],[0.6114884559743814,0.5884439725024153],[0.6114884559743814,0.5476713970682007],[0.6114884559743814,0.5392331611303647],[0.8480644043231941,0.4644265933240915],[0.8480644043231941,0.9970655067320642],[0.3836060316311979,0.41569664957548513],[0.3836060316311979,0.3642910540840711],[0.3836060316311979,0.4644265933240915],[0.48867307066228693,0.4644265933240915],[0.8129565908543038,0.8830079150374622],[0.8129565908543038,0.6904226612863027],[0.8129565908543038,0.4644265933240915],[0.5457359122517992,0.5204616184970776],[0.5457359122517992,0.5756934843630539],[0.5457359122517992,0.4644265933240915],[0.5457359122517992,0.5411998098354136],[0.5457359122517992,0.5146859906287252],[0.5457359122517992,0.5324797516965024],[0.5457359122517992,0.5464994824749025],[0.5457359122517992,0.5191506485901891],[0.5351326715500055,0.5146859906287252],[0.5351326715500055,0.4644265933240915],[0.5351326715500055,0.5411998098354136],[0.3744413623546023,0.27600443680581555],[0.3744413623546023,0.20246350467293522],[0.3744413623546023,0.4644265933240915],[0.1680352984790842,0.4644265933240915],[0.1680352984790842,0.15031846957277747],[0.28765897036398186,0.4644265933240915],[0.5007766899277777,0.5071788679257944],[0.5007766899277777,0.37439611908434434],[0.5007766899277777,0.4598101669700343],[0.5007766899277777,0.41747798898431937],[0.5007766899277777,0.5007766899277777],[0.5007766899277777,0.582176442627514],[0.5007766899277777,0.6015546785961549],[0.5007766899277777,0.4644265933240915],[0.5007766899277777,0.6237727305021749],[0.5007766899277777,0.5655243837424004],[0.5007766899277777,0.43293099809978064],[0.19933334488961252,0.4644265933240915],[0.19933334488961252,0.33055713136062487],[0.002798961435541578,0.24488037792617978],[0.7641417465286434,0.7371297618622412],[0.7641417465286434,0.4644265933240915],[0.3574758276477921,0.41569664957548513],[0.3574758276477921,0.27007728591199187],[0.3574758276477921,0.4644265933240915],[0.6745803882193274,0.6429307396691056],[0.6745803882193274,0.5782368882477646],[0.6745803882193274,0.4644265933240915],[0.6745803882193274,0.6745803882193274],[0.6745803882193274,0.6191203260359933],[0.6745803882193274,0.70196767347563],[0.6143159256020416,0.6162626818062846],[0.6143159256020416,0.6143159256020416],[0.6143159256020416,0.6580949110185261],[0.6143159256020416,0.6355543158364171],[0.6143159256020416,0.5633846671937589],[0.6143159256020416,0.6034712410443259],[0.6143159256020416,0.7311120412458607],[0.6143159256020416,0.7510563490127009],[0.6143159256020416,0.6500322109180686],[0.6143159256020416,0.7211525475839037],[0.6143159256020416,0.7088679714710461],[0.6143159256020416,0.6891849194688708],[0.6143159256020416,0.5993878107889014],[0.6143159256020416,0.7321686807058896],[0.6143159256020416,0.6852702632643184],[0.6143159256020416,0.7334027682174646],[0.6143159256020416,0.6318110145695137],[0.6143159256020416,0.41569664957548513],[0.6143159256020416,0.5671348921371102],[0.6143159256020416,0.6085669803114362],[0.6143159256020416,0.7193167344323413],[0.6143159256020416,0.7089756923612295],[0.6143159256020416,0.6424909535271728],[0.6143159256020416,0.7452829125960218],[0.6143159256020416,0.7527254406328888],[0.6143159256020416,0.7504090640510136],[0.6143159256020416,0.6861984278986488],[0.6143159256020416,0.6156320944435291],[0.6143159256020416,0.7310000899182425],[0.6143159256020416,0.6904226612863027],[0.6143159256020416,0.7217819685043624],[0.6143159256020416,0.6958513172750607],[0.6143159256020416,0.4644265933240915],[0.7995760532528451,0.8830079150374622],[0.7995760532528451,0.6904226612863027],[0.7995760532528451,0.4644265933240915],[0.2394744818775305,0.22637531395393293],[0.2394744818775305,0.2197776096402575],[0.2394744818775305,0.4644265933240915],[0.2394744818775305,0.17837135328717482],[0.2394744818775305,0.19584745008425958],[0.2394744818775305,0.20490598362692178],[0.2394744818775305,0.33843500925763914],[0.2394744818775305,0.30898003112970135],[0.7345271082885712,0.6429307396691056],[0.7345271082885712,0.5681739762661152],[0.7345271082885712,0.6191203260359933],[0.19584745008425958,0.4644265933240915],[0.3850658234158584,0.41569664957548513],[0.3850658234158584,0.3850658234158584],[0.3850658234158584,0.4644265933240915],[0.3850658234158584,0.3975901164304786],[0.5634640869349782,0.5146859906287252],[0.5634640869349782,0.5324797516965024],[0.5634640869349782,0.4644265933240915],[0.5634640869349782,0.5411998098354136],[0.42687603977834965,0.46463118186664565],[0.42687603977834965,0.4644265933240915],[0.6162626818062846,0.8078391955329095],[0.6162626818062846,0.4644265933240915],[0.6162626818062846,0.6085669803114362],[0.6162626818062846,0.5993878107889014],[0.6162626818062846,0.6904226612863027],[0.6162626818062846,0.6034712410443259],[0.6162626818062846,0.6500322109180686],[0.1323325629683591,0.4644265933240915],[0.43351085519853894,0.4644265933240915],[0.43351085519853894,0.4412738654608661],[0.7334027682174646,0.6904226612863027],[0.7334027682174646,0.4644265933240915],[0.6929474037593202,0.5681739762661152],[0.6929474037593202,0.579640533495896],[0.4598101669700343,0.468087975974438],[0.4598101669700343,0.4644265933240915],[0.4876032944294878,0.48453723694984574],[0.4876032944294878,0.45967477884167124],[0.4876032944294878,0.4812389911319088],[0.4876032944294878,0.4644265933240915],[0.4935214922361755,0.4644265933240915],[0.5332065483951346,0.4644265933240915],[0.5332065483951346,0.5140240042309399],[0.2197776096402575,0.4644265933240915],[0.6865036503447209,0.5505574055447559],[0.6865036503447209,0.4644265933240915],[0.4889075870448013,0.4644265933240915],[0.4889075870448013,0.5116991430043761],[0.816696387794036,0.8830079150374622],[0.816696387794036,0.6904226612863027],[0.816696387794036,0.4644265933240915],[0.17145904021242891,0.2627189451238526],[0.17145904021242891,0.09014206234609701],[0.17145904021242891,0.4644265933240915],[0.6026806938089542,0.628402889749191],[0.6026806938089542,0.4644265933240915],[0.47425440150618353,0.4525379216453794],[0.6624697707834359,0.5505574055447559],[0.6624697707834359,0.4644265933240915],[0.24484892440599748,0.4644265933240915],[0.24484892440599748,0.2545198557999168],[0.6819393646825664,0.7444164662901014],[0.6819393646825664,0.4644265933240915],[0.6819393646825664,0.7580853182147079],[0.532079273991722,0.4644265933240915],[0.3248285503180051,0.41569664957548513],[0.3248285503180051,0.3975901164304786],[0.6429307396691056,0.5782368882477646],[0.6429307396691056,0.4644265933240915],[0.6429307396691056,0.6191203260359933],[0.6429307396691056,0.5681739762661152],[0.6429307396691056,0.70196767347563],[0.6429307396691056,0.649129723689199],[0.6429307396691056,0.74877366793852],[0.22637531395393293,0.4644265933240915],[0.5586561342032628,0.4644265933240915],[0.7193167344323413,0.6904226612863027],[0.7193167344323413,0.4644265933240915],[0.21154712567125186,0.41569664957548513],[0.32830933898901904,0.4644265933240915],[0.32830933898901904,0.3814101792614075],[0.7002219082501343,0.6904226612863027],[0.7002219082501343,0.4644265933240915],[0.7002219082501343,0.923372596923963],[0.637701616562345,0.7462947759422153],[0.637701616562345,0.5269626819567745],[0.637701616562345,0.630801416528471],[0.637701616562345,0.4644265933240915],[0.637701616562345,0.6535846371981258],[0.637701616562345,0.7237466047750631],[0.24375376247989744,0.4644265933240915],[0.20963739924688715,0.2576482912815104],[0.20963739924688715,0.4644265933240915],[0.20963739924688715,0.24086342723742865],[0.20963739924688715,0.268006552837604],[0.5633846671937589,0.5993878107889014],[0.5633846671937589,0.6904226612863027],[0.5633846671937589,0.4644265933240915],[0.10182279050687786,0.4644265933240915],[0.3961863164628086,0.32811574748523936],[0.3961863164628086,0.4644265933240915],[0.3961863164628086,0.3756304159096863],[0.48979672257253865,0.41569664957548513],[0.48979672257253865,0.3694577704292969],[0.48979672257253865,0.4644265933240915],[0.48979672257253865,0.468087975974438],[0.48979672257253865,0.6762104750895189],[0.48979672257253865,0.6177264302342022],[0.48979672257253865,0.3814101792614075],[0.31762800862395507,0.1081767734249794],[0.31762800862395507,0.4644265933240915],[0.5936053922055856,0.5505574055447559],[0.5936053922055856,0.6386468337920613],[0.5936053922055856,0.4644265933240915],[0.5936053922055856,0.7113211289585225],[0.5835240296844172,0.4644265933240915],[0.5835240296844172,0.5210969333616969],[0.5835240296844172,0.5505574055447559],[0.5835240296844172,0.6386468337920613],[0.5835240296844172,0.7113211289585225],[0.5835240296844172,0.5371251862374531],[0.5973150253917375,0.6904226612863027],[0.5973150253917375,0.5342409109794203],[0.5973150253917375,0.4644265933240915],[0.5973150253917375,0.5552044611623879],[0.09014206234609701,0.2627189451238526],[0.09014206234609701,0.268006552837604],[0.17837135328717482,0.4644265933240915],[0.5354332583594661,0.4644265933240915],[0.49321589761667906,0.4644265933240915],[0.691886326565762,0.7455202993113186],[0.691886326565762,0.4644265933240915],[0.691886326565762,0.9463574822795291],[0.7612193446686886,0.8731475419437271],[0.7612193446686886,0.4644265933240915],[0.31595608407855186,0.4644265933240915],[0.24019339361525108,0.24019339361525108],[0.24019339361525108,0.22863153884520127],[0.24019339361525108,0.4644265933240915],[0.630801416528471,0.7462947759422153],[0.630801416528471,0.5269626819567745],[0.630801416528471,0.4644265933240915],[0.630801416528471,0.6535846371981258],[0.630801416528471,0.7237466047750631],[0.12164262906037887,0.4644265933240915],[0.49224398292360866,0.4644265933240915],[0.18969589121840597,0.18221201116375585],[0.18969589121840597,0.4644265933240915],[0.0839364307451562,0.268006552837604],[0.0839364307451562,0.24086342723742865],[0.3642910540840711,0.41569664957548513],[0.3642910540840711,0.4607304950314831],[0.5204616184970776,0.5204616184970776],[0.5204616184970776,0.5756934843630539],[0.5204616184970776,0.4644265933240915],[0.5204616184970776,0.5411998098354136],[0.5204616184970776,0.5146859906287252],[0.5204616184970776,0.5324797516965024],[0.5204616184970776,0.5464994824749025],[0.5204616184970776,0.5191506485901891],[0.5803926327104053,0.4644265933240915],[0.02602260530775652,0.268006552837604],[0.32625936365022923,0.41569664957548513],[0.32625936365022923,0.4644265933240915],[0.8023112618661227,0.8830079150374622],[0.8023112618661227,0.6904226612863027],[0.8023112618661227,0.4644265933240915],[0.41569664957548513,0.5269626819567745],[0.41569664957548513,0.35091370069078043],[0.41569664957548513,0.3811804114215997],[0.41569664957548513,0.321680047850924],[0.41569664957548513,0.2877245275031935],[0.41569664957548513,0.2866761446724974],[0.41569664957548513,0.35319012821601903],[0.41569664957548513,0.36705657941491054],[0.41569664957548513,0.4198032904377029],[0.41569664957548513,0.5210969333616969],[0.41569664957548513,0.611776552412223],[0.41569664957548513,0.32903756454915417],[0.41569664957548513,0.3975901164304786],[0.41569664957548513,0.41747798898431937],[0.41569664957548513,0.35372947827716217],[0.41569664957548513,0.28967045807142405],[0.41569664957548513,0.39723488268211155],[0.41569664957548513,0.4644265933240915],[0.41569664957548513,0.4435919918519365],[0.41569664957548513,0.3015005471981137],[0.41569664957548513,0.30163224913901937],[0.18417900132468612,0.4644265933240915],[0.5411998098354136,0.4977491277771893],[0.5411998098354136,0.5782368882477646],[0.5411998098354136,0.5464994824749025],[0.5411998098354136,0.5756934843630539],[0.5411998098354136,0.4607304950314831],[0.5411998098354136,0.7487474820814098],[0.5411998098354136,0.5146859906287252],[0.5411998098354136,0.4644265933240915],[0.5411998098354136,0.5324797516965024],[0.5411998098354136,0.7131321290633202],[0.3811804114215997,0.4644265933240915],[0.23966908896035619,0.4644265933240915],[0.5884439725024153,0.5661247818553705],[0.5884439725024153,0.4644265933240915],[0.5884439725024153,0.5476713970682007],[0.5884439725024153,0.5392331611303647],[0.5191506485901891,0.5146859906287252],[0.5191506485901891,0.4644265933240915],[0.5191506485901891,0.4977491277771893],[0.5464994824749025,0.4607304950314831],[0.5464994824749025,0.5586600444464479],[0.5464994824749025,0.5146859906287252],[0.5464994824749025,0.527730855490007],[0.3054425167881268,0.4644265933240915],[0.8370998501953743,0.4644265933240915],[0.8370998501953743,0.9722576374189348],[0.7321686807058896,0.6904226612863027],[0.7321686807058896,0.4644265933240915],[0.5381327218855235,0.6244488551073897],[0.5381327218855235,0.5999866263324974],[0.5381327218855235,0.4644265933240915],[0.5381327218855235,0.5381327218855235],[0.5381327218855235,0.46463118186664565],[0.5381327218855235,0.5671348921371102],[0.32903756454915417,0.4644265933240915],[0.45567894400574516,0.46463118186664565],[0.45567894400574516,0.4644265933240915],[0.3336401440765844,0.4644265933240915],[0.5091876625107056,0.4644265933240915],[0.5091876625107056,0.5140240042309399],[0.3461691993004907,0.4644265933240915],[0.3461691993004907,0.3814101792614075],[0.5940705956617384,0.6762104750895189],[0.5940705956617384,0.6177264302342022],[0.5940705956617384,0.4644265933240915],[0.6191203260359933,0.628402889749191],[0.6191203260359933,0.5782368882477646],[0.6191203260359933,0.4644265933240915],[0.6191203260359933,0.649129723689199],[0.6191203260359933,0.5681739762661152],[0.6191203260359933,0.74877366793852],[0.2500794065488848,0.30604823057945385],[0.2500794065488848,0.3694577704292969],[0.2500794065488848,0.4644265933240915],[0.657086202431473,0.6034712410443259],[0.657086202431473,0.657086202431473],[0.657086202431473,0.4644265933240915],[0.105211734290933,0.4644265933240915],[0.7504090640510136,0.6904226612863027],[0.7504090640510136,0.4644265933240915],[0.6156320944435291,0.6156320944435291],[0.6156320944435291,0.6034712410443259],[0.6156320944435291,0.6580949110185261],[0.6156320944435291,0.4644265933240915],[0.6355438452819554,0.4644265933240915],[0.6355438452819554,0.7034586032808088],[0.3814101792614075,0.388417647624072],[0.3814101792614075,0.35124935361294507],[0.3814101792614075,0.5681739762661152],[0.3814101792614075,0.33055713136062487],[0.3814101792614075,0.3076447431098306],[0.3814101792614075,0.4452292275739381],[0.3814101792614075,0.32365947792215594],[0.3814101792614075,0.3662196950547806],[0.3814101792614075,0.3529082566550165],[0.3814101792614075,0.29959065960548625],[0.3814101792614075,0.290973142510098],[0.3814101792614075,0.39651518609686176],[0.3814101792614075,0.4644265933240915],[0.22863153884520127,0.4644265933240915],[0.9312095100973454,0.8086494090192747],[0.35124935361294507,0.4644265933240915],[0.321680047850924,0.4644265933240915],[0.2851408486858898,0.4644265933240915],[0.8830079150374622,0.7968717860750494],[0.8830079150374622,0.7900187994632909],[0.8830079150374622,0.7890076050183971],[0.8830079150374622,0.8045534864851885],[0.8830079150374622,0.7941581650806059],[0.8830079150374622,0.6904226612863027],[0.8830079150374622,0.8134193274559792],[0.4281253663696925,0.4644265933240915],[0.18221201116375585,0.15869576594179613],[0.18221201116375585,0.18444928769237487],[0.18221201116375585,0.19731172210428197],[0.18221201116375585,0.16016274624505258],[0.18221201116375585,0.16852785115334742],[0.18221201116375585,0.13741285746048232],[0.18221201116375585,0.4644265933240915],[0.5943727764857878,0.4644265933240915],[0.5505574055447559,0.6946543424032136],[0.5505574055447559,0.6797349754383587],[0.5505574055447559,0.6383001874738673],[0.5505574055447559,0.6314946864402609],[0.5505574055447559,0.8223984231829917],[0.5505574055447559,0.6594916630702127],[0.5505574055447559,0.388417647624072],[0.5505574055447559,0.5145525649499937],[0.5505574055447559,0.5750826143843594],[0.5505574055447559,0.5210969333616969],[0.5505574055447559,0.6017510295555455],[0.5505574055447559,0.5681739762661152],[0.5505574055447559,0.608632763773559],[0.5505574055447559,0.3694577704292969],[0.5505574055447559,0.4644265933240915],[0.5505574055447559,0.6904226612863027],[0.5505574055447559,0.6386468337920613],[0.5505574055447559,0.7113211289585225],[0.5505574055447559,0.5371251862374531],[0.36705657941491054,0.4644265933240915],[0.36705657941491054,0.33843500925763914],[0.74877366793852,0.5681739762661152],[0.628402889749191,0.6399926936563858],[0.628402889749191,0.5514117581134003],[0.628402889749191,0.4644265933240915],[0.628402889749191,0.6586521543222597],[0.628402889749191,0.6210846640660135],[0.628402889749191,0.6797909978021992],[0.2627189451238526,0.4644265933240915],[0.2627189451238526,0.268006552837604],[0.6741822813624635,0.4644265933240915],[0.8557571722218559,0.8528721121156967],[0.8557571722218559,0.4644265933240915],[0.4977491277771893,0.4644265933240915],[0.4977491277771893,0.45250458946179123],[0.4977491277771893,0.5146859906287252],[0.4393404746789394,0.4644265933240915],[0.7089756923612295,0.6904226612863027],[0.7089756923612295,0.4644265933240915],[0.268006552837604,0.2576482912815104],[0.268006552837604,0.3694577704292969],[0.268006552837604,0.16173073020245696],[0.268006552837604,0.39723488268211155],[0.268006552837604,0.08155316871340108],[0.268006552837604,0.24086342723742865],[0.268006552837604,0.27420827225574895],[0.268006552837604,0.33364665792653025],[0.268006552837604,0.08710036054342263],[0.268006552837604,0.4644265933240915],[0.268006552837604,0.012014781810010287],[0.268006552837604,0.04536084763174147],[0.8078391955329095,0.6034712410443259],[0.8078391955329095,0.6500322109180686],[0.3682142606449557,0.388417647624072],[0.3682142606449557,0.3694577704292969],[0.3682142606449557,0.2402041690827045],[0.3682142606449557,0.4030728953171881],[0.3682142606449557,0.4644265933240915],[0.3682142606449557,0.45250458946179123],[0.3682142606449557,0.2961160615424195],[0.3682142606449557,0.33055713136062487],[0.3682142606449557,0.37439611908434434],[0.16852785115334742,0.4644265933240915],[0.6958513172750607,0.6904226612863027],[0.6958513172750607,0.6500322109180686],[0.6958513172750607,0.4644265933240915],[0.7900187994632909,0.6904226612863027],[0.7900187994632909,0.4644265933240915],[0.2961160615424195,0.388417647624072],[0.2961160615424195,0.2402041690827045],[0.2961160615424195,0.4644265933240915],[0.2961160615424195,0.33055713136062487],[0.2961160615424195,0.37439611908434434],[0.3512865619336758,0.3788913931950467],[0.18444928769237487,0.4644265933240915],[0.3756304159096863,0.4644265933240915],[0.33843500925763914,0.4644265933240915],[0.4452292275739381,0.444027353342111],[0.4452292275739381,0.4644265933240915],[0.35537686614228586,0.3694577704292969],[0.35537686614228586,0.33364665792653025],[0.35537686614228586,0.4644265933240915],[0.4385303799398052,0.41254406548995315],[0.3377009970768298,0.3698943178774708],[0.3377009970768298,0.4644265933240915],[0.3951994930091709,0.4644265933240915],[0.4198032904377029,0.4644265933240915],[0.3292708222451807,0.4644265933240915],[0.290973142510098,0.4644265933240915],[0.5661247818553705,0.5661247818553705],[0.5661247818553705,0.4644265933240915],[0.5661247818553705,0.5476713970682007],[0.5661247818553705,0.5392331611303647],[0.5071788679257944,0.4644265933240915],[0.4049271448617068,0.4644265933240915],[0.611776552412223,0.76402195296293],[0.611776552412223,0.7976637782492555],[0.611776552412223,0.4644265933240915],[0.6314946864402609,0.4644265933240915],[0.27420827225574895,0.27420827225574895],[0.27420827225574895,0.24488037792617978],[0.27420827225574895,0.08710036054342263],[0.27420827225574895,0.13366888995334028],[0.27420827225574895,0.08155316871340108],[0.27420827225574895,0.33055713136062487],[0.27420827225574895,0.20835868980238664],[0.27420827225574895,0.4644265933240915],[0.2669192248469852,0.4644265933240915],[0.7217819685043624,0.6904226612863027],[0.7217819685043624,0.4644265933240915],[0.4388313367196233,0.45967477884167124],[0.4388313367196233,0.4644265933240915],[0.6210846640660135,0.4644265933240915],[0.2545198557999168,0.4644265933240915],[0.2545198557999168,0.30898003112970135],[0.6904226612863027,0.7941581650806059],[0.6904226612863027,0.8045534864851885],[0.6904226612863027,0.5993878107889014],[0.6904226612863027,0.7088679714710461],[0.6904226612863027,0.6891849194688708],[0.6904226612863027,0.6852702632643184],[0.6904226612863027,0.6318110145695137],[0.6904226612863027,0.8134193274559792],[0.6904226612863027,0.6355543158364171],[0.6904226612863027,0.7452829125960218],[0.6904226612863027,0.7527254406328888],[0.6904226612863027,0.4644265933240915],[0.6904226612863027,0.7310000899182425],[0.6904226612863027,0.7311120412458607],[0.6904226612863027,0.7510563490127009],[0.6904226612863027,0.6034712410443259],[0.6904226612863027,0.6500322109180686],[0.6904226612863027,0.7890076050183971],[0.6904226612863027,0.7211525475839037],[0.6904226612863027,0.6424909535271728],[0.6904226612863027,0.6861984278986488],[0.6904226612863027,0.7968717860750494],[0.19715153275207803,0.1394052277779232],[0.19715153275207803,0.4644265933240915],[0.2717753269630601,0.27600443680581555],[0.2717753269630601,0.4644265933240915],[0.5371251862374531,0.4644265933240915],[0.5371251862374531,0.5210969333616969],[0.5371251862374531,0.5371251862374531],[0.2576482912815104,0.08710036054342263],[0.2576482912815104,0.4644265933240915],[0.2576482912815104,0.33055713136062487],[0.2576482912815104,0.08155316871340108],[0.30899557178097814,0.4644265933240915],[0.24488037792617978,0.20835868980238664],[0.24488037792617978,0.4644265933240915],[0.24488037792617978,0.33055713136062487],[0.24488037792617978,0.13366888995334028],[0.18497468648403095,0.4644265933240915],[0.38789225754056694,0.4058441348357288],[0.38789225754056694,0.4644265933240915],[0.38789225754056694,0.4285635536904042],[0.24740263237564292,0.27007728591199187],[0.24740263237564292,0.4644265933240915],[0.6852702632643184,0.6500322109180686],[0.6852702632643184,0.4644265933240915],[0.45743011437986236,0.5051474678294182],[0.45743011437986236,0.43293099809978064],[0.45743011437986236,0.4644265933240915],[0.37439611908434434,0.33055713136062487],[0.37439611908434434,0.4644265933240915],[0.41747798898431937,0.4644265933240915],[0.41747798898431937,0.33055713136062487],[0.08710036054342263,0.16173073020245696],[0.33055713136062487,0.388417647624072],[0.33055713136062487,0.2030813546636055],[0.33055713136062487,0.2402041690827045],[0.33055713136062487,0.4644265933240915],[0.33055713136062487,0.3694577704292969],[0.33055713136062487,0.20835868980238664],[0.579640533495896,0.4644265933240915],[0.5059293859544223,0.48453723694984574],[0.5059293859544223,0.4644265933240915],[0.6244488551073897,0.5999866263324974],[0.6244488551073897,0.4644265933240915],[0.35091370069078043,0.4644265933240915],[0.11577436713543154,0.4644265933240915],[0.3975901164304786,0.4644265933240915],[0.2678319918497413,0.30604823057945385],[0.2678319918497413,0.3694577704292969],[0.2678319918497413,0.4644265933240915],[0.2678319918497413,0.39651518609686176],[0.444027353342111,0.4644265933240915],[0.27328737251276447,0.4644265933240915],[0.3076447431098306,0.4644265933240915],[0.7455202993113186,0.4644265933240915],[0.6535846371981258,0.7462947759422153],[0.6535846371981258,0.5269626819567745],[0.6535846371981258,0.4644265933240915],[0.6535846371981258,0.6535846371981258],[0.6535846371981258,0.7237466047750631],[0.7890076050183971,0.4644265933240915],[0.08797376753696164,0.4644265933240915],[0.08797376753696164,0.0],[0.3529082566550165,0.4644265933240915],[0.35319012821601903,0.4644265933240915],[0.22008850143988615,0.27007728591199187],[0.22008850143988615,0.4644265933240915],[0.5392331611303647,0.4644265933240915],[0.5392331611303647,0.5476713970682007],[0.5392331611303647,0.5392331611303647],[0.16173073020245696,0.4644265933240915],[0.16173073020245696,0.08155316871340108],[0.5145525649499937,0.4644265933240915],[0.5671348921371102,0.5999866263324974],[0.5671348921371102,0.4644265933240915],[0.5671348921371102,0.6085669803114362],[0.5671348921371102,0.5993878107889014],[0.7879215815685586,0.4644265933240915],[0.3011411395091858,0.4644265933240915],[0.7976637782492555,0.4644265933240915],[0.7976637782492555,0.9633874721979587],[0.7976637782492555,0.9379828427440832],[0.4285635536904042,0.4058441348357288],[0.4285635536904042,0.4644265933240915],[0.15031846957277747,0.4644265933240915],[0.13291619607318123,0.1331731863459878],[0.13291619607318123,0.4644265933240915],[0.5999866263324974,0.4644265933240915],[0.4607304950314831,0.5146859906287252],[0.4607304950314831,0.42195595902769334],[0.4607304950314831,0.4644265933240915],[0.6586521543222597,0.4644265933240915],[0.527730855490007,0.5146859906287252],[0.527730855490007,0.4644265933240915],[0.1324193910282083,0.4644265933240915],[0.1324193910282083,0.060307632698421966],[0.1324193910282083,0.15065641730078955],[0.6797349754383587,0.4644265933240915],[0.6399926936563858,0.4644265933240915],[0.4633349136726842,0.4644265933240915],[0.4412738654608661,0.45967477884167124],[0.4412738654608661,0.4644265933240915],[0.15968467616016585,0.4644265933240915],[0.21223921744449123,0.4644265933240915],[0.5476713970682007,0.4644265933240915],[0.5476713970682007,0.5140240042309399],[0.5476713970682007,0.5476713970682007],[0.32060758787424637,0.3694577704292969],[0.32060758787424637,0.33364665792653025],[0.32060758787424637,0.4644265933240915],[0.15065641730078955,0.4644265933240915],[0.15065641730078955,0.060307632698421966],[0.6891849194688708,0.5993878107889014],[0.6891849194688708,0.4644265933240915],[0.6855416614287914,0.6762104750895189],[0.6855416614287914,0.6177264302342022],[0.6855416614287914,0.4644265933240915],[0.7117538031098491,0.4644265933240915],[0.4710846877627917,0.4644265933240915],[0.4710846877627917,0.5140240042309399],[0.649129723689199,0.5197629058866543],[0.649129723689199,0.4644265933240915],[0.468087975974438,0.46542373082288824],[0.468087975974438,0.43293099809978064],[0.468087975974438,0.4806671826599098],[0.32447229181159315,0.4644265933240915],[0.6762104750895189,0.6177264302342022],[0.6762104750895189,0.6344026112713228],[0.6762104750895189,0.6598473043084586],[0.33364665792653025,0.3694577704292969],[0.33364665792653025,0.33364665792653025],[0.33364665792653025,0.4644265933240915],[0.33364665792653025,0.43293099809978064],[0.2402041690827045,0.4644265933240915],[0.5644052729302718,0.4644265933240915],[0.46542373082288824,0.4644265933240915],[0.4812389911319088,0.4644265933240915],[0.6034712410443259,0.6034712410443259],[0.6034712410443259,0.7146508825410139],[0.6034712410443259,0.6980098944564919],[0.6034712410443259,0.6580949110185261],[0.6034712410443259,0.6500322109180686],[0.6034712410443259,0.5993878107889014],[0.6034712410443259,0.5855399018260025],[0.6034712410443259,0.4644265933240915],[0.20490598362692178,0.4644265933240915],[0.4722671490732712,0.4644265933240915],[0.5452245805654169,0.4644265933240915],[0.05477044416658729,0.13627939091125882],[0.9633874721979587,0.8321147999922618],[0.5269626819567745,0.5162309872640686],[0.15419286639427188,0.4644265933240915],[0.5993878107889014,0.6085669803114362],[0.5993878107889014,0.6355543158364171],[0.5993878107889014,0.6861984278986488],[0.5993878107889014,0.4644265933240915],[0.5993878107889014,0.5993878107889014],[0.5993878107889014,0.6318110145695137],[0.6318110145695137,0.4644265933240915],[0.6318110145695137,0.6085669803114362],[0.7923960630635131,0.4644265933240915],[0.48090941535909565,0.46463118186664565],[0.48090941535909565,0.4644265933240915],[0.5855399018260025,0.4644265933240915],[0.7726065575391908,0.7371297618622412],[0.7726065575391908,0.4644265933240915],[0.608632763773559,0.4644265933240915],[0.7045574966363791,0.4644265933240915],[0.6861984278986488,0.4644265933240915],[0.45250458946179123,0.3694577704292969],[0.45250458946179123,0.5782368882477646],[0.45250458946179123,0.4644265933240915],[0.45250458946179123,0.45250458946179123],[0.5934927805921262,0.6831448909424619],[0.5934927805921262,0.4644265933240915],[0.6980098944564919,0.6980098944564919],[0.6980098944564919,0.4644265933240915],[0.6980098944564919,0.7146508825410139],[0.6598473043084586,0.6177264302342022],[0.6598473043084586,0.4644265933240915],[0.3662196950547806,0.4644265933240915],[0.6946543424032136,0.4644265933240915],[0.41254406548995315,0.3756071601170002],[0.41254406548995315,0.4644265933240915],[0.5197629058866543,0.5324797516965024],[0.5197629058866543,0.4644265933240915],[0.3784550836111945,0.27007728591199187],[0.3784550836111945,0.4644265933240915],[0.13627939091125882,0.4644265933240915],[0.6355543158364171,0.4644265933240915],[0.8086494090192747,0.4644265933240915],[0.44720670796608125,0.4644265933240915],[0.7444164662901014,0.4644265933240915],[0.8045534864851885,0.4644265933240915],[0.5696401069015957,0.4644265933240915],[0.7580853182147079,0.4644265933240915],[0.45955818521324665,0.4644265933240915],[0.5283913703426419,0.4644265933240915],[0.6594916630702127,0.4644265933240915],[0.70196767347563,0.5782368882477646],[0.70196767347563,0.4644265933240915],[0.20913385755198127,0.4644265933240915],[0.3788913931950467,0.4644265933240915],[0.798598861653098,0.4644265933240915],[0.5681739762661152,0.4644265933240915],[0.5681739762661152,0.48453723694984574],[0.6344026112713228,0.6177264302342022],[0.6344026112713228,0.4644265933240915],[0.30113802493274033,0.4644265933240915],[0.34976785016864254,0.4644265933240915],[0.13857379959444122,0.4644265933240915],[0.7527254406328888,0.4644265933240915],[0.42195595902769334,0.4644265933240915],[0.7311120412458607,0.4644265933240915],[0.6177264302342022,0.4644265933240915],[0.43293099809978064,0.3694577704292969],[0.43293099809978064,0.4644265933240915],[0.1486026017777609,0.4644265933240915],[0.6383001874738673,0.4644265933240915],[0.24086342723742865,0.4644265933240915],[0.6500322109180686,0.4644265933240915],[0.6500322109180686,0.6424909535271728],[0.3393929547320893,0.4644265933240915],[0.5146859906287252,0.5586600444464479],[0.5146859906287252,0.5782368882477646],[0.5146859906287252,0.4644265933240915],[0.5146859906287252,0.5146859906287252],[0.5146859906287252,0.5324797516965024],[0.7371297618622412,0.7595767097293317],[0.7371297618622412,0.4644265933240915],[0.8134193274559792,0.4644265933240915],[0.7621605629428484,0.4644265933240915],[0.7310000899182425,0.4644265933240915],[0.7595767097293317,0.4644265933240915],[0.48453723694984574,0.45967477884167124],[0.48453723694984574,0.4644265933240915],[0.48453723694984574,0.5140240042309399],[0.637727285059424,0.4644265933240915],[0.6797909978021992,0.4644265933240915],[0.30604823057945385,0.388417647624072],[0.30604823057945385,0.3694577704292969],[0.30604823057945385,0.30604823057945385],[0.30604823057945385,0.4644265933240915],[0.40258749171673497,0.4644265933240915],[0.5514117581134003,0.5514117581134003],[0.5514117581134003,0.4644265933240915],[0.6074850831813735,0.4644265933240915],[0.4056395478047269,0.4644265933240915],[0.6085669803114362,0.4644265933240915],[0.16016274624505258,0.4644265933240915],[0.6017510295555455,0.4644265933240915],[0.46463118186664565,0.4644265933240915],[0.19731172210428197,0.4644265933240915],[0.35372947827716217,0.4644265933240915],[0.2030813546636055,0.4644265933240915],[0.5586600444464479,0.4644265933240915],[0.7510563490127009,0.4644265933240915],[0.7968717860750494,0.4644265933240915],[0.9379828427440832,0.76402195296293],[0.48046567508521565,0.3694577704292969],[0.48046567508521565,0.4644265933240915],[0.48046567508521565,0.39651518609686176],[0.24532755355273295,0.3694577704292969],[0.24532755355273295,0.4644265933240915],[0.7941581650806059,0.4644265933240915],[0.39723488268211155,0.4644265933240915],[0.3698943178774708,0.4644265933240915],[0.10224652605134109,0.4644265933240915],[0.6580949110185261,0.4644265933240915],[0.4806671826599098,0.4644265933240915],[0.8321147999922618,0.4644265933240915],[0.15869576594179613,0.4644265933240915],[0.3560301340694253,0.4644265933240915],[0.7088679714710461,0.4644265933240915],[0.5324797516965024,0.4644265933240915],[0.5324797516965024,0.5324797516965024],[0.42664086597482787,0.4644265933240915],[0.12389046732526335,0.4644265933240915],[0.3694577704292969,0.4030728953171881],[0.3694577704292969,0.388417647624072],[0.3694577704292969,0.3694577704292969],[0.3694577704292969,0.4644265933240915],[0.3694577704292969,0.39651518609686176],[0.1331731863459878,0.4644265933240915],[0.30898003112970135,0.4644265933240915],[0.5750826143843594,0.4644265933240915],[0.27007728591199187,0.4644265933240915],[0.7452829125960218,0.4644265933240915],[0.28967045807142405,0.4644265933240915],[0.5756934843630539,0.4644265933240915],[0.4435919918519365,0.4644265933240915],[0.4644265933240915,0.29959065960548625],[0.4644265933240915,0.6386468337920613],[0.4644265933240915,0.42038396057478256],[0.4644265933240915,0.5116991430043761],[0.4644265933240915,0.697774703423627],[0.4644265933240915,0.40545765038305975],[0.4644265933240915,0.4644265933240915],[0.4644265933240915,0.21337252010202712],[0.4644265933240915,0.5140240042309399],[0.4644265933240915,0.7211525475839037],[0.4644265933240915,0.5782368882477646],[0.4644265933240915,0.20835868980238664],[0.4644265933240915,0.30163224913901937],[0.4644265933240915,0.4525379216453794],[0.4644265933240915,0.13741285746048232],[0.4644265933240915,0.4030728953171881],[0.4644265933240915,0.76402195296293],[0.4644265933240915,0.45967477884167124],[0.4644265933240915,0.32365947792215594],[0.4644265933240915,0.5162309872640686],[0.4644265933240915,0.27600443680581555],[0.4644265933240915,0.388417647624072],[0.4644265933240915,0.37719691319932325],[0.4644265933240915,0.7146508825410139],[0.4644265933240915,0.5210969333616969],[0.4644265933240915,0.4058441348357288],[0.4644265933240915,0.8528721121156967],[0.4644265933240915,0.6424909535271728],[0.4644265933240915,0.13948597135490573],[0.4644265933240915,0.3015005471981137],[0.4644265933240915,0.39651518609686176],[0.4644265933240915,0.35602008500293675],[0.5782368882477646,0.5782368882477646],[0.20835868980238664,0.13366888995334028],[0.45967477884167124,0.45967477884167124],[0.7113211289585225,0.6386468337920613],[0.5210969333616969,0.5210969333616969],[0.6386468337920613,0.6386468337920613],[0.4058441348357288,0.4058441348357288]]}},\"id\":\"ab0d71df-1008-4bd0-8ee8-b60394cda912\",\"type\":\"ColumnDataSource\"},{\"attributes\":{\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"}},\"id\":\"5adc6f1b-6f56-486a-9aee-20ea3f45dd55\",\"type\":\"ResetTool\"},{\"attributes\":{},\"id\":\"11e0143f-ef0b-4d47-9e99-898ba2130987\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"line_alpha\":{\"value\":0.1},\"line_color\":{\"value\":\"#1f77b4\"},\"line_width\":{\"value\":1.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"1a1f89ff-65f0-49a4-a490-2938aca9f648\",\"type\":\"MultiLine\"},{\"attributes\":{\"plot\":null,\"text\":null},\"id\":\"800ff3d4-6e8f-4a0b-87a3-6bc5122f7678\",\"type\":\"Title\"},{\"attributes\":{\"formatter\":{\"id\":\"f26e124b-b0b4-493f-b007-5e80685078a5\",\"type\":\"BasicTickFormatter\"},\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"9720aeca-f949-4a69-a0d8-7d5eed928666\",\"type\":\"BasicTicker\"}},\"id\":\"e43c1d7a-7174-4725-a05c-aecb2ecf6c29\",\"type\":\"LinearAxis\"},{\"attributes\":{\"callback\":null,\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"}},\"id\":\"dee07948-35c4-4872-a632-62aedee74dcf\",\"type\":\"TapTool\"},{\"attributes\":{\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"9720aeca-f949-4a69-a0d8-7d5eed928666\",\"type\":\"BasicTicker\"}},\"id\":\"7cddbcbd-7485-449e-9f4f-5bd9d4f56156\",\"type\":\"Grid\"},{\"attributes\":{\"line_alpha\":{\"field\":\"alphas\"},\"line_color\":{\"value\":\"navy\"},\"line_width\":{\"value\":1.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"48a529e0-49c1-4985-8d95-028503b36abd\",\"type\":\"MultiLine\"},{\"attributes\":{\"overlay\":{\"id\":\"e291121b-79c6-40c5-b081-7371926c685a\",\"type\":\"BoxAnnotation\"},\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"}},\"id\":\"60156367-73d9-4892-8324-eaa5c2ee576f\",\"type\":\"BoxZoomTool\"},{\"attributes\":{\"formatter\":{\"id\":\"11e0143f-ef0b-4d47-9e99-898ba2130987\",\"type\":\"BasicTickFormatter\"},\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"20197a57-7180-4dba-a3f8-12a57f1aedd1\",\"type\":\"BasicTicker\"}},\"id\":\"c82cd6a8-c815-4d2a-848e-1e6052945a3c\",\"type\":\"LinearAxis\"},{\"attributes\":{\"callback\":null,\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"tooltips\":[[\"name\",\"@name\"],[\"id\",\"$index\"]]},\"id\":\"145c024b-5fa5-4086-871c-cd25f1d1ac7a\",\"type\":\"HoverTool\"}],\"root_ids\":[\"5d5b7b93-ed51-44de-a816-c29d492b70ab\"]},\"title\":\"Bokeh Application\",\"version\":\"0.12.0\"}};\n",
       "            var render_items = [{\"docid\":\"652e6c5c-946c-49cb-80d4-2d945130ba16\",\"elementid\":\"6ed1c7a1-119e-4d72-9657-d5d894380eb3\",\"modelid\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"notebook_comms_target\":\"8a69764c-affb-456f-92bf-73012e4a8311\"}];\n",
       "            \n",
       "            Bokeh.embed.embed_items(docs_json, render_items);\n",
       "        });\n",
       "      },\n",
       "      function(Bokeh) {\n",
       "      }\n",
       "    ];\n",
       "  \n",
       "    function run_inline_js() {\n",
       "      for (var i = 0; i < inline_js.length; i++) {\n",
       "        inline_js[i](window.Bokeh);\n",
       "      }\n",
       "    }\n",
       "  \n",
       "    if (window._bokeh_is_loading === 0) {\n",
       "      console.log(\"Bokeh: BokehJS loaded, going straight to plotting\");\n",
       "      run_inline_js();\n",
       "    } else {\n",
       "      load_libs(js_urls, function() {\n",
       "        console.log(\"Bokeh: BokehJS plotting callback run at\", now());\n",
       "        run_inline_js();\n",
       "      });\n",
       "    }\n",
       "  }(this));\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<p><code>&lt;Bokeh Notebook handle for <strong>In[7]</strong>&gt;</code></p>"
      ],
      "text/plain": [
       "<bokeh.io._CommsHandle at 0x106333be0>"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "r_lines = plot.multi_line('xs', 'ys', line_width=1.5,\n",
    "                          alpha='alphas', color='navy',\n",
    "                          source=lines_source)\n",
    "show(plot)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# Step 4: Visualize properties\n",
    "\n",
    "### Add Clustering and Centrality to ColumnDataSource"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {
    "collapsed": false,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'centrality'"
      ]
     },
     "execution_count": 13,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "centrality =\\\n",
    "    networkx.algorithms.centrality.betweenness_centrality(network)\n",
    "# first element are nodes again\n",
    "_, nodes_centrality = zip(*sorted(centrality.items()))\n",
    "max_centraliy = max(nodes_centrality)\n",
    "nodes_source.add([7 + 10 * t / max_centraliy\n",
    "                  for t in nodes_centrality],\n",
    "                 'centrality')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {
    "collapsed": false,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'community_color'"
      ]
     },
     "execution_count": 9,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "import community # python-louvain\n",
    "partition = community.best_partition(network)\n",
    "p_, nodes_community = zip(*sorted(partition.items()))\n",
    "nodes_source.add(nodes_community, 'community')\n",
    "community_colors = ['#e41a1c','#377eb8','#4daf4a','#984ea3','#ff7f00','#ffff33','#a65628', '#b3cde3','#ccebc5','#decbe4','#fed9a6','#ffffcc','#e5d8bd','#fddaec','#1b9e77','#d95f02','#7570b3','#e7298a','#66a61e','#e6ab02','#a6761d','#666666']\n",
    "nodes_source.add([community_colors[t % len(community_colors)]\n",
    "                  for t in nodes_community],\n",
    "                 'community_color')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "### Update the Renderer"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "collapsed": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [],
   "source": [
    "r_circles.glyph.size = 'centrality'\n",
    "r_circles.glyph.fill_color = 'community_color'"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {
    "collapsed": false,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "\n",
       "    <div class=\"bk-root\">\n",
       "        <div class=\"plotdiv\" id=\"69439cfc-98f6-4085-a625-e6540faa5863\"></div>\n",
       "    </div>\n",
       "<script type=\"text/javascript\">\n",
       "  \n",
       "  (function(global) {\n",
       "    function now() {\n",
       "      return new Date();\n",
       "    }\n",
       "  \n",
       "    if (typeof (window._bokeh_onload_callbacks) === \"undefined\") {\n",
       "      window._bokeh_onload_callbacks = [];\n",
       "    }\n",
       "  \n",
       "    function run_callbacks() {\n",
       "      window._bokeh_onload_callbacks.forEach(function(callback) { callback() });\n",
       "      delete window._bokeh_onload_callbacks\n",
       "      console.info(\"Bokeh: all callbacks have finished\");\n",
       "    }\n",
       "  \n",
       "    function load_libs(js_urls, callback) {\n",
       "      window._bokeh_onload_callbacks.push(callback);\n",
       "      if (window._bokeh_is_loading > 0) {\n",
       "        console.log(\"Bokeh: BokehJS is being loaded, scheduling callback at\", now());\n",
       "        return null;\n",
       "      }\n",
       "      if (js_urls == null || js_urls.length === 0) {\n",
       "        run_callbacks();\n",
       "        return null;\n",
       "      }\n",
       "      console.log(\"Bokeh: BokehJS not loaded, scheduling load and callback at\", now());\n",
       "      window._bokeh_is_loading = js_urls.length;\n",
       "      for (var i = 0; i < js_urls.length; i++) {\n",
       "        var url = js_urls[i];\n",
       "        var s = document.createElement('script');\n",
       "        s.src = url;\n",
       "        s.async = false;\n",
       "        s.onreadystatechange = s.onload = function() {\n",
       "          window._bokeh_is_loading--;\n",
       "          if (window._bokeh_is_loading === 0) {\n",
       "            console.log(\"Bokeh: all BokehJS libraries loaded\");\n",
       "            run_callbacks()\n",
       "          }\n",
       "        };\n",
       "        s.onerror = function() {\n",
       "          console.warn(\"failed to load library \" + url);\n",
       "        };\n",
       "        console.log(\"Bokeh: injecting script tag for BokehJS library: \", url);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      }\n",
       "    };var element = document.getElementById(\"69439cfc-98f6-4085-a625-e6540faa5863\");\n",
       "    if (element == null) {\n",
       "      console.log(\"Bokeh: ERROR: autoload.js configured with elementid '69439cfc-98f6-4085-a625-e6540faa5863' but no matching script tag was found. \")\n",
       "      return false;\n",
       "    }\n",
       "  \n",
       "    var js_urls = [];\n",
       "  \n",
       "    var inline_js = [\n",
       "      function(Bokeh) {\n",
       "        Bokeh.$(function() {\n",
       "            var docs_json = {\"580c0d09-670b-4531-8280-a3cb25b25660\":{\"roots\":{\"references\":[{\"attributes\":{\"callback\":null,\"column_names\":[\"name\",\"x\",\"y\",\"centrality\",\"community\",\"community_color\"],\"data\":{\"centrality\":[7.0,7.0,7.0,7.0,7.0,7.060060252479778,7.022438112400422,7.038081470677081,7.0,7.0036340326997735,7.006907835152465,7.000306176323245,7.0,7.0,7.0,7.0,7.007307920366143,7.0000666808689465,7.015069876381858,7.0,7.000500106517097,7.0,7.0,7.031757812289561,7.020170702807231,7.001050223685904,7.0,7.0,7.0,7.0,7.045409671752413,7.014247562653128,7.0036340326997735,7.0,7.014121198745192,7.000058345760328,7.00008946349917,7.0,7.022426876241012,7.0,7.0,7.0,7.001651542236223,7.014121198745192,7.0,7.0,7.001771004547963,7.011575798849074,7.0,7.045409671752413,7.0,7.0036340326997735,7.0,7.0,7.030066213431863,7.0,7.0,7.0036340326997735,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.000178371324432,7.0,7.0,7.0,7.022654825224497,7.0,7.0,7.0,7.0,7.0,7.0,7.001170249250007,7.0,7.0,7.022654825224497,7.0,7.0,7.006633594219344,7.0,7.0,7.007009450521386,7.0,7.000025005325855,7.045409671752413,7.0,7.000431480789473,7.0,7.054214136668452,7.0,7.0,7.045409671752413,7.0,7.015103216816331,7.0,7.0,7.0,7.0147491102611035,7.0,7.000033340434473,7.000783500210119,7.0,7.0,7.0,7.000266723475785,7.000026672347579,7.0,7.0,7.000325069236113,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.045409671752413,7.0,7.000025005325855,7.0,7.0,7.000871018850611,7.0,7.0,7.0,7.0,7.011172379591948,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.000448666989624,7.000033340434473,7.0,7.034293970899069,7.0,7.007247993734294,7.045409671752413,7.0,7.000553451212254,7.045409671752413,7.0,7.0,7.0,7.006401838989109,7.0,7.0,7.0,7.00005001065171,7.0,7.0,7.011172379591948,7.045409671752413,7.0,7.0,7.0,7.055871536681236,7.000366744779204,7.0,7.038081470677081,7.111621876664924,7.000325069236113,7.0,7.0,7.041840346566972,7.00005001065171,7.00040730897448,7.0146505807273645,7.0,7.000556785255702,7.0320448734802055,7.0,7.0,7.0,7.000033340434473,7.0,7.0,7.0,7.0,7.045409671752413,7.0,7.0,7.00848547461329,7.0,7.0,7.0,7.045409671752413,7.006070974387609,7.0029170657468365,7.0,7.0,7.0,7.006800315068782,7.0,7.000650138472226,7.007730937409915,7.0,7.052267496253168,7.0,7.006132690754453,7.007161252222707,7.090719322201407,7.014931412547175,7.000242908879732,7.0,7.001500319551291,7.018276886828491,7.002100447371808,7.000083351086182,7.000033340434473,7.019944143563634,7.0,7.0,7.0,7.0,7.0,7.0,7.015069876381858,7.02964112289233,7.045409671752413,7.045409671752413,7.0,7.000150031955129,7.045504258998006,7.0,7.0,7.0,7.00005001065171,7.0,7.007247993734294,7.045524140577437,7.000180038346155,7.0,17.0,7.0,7.0,7.0,7.0,7.0001833723896025,7.0,7.0,7.0,7.000479322869634,7.0,7.0,7.0,7.0,7.0,7.0,7.006070974387609,7.045409671752413,7.0,7.0,7.0,7.0,7.022654825224497,7.0036340326997735,7.0,7.020601243547817,7.006645034374414,7.0036340326997735,7.043181699595062,7.0,7.0,7.001350287596162,7.014119201980407,7.0,7.0036340326997735,7.0,7.0,7.000700149123936,7.0,7.00005001065171,7.045409671752413,7.021041472940489,7.00005001065171,7.090719322201407,7.0,7.000075015977565,7.0,7.090719322201407,7.0036340326997735,7.0,7.0,7.0,7.006384058145711,7.0,7.0,7.0,7.0036340326997735,7.007730937409915,7.000562619831734,7.014059633015827,7.0,7.006070974387609,7.0,7.022654825224497,7.0,7.0,7.00005001065171,7.0036340326997735,7.0,7.0,7.0,7.0,7.000100021303419,7.0,7.0,7.00005001065171,7.0,7.000771354766132,7.0,7.001400298247872,7.001169557571996,7.246365619056506,7.0,7.0,7.0,7.0,7.0147012307079235,7.0,7.0,7.0,7.031932767562132,7.0,7.0,7.000908838261034,7.0,7.0,7.0,7.000306176323245,7.0,7.0,7.0,7.022654825224497,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.000033340434473,7.0,7.0225881443555505,7.0,7.014059633015827,7.0,7.006070974387609,7.0,7.0,7.182322772106069,7.038081470677081,7.0,7.045409671752413,7.0,7.0,7.000965810102358,7.0,7.0,7.090719322201407,7.0,7.0,7.007975058347838,7.0,7.0,7.0,7.0,7.0,7.0,7.000250053258548,7.0,7.000666808689463,7.0,7.0,7.0,7.0,7.0,7.000150031955129,7.0,7.0,7.0,7.0,7.022654825224497,7.0,7.021447335854659,7.000500106517097,7.0,7.006800315068782,7.017364689826791,7.0,7.022654825224497,7.0,7.014121198745192,7.0,7.006132690754453,7.067977800191236,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.0,7.022654825224497,7.006070974387609,7.0,7.0,7.015159541944267,7.0,7.012823480189068,7.0,7.0,7.000100021303419,7.0,7.0,7.006857824500756,7.0,7.0,7.0,7.0,7.0196357445447575,7.000100021303419,7.0,7.0,7.0,7.0,7.052540863340081,7.0,7.014164211566945,7.000375079887823,7.188785982808666,7.0012393981770895,7.0107485194732115,7.0,7.009446971499234],\"community\":[3,1,2,1,1,8,2,10,16,0,17,5,28,1,26,24,17,8,7,1,6,1,1,8,8,1,1,13,17,8,15,5,0,0,5,27,0,5,27,1,0,1,1,5,1,1,1,2,9,33,6,0,0,1,9,1,1,0,1,34,0,9,0,1,8,6,6,0,1,1,1,1,17,5,1,8,1,31,0,13,23,1,0,1,1,17,1,11,1,14,4,1,0,1,9,13,1,1,3,1,0,16,10,20,8,7,9,21,14,5,17,5,1,1,1,1,0,0,1,9,1,1,0,0,1,1,3,1,8,9,18,1,9,1,1,14,1,3,0,17,2,1,1,17,3,1,1,1,1,0,1,6,1,2,1,3,30,14,13,25,9,0,1,13,1,8,3,1,1,1,2,28,0,1,1,9,6,1,10,13,6,1,1,8,1,13,8,32,13,14,13,1,10,16,1,1,1,0,14,0,8,8,3,1,1,1,4,9,1,1,1,1,1,17,0,1,1,1,13,17,22,0,3,3,0,4,10,27,7,3,0,6,1,0,3,17,7,9,29,32,1,1,27,1,1,9,1,1,3,13,9,17,1,24,3,3,3,6,18,1,0,13,20,0,1,1,3,14,4,34,1,1,13,19,12,0,1,13,1,0,0,22,15,9,5,1,0,1,3,8,30,1,1,13,1,0,1,8,1,24,0,1,1,8,8,1,1,13,0,0,4,0,23,4,1,19,1,3,1,0,9,17,0,1,1,1,3,1,1,8,1,1,0,3,8,1,9,1,5,1,1,31,14,8,1,3,21,1,17,5,1,1,0,19,1,1,1,8,0,1,15,16,1,27,14,0,1,4,14,1,14,10,1,1,1,17,8,1,0,21,17,26,10,1,29,1,3,1,1,1,33,8,5,1,14,5,0,13,8,1,1,1,11,1,1,1,1,14,13,5,12,12,5,1,13,17,3,13,11,1,1,13,22,15,31,4,1,8,0,1,3,0,14,1,1,1,17,2,25,1,1,3,9,1,1,1,0,0,1,5,3,5,27,13,1,17],\"community_color\":[\"#984ea3\",\"#377eb8\",\"#4daf4a\",\"#377eb8\",\"#377eb8\",\"#ccebc5\",\"#4daf4a\",\"#fed9a6\",\"#7570b3\",\"#e41a1c\",\"#e7298a\",\"#ffff33\",\"#a65628\",\"#377eb8\",\"#ff7f00\",\"#4daf4a\",\"#e7298a\",\"#ccebc5\",\"#b3cde3\",\"#377eb8\",\"#a65628\",\"#377eb8\",\"#377eb8\",\"#ccebc5\",\"#ccebc5\",\"#377eb8\",\"#377eb8\",\"#fddaec\",\"#e7298a\",\"#ccebc5\",\"#d95f02\",\"#ffff33\",\"#e41a1c\",\"#e41a1c\",\"#ffff33\",\"#ffff33\",\"#e41a1c\",\"#ffff33\",\"#ffff33\",\"#377eb8\",\"#e41a1c\",\"#377eb8\",\"#377eb8\",\"#ffff33\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#4daf4a\",\"#decbe4\",\"#ffffcc\",\"#a65628\",\"#e41a1c\",\"#e41a1c\",\"#377eb8\",\"#decbe4\",\"#377eb8\",\"#377eb8\",\"#e41a1c\",\"#377eb8\",\"#e5d8bd\",\"#e41a1c\",\"#decbe4\",\"#e41a1c\",\"#377eb8\",\"#ccebc5\",\"#a65628\",\"#a65628\",\"#e41a1c\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#e7298a\",\"#ffff33\",\"#377eb8\",\"#ccebc5\",\"#377eb8\",\"#decbe4\",\"#e41a1c\",\"#fddaec\",\"#377eb8\",\"#377eb8\",\"#e41a1c\",\"#377eb8\",\"#377eb8\",\"#e7298a\",\"#377eb8\",\"#ffffcc\",\"#377eb8\",\"#1b9e77\",\"#ff7f00\",\"#377eb8\",\"#e41a1c\",\"#377eb8\",\"#decbe4\",\"#fddaec\",\"#377eb8\",\"#377eb8\",\"#984ea3\",\"#377eb8\",\"#e41a1c\",\"#7570b3\",\"#fed9a6\",\"#a6761d\",\"#ccebc5\",\"#b3cde3\",\"#decbe4\",\"#666666\",\"#1b9e77\",\"#ffff33\",\"#e7298a\",\"#ffff33\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#e41a1c\",\"#e41a1c\",\"#377eb8\",\"#decbe4\",\"#377eb8\",\"#377eb8\",\"#e41a1c\",\"#e41a1c\",\"#377eb8\",\"#377eb8\",\"#984ea3\",\"#377eb8\",\"#ccebc5\",\"#decbe4\",\"#66a61e\",\"#377eb8\",\"#decbe4\",\"#377eb8\",\"#377eb8\",\"#1b9e77\",\"#377eb8\",\"#984ea3\",\"#e41a1c\",\"#e7298a\",\"#4daf4a\",\"#377eb8\",\"#377eb8\",\"#e7298a\",\"#984ea3\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#e41a1c\",\"#377eb8\",\"#a65628\",\"#377eb8\",\"#4daf4a\",\"#377eb8\",\"#984ea3\",\"#ccebc5\",\"#1b9e77\",\"#fddaec\",\"#984ea3\",\"#decbe4\",\"#e41a1c\",\"#377eb8\",\"#fddaec\",\"#377eb8\",\"#ccebc5\",\"#984ea3\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#4daf4a\",\"#a65628\",\"#e41a1c\",\"#377eb8\",\"#377eb8\",\"#decbe4\",\"#a65628\",\"#377eb8\",\"#fed9a6\",\"#fddaec\",\"#a65628\",\"#377eb8\",\"#377eb8\",\"#ccebc5\",\"#377eb8\",\"#fddaec\",\"#ccebc5\",\"#fed9a6\",\"#fddaec\",\"#1b9e77\",\"#fddaec\",\"#377eb8\",\"#fed9a6\",\"#7570b3\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#e41a1c\",\"#1b9e77\",\"#e41a1c\",\"#ccebc5\",\"#ccebc5\",\"#984ea3\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#ff7f00\",\"#decbe4\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#e7298a\",\"#e41a1c\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#fddaec\",\"#e7298a\",\"#e41a1c\",\"#e41a1c\",\"#984ea3\",\"#984ea3\",\"#e41a1c\",\"#ff7f00\",\"#fed9a6\",\"#ffff33\",\"#b3cde3\",\"#984ea3\",\"#e41a1c\",\"#a65628\",\"#377eb8\",\"#e41a1c\",\"#984ea3\",\"#e7298a\",\"#b3cde3\",\"#decbe4\",\"#b3cde3\",\"#fed9a6\",\"#377eb8\",\"#377eb8\",\"#ffff33\",\"#377eb8\",\"#377eb8\",\"#decbe4\",\"#377eb8\",\"#377eb8\",\"#984ea3\",\"#fddaec\",\"#decbe4\",\"#e7298a\",\"#377eb8\",\"#4daf4a\",\"#984ea3\",\"#984ea3\",\"#984ea3\",\"#a65628\",\"#66a61e\",\"#377eb8\",\"#e41a1c\",\"#fddaec\",\"#a6761d\",\"#e41a1c\",\"#377eb8\",\"#377eb8\",\"#984ea3\",\"#1b9e77\",\"#ff7f00\",\"#e5d8bd\",\"#377eb8\",\"#377eb8\",\"#fddaec\",\"#e6ab02\",\"#e5d8bd\",\"#e41a1c\",\"#377eb8\",\"#fddaec\",\"#377eb8\",\"#e41a1c\",\"#e41a1c\",\"#e41a1c\",\"#d95f02\",\"#decbe4\",\"#ffff33\",\"#377eb8\",\"#e41a1c\",\"#377eb8\",\"#984ea3\",\"#ccebc5\",\"#ccebc5\",\"#377eb8\",\"#377eb8\",\"#fddaec\",\"#377eb8\",\"#e41a1c\",\"#377eb8\",\"#ccebc5\",\"#377eb8\",\"#4daf4a\",\"#e41a1c\",\"#377eb8\",\"#377eb8\",\"#ccebc5\",\"#ccebc5\",\"#377eb8\",\"#377eb8\",\"#fddaec\",\"#e41a1c\",\"#e41a1c\",\"#ff7f00\",\"#e41a1c\",\"#377eb8\",\"#ff7f00\",\"#377eb8\",\"#e6ab02\",\"#377eb8\",\"#984ea3\",\"#377eb8\",\"#e41a1c\",\"#decbe4\",\"#e7298a\",\"#e41a1c\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#984ea3\",\"#377eb8\",\"#377eb8\",\"#ccebc5\",\"#377eb8\",\"#377eb8\",\"#e41a1c\",\"#984ea3\",\"#ccebc5\",\"#377eb8\",\"#decbe4\",\"#377eb8\",\"#ffff33\",\"#377eb8\",\"#377eb8\",\"#decbe4\",\"#1b9e77\",\"#ccebc5\",\"#377eb8\",\"#984ea3\",\"#666666\",\"#377eb8\",\"#e7298a\",\"#ffff33\",\"#377eb8\",\"#377eb8\",\"#e41a1c\",\"#e6ab02\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#ccebc5\",\"#e41a1c\",\"#377eb8\",\"#d95f02\",\"#7570b3\",\"#377eb8\",\"#ffff33\",\"#1b9e77\",\"#e41a1c\",\"#377eb8\",\"#ff7f00\",\"#1b9e77\",\"#377eb8\",\"#1b9e77\",\"#fed9a6\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#e7298a\",\"#ccebc5\",\"#377eb8\",\"#e41a1c\",\"#666666\",\"#e7298a\",\"#ff7f00\",\"#fed9a6\",\"#377eb8\",\"#b3cde3\",\"#377eb8\",\"#984ea3\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#ffffcc\",\"#ccebc5\",\"#ffff33\",\"#377eb8\",\"#1b9e77\",\"#ffff33\",\"#e41a1c\",\"#fddaec\",\"#ccebc5\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#ffffcc\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#1b9e77\",\"#fddaec\",\"#ffff33\",\"#e5d8bd\",\"#e5d8bd\",\"#ffff33\",\"#377eb8\",\"#fddaec\",\"#e7298a\",\"#984ea3\",\"#fddaec\",\"#ffffcc\",\"#377eb8\",\"#377eb8\",\"#fddaec\",\"#e41a1c\",\"#d95f02\",\"#decbe4\",\"#ff7f00\",\"#377eb8\",\"#ccebc5\",\"#e41a1c\",\"#377eb8\",\"#984ea3\",\"#e41a1c\",\"#1b9e77\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#e7298a\",\"#4daf4a\",\"#984ea3\",\"#377eb8\",\"#377eb8\",\"#984ea3\",\"#decbe4\",\"#377eb8\",\"#377eb8\",\"#377eb8\",\"#e41a1c\",\"#e41a1c\",\"#377eb8\",\"#ffff33\",\"#984ea3\",\"#ffff33\",\"#ffff33\",\"#fddaec\",\"#377eb8\",\"#e7298a\"],\"name\":[\"100Commits\",\"1337bullets\",\"1st1\",\"AartGoossens\",\"AbletonDev\",\"AdaTheShow\",\"AergNuor\",\"AishaXBello\",\"Angel_Cruijff\",\"Angelinux3000\",\"ApacheAirflow\",\"BBC\",\"BBCmicrobit\",\"BYAnalytics_en\",\"BayesianHorse\",\"BetabeersVG\",\"BlueYonderTech\",\"BokehPlots\",\"BorsLTD\",\"CAChemEorg\",\"CIBBVA\",\"Cambolc\",\"Charles_JUDITH\",\"CodingGrace\",\"ContinuumIO\",\"CriteoEng\",\"DRMacIver\",\"DaniBot_\",\"DanielDomeneL\",\"DaryaChyzhyk\",\"DasIstHerrKuska\",\"DavidjMarkey\",\"DeborahTaos12\",\"DigitYasuhara\",\"DjangoGirlsDUB\",\"DjangoGirlsEP16\",\"DjangoGirlsEc\",\"EPfestival\",\"ElnexoMarit\",\"EnCuKou\",\"EnriquetaSo\",\"EntropyFarmer\",\"Eurocentrique\",\"EventGeekie\",\"FAECTA_\",\"FernanMilla\",\"Foxinsock\",\"GMLudo\",\"Garrosa\",\"GinnyGhezzo\",\"GlaciarBlue\",\"Glenio_Oliveira\",\"GrandsCru\",\"GsBitBalear\",\"Gtzl\",\"HashtagLaToya\",\"HelloML9\",\"HokstadConsult\",\"HugoHerter\",\"IKERGUNE\",\"ITCrowdsource\",\"IcanadasM\",\"IldikoVancsa\",\"ImaneElAzlouk\",\"InspirefestHQ\",\"JOANNALETIZIA\",\"JancaStroma\",\"JasmineMcTigue\",\"Jaysinhp\",\"JohaPrime\",\"JoseOpposite\",\"JuliaDrBa\",\"KoehlerKerstin\",\"LIGO\",\"LaetitiaCarquet\",\"LatitudeFest\",\"Limejump\",\"Luen\",\"MBonell\",\"Macario8\",\"MakingLyst\",\"MarcoBasic\",\"MariaDehn\",\"MartaUhlirova\",\"MassHaste\",\"MaxBenChrist\",\"Miau_DB\",\"MiloslavPojman\",\"MirkoDziadzka\",\"MissPhilbin\",\"MongoDB\",\"MrsCaroline_C\",\"N4h_H4N\",\"NaomiCeder\",\"NegoBide\",\"NeuroSky\",\"NotANormalNerd\",\"NowLivecodingtv\",\"OReillyMedia\",\"OpenAtWE\",\"OpenStack\",\"PCalcao\",\"Patjouk\",\"Pazqo\",\"PiusNyongesa\",\"Polyconseiltech\",\"Ppuji1Ppuji\",\"PyCharm_edu\",\"PyConUK\",\"PyLadiesDub\",\"PythonEggs\",\"PythonIreland\",\"PythonSV\",\"RLerallut\",\"RTFMCelia\",\"RealPython\",\"RedHatNews\",\"Rhapsody_Girl\",\"Rico858\",\"SEReuskadi\",\"STajbakhsh\",\"SalamancaPeral\",\"SaltStack\",\"SaltStackInc\",\"SancasDev\",\"Sesivany\",\"Sophie_Talent\",\"Spanarchie\",\"SparkyCZ\",\"SrNilsson\",\"StefanTuralski\",\"StephLKim\",\"Sustatu\",\"TFConsult\",\"TeX4Publication\",\"ThePSF\",\"ThomasJWaldmann\",\"Transition\",\"Twitteze\",\"Ukerzel\",\"VictorStinner\",\"Vince92100\",\"ViniciusPach\",\"WickFelix\",\"WillingCarol\",\"WillyFrog_\",\"WuShell\",\"_JamesRG\",\"__amol__\",\"__katatonia\",\"__pamaron__\",\"_joac\",\"aRkadeFR\",\"a_soldatenko\",\"abelgvidal\",\"aborttrap6\",\"achimdomma\",\"acollard\",\"acpyss\",\"adambcn\",\"aitzol\",\"ajolo\",\"alabarga\",\"alba_caon\",\"alepernin\",\"alex_savio\",\"alison985\",\"almu_hs\",\"aloctavodia\",\"amleczko\",\"andrew_svetlov\",\"angineering\",\"angvp\",\"aniawsz\",\"aniiimaginary\",\"apueblago\",\"argenpython\",\"argonemyth\",\"asendecka\",\"asereteresa23\",\"astrojuanlu\",\"avillamarink\",\"b1n0anb\",\"b_smoke\",\"barakamediatv\",\"bayerdi\",\"bazkennedy\",\"bbc_microbit\",\"bbva\",\"ben_nuttall\",\"bilbaochess\",\"blckdt\",\"bmispelon\",\"bobcatwilson\",\"boiagames\",\"calvinhp\",\"carlosperate\",\"carohadad\",\"ccdesales\",\"cemnova\",\"ch_doig\",\"christianbarra\",\"clinker\",\"coala_analyzer\",\"cobe\",\"cobeio\",\"codekee\",\"codesyntax\",\"codingquark\",\"colmharrington\",\"connctBunker\",\"cool_python\",\"cris_calvo\",\"ctrebing\",\"d0ugal\",\"dArignac\",\"da_bjoerni\",\"dajoffe\",\"daniel7773121\",\"data_hope\",\"dbra\",\"deblike\",\"deshipu\",\"devbootcamp\",\"dfflanders\",\"diegor\",\"djangocon\",\"djangogirls\",\"docker\",\"doriczapari\",\"doughellmann\",\"douglasandrade\",\"drgarcia1986\",\"drridolfo\",\"drvinceknight\",\"dynamitts\",\"dzen\",\"eastigarraga\",\"echorand\",\"edu2b\",\"eitbAlbisteak\",\"eitbNoticias\",\"eladyonas\",\"eliasmoli\",\"eliasthorpet\",\"elmundoempresa\",\"emergya\",\"eolo999\",\"er1p\",\"erralin\",\"esletweets\",\"euro_ii\",\"europython\",\"euskalencounter\",\"evildmp\",\"exaeducation\",\"facebook\",\"facundobatista\",\"fbuontempo\",\"fedeteotini\",\"fergleiser\",\"fintxuarregi\",\"fishnets88\",\"fleioapp\",\"flubdevork\",\"flyingcircusio\",\"fmasanori\",\"freakboy3742\",\"free_control\",\"fuelex\",\"g16n\",\"gaceta_tec\",\"galindale\",\"gdsteam\",\"georgebernhard\",\"getGNU\",\"getbynder\",\"gherranzc\",\"giovannibajo\",\"globalmikem\",\"godlike64\",\"golangweekly\",\"google\",\"grupospri\",\"gwoptics\",\"hackebrot\",\"hanasulc\",\"hawkieowl\",\"helenst\",\"hendorf\",\"hpk42\",\"hundredrooms\",\"hydarscouser\",\"i4ssecurity\",\"iElectric\",\"iamtontann\",\"iferminm\",\"ifosch\",\"ikarantan\",\"iliebana\",\"imkaushalparikh\",\"indizen_corp\",\"int_lcd\",\"intel\",\"ioggstream\",\"iwangulenko\",\"j_zar21\",\"javier_arilos\",\"jbkamaraj\",\"jcoscia\",\"jdrumgoole\",\"jedux\",\"jesushdz_\",\"jimthree\",\"jirikuncar\",\"jjvie\",\"jmaurola\",\"jmkaluzka\",\"jmortegac\",\"josethegeek93\",\"kaleidomkt\",\"kantrn\",\"kanumankalwa\",\"kerma_dj\",\"kjam\",\"kkvie\",\"laceynwilliams\",\"ladybiss\",\"lehinevych\",\"leriomaggio\",\"lethal_guitar\",\"librecon\",\"linuxchixar\",\"loooorenanicole\",\"lucaotta\",\"lugensaDE\",\"luistxo\",\"lunkwill42\",\"lusantala\",\"m3ntaal\",\"m4rpl4t3ns3\",\"maidotgimenez\",\"malemburg\",\"marchingMarcin\",\"mariog5tw\",\"matrixise\",\"med_vector\",\"mesic_ivan\",\"methauser\",\"micktwomey\",\"micropython\",\"miguelsr1987\",\"mikilinchu\",\"minglis\",\"miravallesm\",\"mircea_zetea\",\"mishunika\",\"moaiamorfo\",\"moderndev_org\",\"moreati\",\"mstuchli\",\"mtomwing\",\"mumak\",\"mutetella\",\"ncoghlan_dev\",\"nerdearla\",\"neuralhacker\",\"nodejstweet\",\"notsolonecoder\",\"ntigc\",\"ntoll\",\"olasitarska\",\"oleiade\",\"palimarium\",\"patrick91\",\"patrickwiener\",\"paulhildebrandt\",\"pauloxnet\",\"pdenapo\",\"pepuchoZ\",\"peterhoffmann\",\"philipp_kalweit\",\"piquadrat_ch\",\"porelmorro\",\"postenterprise\",\"pranavs18\",\"ps_python\",\"pvergain\",\"pyacademy\",\"pycologne\",\"pydatacarolinas\",\"pydatait\",\"pyladies\",\"pyladiesblore\",\"pythonsummit\",\"qba73\",\"radhios\",\"rafaorga\",\"ramalhoorg\",\"rcarrillocruz\",\"rciorba\",\"regiguren\",\"rembish\",\"renatolrr\",\"renedudfield\",\"rmarianoa\",\"rmistaken\",\"rodesia\",\"rodynnz\",\"roguelynn\",\"russel_winder\",\"rwillmer\",\"scas\",\"scott_triglia\",\"sealth\",\"sebineubauer\",\"secretsauceguys\",\"sectest9\",\"seznam_cz\",\"simbasso\",\"simondolle\",\"sirtoothbrush\",\"sjwrenlewis\",\"slavek_k\",\"slothy\",\"sprintworks\",\"strusberg\",\"swintgs\",\"sysarmy\",\"talideon\",\"tanyaschlusser\",\"tcarrez\",\"teach_python\",\"the_compiler\",\"thebenlove\",\"tjguk\",\"tmuxbee\",\"toptalllc\",\"travelperk\",\"tsatt_team\",\"ubnu42\",\"ulysseas\",\"unbit\",\"urbanskudnik\",\"uweziegenhagen\",\"vhardion\",\"victornc83\",\"vkmc\",\"vpettorino\",\"vvatsa\",\"whosbacon\",\"whykay\",\"yamila_moreno\",\"zamarrowski\",\"zeth0\",\"zuriich92\"],\"x\":[0.32937314578834825,0.34948677156023716,0.8882892913147034,0.4562184002572107,0.6293972386035256,0.5267863645195076,0.8420677510419282,0.17512726011751575,0.7998254358498652,0.4850450724209578,0.6074710587608619,0.6080051629526841,0.49944412323518156,0.6268508164927742,0.5895173731766337,0.01491152415878895,0.6107355293327792,0.4907090195063411,0.2753690782443153,0.7004173260385501,0.7560820530487513,0.8929393822206129,0.40731554504571377,0.5447150666945445,0.47738724885640027,0.3738634677907164,0.19425256693751614,0.34599043477666275,0.5529824335702461,0.5350126454523644,0.6183173145362721,0.5966708414632891,0.40997393568107054,0.559419831092162,0.5946504680499989,0.26121459320914797,0.5359688794021277,0.5987207378759382,0.38710514416806735,0.834430925358825,0.4977382956718392,0.2526976678148345,0.42295945765243814,0.6154578014735469,0.7749704651885716,0.723708267997975,0.5169218248929459,0.7344383643704192,0.7483810189890286,0.8639999622738026,0.8438595465067269,0.4449409251161033,0.46608893696390463,0.1893636514025236,0.6403023207536772,0.5413675166391315,0.36329127930353833,0.42677214100651073,0.40801296993013914,0.03387804922264454,0.40167020169332,0.8245584052983008,0.5113462489571763,0.339490529991326,0.5458348865235372,0.8429349676089558,0.841436009225072,0.49425476008554386,0.24092592363167847,0.7415379765400981,0.6824933772230014,0.7866984440999546,0.6986026475011937,0.6861337059886096,0.8999153118864638,0.46562646714640893,0.5961847279537155,0.3094196801466035,0.5503692923694219,0.40246340244580703,0.812997251330952,0.4536149058326496,0.43136066141760676,0.2408523952121474,0.7328624564696022,0.680297843895486,0.869789378211215,0.2284611938858925,0.596605921943523,0.01734191341632451,0.2949650517770683,0.32306974830188095,0.43175051267272974,0.4189157068812568,0.7935304655073256,0.2984755496377469,0.6433428028976722,0.7409999722997533,0.16720049055701025,0.2991927802544625,0.46725188988062477,0.7872166262798496,0.0666376520597208,0.5790707889827418,0.4962091998987209,0.32725306453715725,0.8105537647772262,0.05119568519436346,0.19349604237479048,0.5649709653000902,0.6968954957038507,0.6250611858264904,0.6080309874401345,0.3962128954605851,0.22319313083257478,0.6781321865441622,0.3354796280607799,0.5124618527636177,0.48393231337562054,0.761224114805333,0.4715396132256285,0.7516747463259655,0.39436003118292895,0.36366893746276097,0.726770167517955,0.9677721505314865,0.2580476450823534,0.5276767715252405,0.5277819773456729,0.8189600654341986,0.24820547587082087,0.8324764569733091,0.5972718337639362,0.761813628266647,0.8168057606613124,0.2668432841062252,0.8931697215832224,0.10861525817488801,0.45401224027153125,0.7243670816727983,0.7138964428690399,0.35594095814264237,0.23564451833165584,0.7167019153870717,0.3258229314629499,0.4460363754868059,0.2340754405001311,0.6518500628476263,0.6473208358041451,0.5475352476810662,0.5448191465475354,0.6717153141828879,0.8628547242807124,0.7680466001592029,0.4232741731428999,0.28258678170836293,0.7761786220296911,0.22900430309695666,0.46232631932681983,0.7042899634519145,0.3679874628262692,0.28437605693851287,0.761656859121696,0.4322559884048272,0.29952075887699614,0.49592377787927816,0.28311721776637655,0.6685489782327163,0.8556121857527282,0.7916796401593695,0.7847822765559535,0.5071638873750163,0.48632283686369515,0.271838772675641,0.18531482750887057,0.6649554871730126,0.567920962016376,0.7859863180590075,0.1608098361767725,0.4077105934103404,0.5819844791493612,0.5217992519770993,0.8366710372490394,0.4864261770589082,0.5659837781046475,0.396558598150051,0.5505241768390209,0.7266454077620865,0.3474967582324662,0.3696102306509866,0.07346649337272483,0.877096902978967,0.05440411351733689,0.6768329005466855,0.7791414891415637,0.8560536118270783,0.6329493711757243,0.4133296998103043,0.19650212578825868,0.5250628515459467,0.430521278698538,0.4529860888516215,0.34790904717371385,0.6122920872296445,0.20442646732631017,0.39925818847095174,0.3350585537496382,0.5096609465005195,0.2941857964504337,0.6924426591714892,0.627272250059462,0.3661621372044959,0.7037922615792445,0.6591189655369051,0.4184581518441556,0.48540992073820394,0.5992223660595205,0.8263847481724219,0.2879879844646292,0.5761766725749653,0.1322454057651943,0.46301048244358173,0.3296525707818188,0.27087086409615146,0.4530764629204581,0.4239438713479811,0.15719524760500456,0.3130781698377906,0.1843789805922721,0.38529607741643523,0.012345996632333186,0.7452906139267168,0.2358727100151212,0.5313109656023342,0.2570141524214476,0.6831222541558417,0.29134409322657606,0.6277876734099467,0.7946978866221922,0.7052668737315834,0.7404431308269849,0.7131000611151268,0.33634272929883396,0.8345012133036179,0.7675582807520264,0.6925271287281928,0.7388205894069465,0.7272638538465169,0.2743397678659176,0.3959163596851933,0.6520292797891475,0.6401117262934481,0.5273702911813317,0.003015380849707185,0.21718748780794514,0.2981618960890701,0.18139172755563043,0.6527603423114108,0.14722407149633063,0.47242041926269346,0.4082859360018825,0.46741740038951296,0.5560658847433289,0.4765462912646269,0.7814198436314305,0.7994834301821617,0.3093605027419721,0.018422355054930853,0.25536819436085423,0.166819139529403,0.6167832479852217,0.28602282595682754,0.1517748264614068,0.6629041068383162,0.544539004263694,0.44931378564384283,0.8790374985140805,0.3898214122008547,0.6675537786814328,0.5085355089048774,0.4454174987254497,0.006266469508740191,0.7180429321977851,0.7670459256438553,0.651783556975088,0.6565697794292283,0.5376504568319638,0.4574369736626141,0.28638920473736407,0.5028661165493689,0.8326603424290081,0.17952403456861613,0.7274773978033486,0.42859586363905927,0.7085157545233863,0.20568856869292532,0.5693465742587844,0.5034422420528094,0.9009080692474105,0.13777514371507615,0.4871078639740247,0.2170270862194745,0.6690835875483784,0.3835366836923065,0.5260875552648081,0.7145665609164941,0.7622356439433351,0.256898169164969,0.5167072560318462,0.37238772853881913,0.21176849404182965,0.3570884139781243,0.7928027598163593,0.2632069130739772,0.5638629012589974,0.62667991174485,0.35660111712708964,0.337805765625278,0.5768091365055497,0.4658322959020708,0.7754670377276417,0.7871751446700895,0.39509450781332645,0.42703531786246235,0.6856612640188375,0.5593387736680957,0.12861167176615745,0.651284678747614,0.8867889565968607,0.5594875154588832,0.4326081736583103,0.6788475874745815,0.510636052227933,0.3859002352702982,0.43758201921451484,0.8550325710422679,0.5907137988525875,0.42179931848929575,0.6182294553862728,0.21728377584402567,0.31671444199530546,0.2622240439629714,0.3883046727706779,0.4523018886875211,0.8182375006568635,0.43309367370941704,0.07356067020449042,0.8764029275146705,0.6707908271840203,0.5878329508692572,0.23434494729439112,0.25876633382212216,0.5332561504933538,0.6505706726576815,0.6978388426777503,0.8751765679775968,0.6964366138893624,0.49714673323819925,0.4390134984338319,0.3706081060186885,0.6338609228657242,0.7618397943634078,0.44810173436769446,0.32466549841724035,0.014738104337967814,0.34822187064016563,0.6180153563450871,0.25937843210368355,0.24043984372654761,0.3451810016352063,0.30337140564146303,0.17699789901213275,0.6051882508374126,0.37507348473355595,0.7495572849740229,0.7106268413894079,0.4850507051728439,0.8514221020669225,0.5048020132447048,0.17743396243185067,0.6301227041720708,0.6200866052863462,0.1956204643491215,0.7710731504157251,0.8458135821758563,0.5985644739547227,0.37686218083089046,0.5008342945444857,0.7249121824073669,0.6277656575160098,0.9564087420034828,0.42091930483654755,0.6268218014615353,0.8834912863072185,0.0004072719444873302,0.642911896564152,0.5329057104081123,0.4021407240331482,0.4016712656772196,0.8074746819308689,0.8953123919280528,0.717088586823395,0.3185649993242489,0.6899260224655718,0.7362508636476812,0.36833004578891965,0.8010814415715746,0.21808878860540684,0.4409991471742692,0.653308244231644,0.5200235387316209,0.5018163516447947,0.5735981203934972,0.8109428641580553,0.28620078997995535,0.5855843530952799,0.09238113774550924,0.31086305052919483,0.10831624645503504,0.6757251420711579,0.3767405480752065,0.12481825518894532,0.0,0.6593906549121756,0.3337395622473997,0.27913978746429013,0.8636362988904436,0.4630528834970288,0.44135240790243374,0.6522806171755322,0.27905603083075564,0.010924079583337212,0.024692388236573402,0.7125408561767473,0.8045028091519743,0.8392903505932183,0.5988334756269038,0.9359267969716011,0.7531227867440443,0.7469397426983816,0.8934477193344548,0.3567440019403381,0.8907052237673692,0.8144674872146741,0.8199222308019513,0.8673087402297465,0.49699675212891453,0.4797842514091308,0.6423456766982111,0.6010403923593373,0.43197377845479096,0.5760663534786334,0.37618345634908607,0.3707113270994126,0.20315850054990733,0.5177148447912643],\"y\":[0.28967045807142405,0.49321589761667906,0.6114884559743814,0.28765897036398186,0.42038396057478256,0.24488037792617978,0.6555924748004226,0.637701616562345,0.40775345452754036,0.816696387794036,0.6386468337920613,0.08710036054342263,0.0,0.9830068707539786,0.1331731863459878,0.3756071601170002,0.5716356784561741,0.2678319918497413,0.7444164662901014,0.4710846877627917,0.46463118186664565,0.4049271448617068,0.18444928769237487,0.27420827225574895,0.30604823057945385,0.18221201116375585,0.5452245805654169,0.5756934843630539,0.5371251862374531,0.35537686614228586,0.691886326565762,0.24086342723742865,0.7890076050183971,0.7321686807058896,0.16173073020245696,0.9379828427440832,0.6085669803114362,0.012014781810010287,0.8321147999922618,0.5332065483951346,0.5633846671937589,0.2669192248469852,0.41747798898431937,0.16036723110733567,0.24484892440599748,0.19584745008425958,0.39723488268211155,0.5476713970682007,0.74877366793852,0.6355438452819554,0.45567894400574516,0.8129565908543038,0.7193167344323413,0.42664086597482787,0.6191203260359933,0.10224652605134109,0.16016274624505258,0.7995760532528451,0.12389046732526335,0.6831448909424619,0.7089756923612295,0.6026806938089542,0.7310000899182425,0.16852785115334742,0.13366888995334028,0.48090941535909565,0.42687603977834965,0.7164114852181838,0.5803926327104053,0.4388313367196233,0.7726065575391908,0.444027353342111,0.6017510295555455,0.09014206234609701,0.4393404746789394,0.002798961435541578,0.44720670796608125,0.15065641730078955,0.7088679714710461,0.5634640869349782,0.24019339361525108,0.3784550836111945,0.7452829125960218,0.24375376247989744,0.5140240042309399,0.6624697707834359,0.5283913703426419,0.3788913931950467,0.3698943178774708,0.5655243837424004,0.6177264302342022,0.18969589121840597,0.6958513172750607,0.4598101669700343,0.6586521543222597,0.5862690940697507,0.3744413623546023,0.2197776096402575,0.3642910540840711,0.7119263878031391,0.6904226612863027,0.38789225754056694,0.7462947759422153,0.8480644043231941,0.2030813546636055,0.6819393646825664,0.6210846640660135,0.27779010446024777,0.3872220465602767,0.2576482912815104,0.6797349754383587,0.20963739924688715,0.48453723694984574,0.15869576594179613,0.5354332583594661,0.1486026017777609,0.660432871437816,0.6318110145695137,0.15968467616016585,0.7345271082885712,0.36705657941491054,0.7045574966363791,0.657086202431473,0.8078391955329095,0.7595767097293317,0.32811574748523936,0.35091370069078043,0.15419286639427188,0.19933334488961252,0.6399926936563858,0.7357940507538124,0.5091876625107056,0.6745803882193274,0.5059293859544223,0.5704206344468208,0.468087975974438,0.532079273991722,0.24383610004311296,0.7474388513889462,0.608632763773559,0.5392331611303647,0.19731172210428197,0.6074850831813735,0.6383001874738673,0.35319012821601903,0.1680352984790842,0.637727285059424,0.3393929547320893,0.2694545569779559,0.7504090640510136,0.39651518609686176,0.5999866263324974,0.40258749171673497,0.5884439725024153,0.15031846957277747,0.4198032904377029,0.7612193446686886,0.4507684163240844,0.45250458946179123,0.8086494090192747,0.6279263550325983,0.831282443778007,0.18497468648403095,0.5457359122517992,0.24740263237564292,0.4030728953171881,0.35372947827716217,0.30898003112970135,0.3011411395091858,0.3461691993004907,0.5661247818553705,0.08797376753696164,0.6424909535271728,0.23966908896035619,0.4935214922361755,0.5681739762661152,0.5671348921371102,0.7117538031098491,0.630801416528471,0.5411998098354136,0.42047350559793945,0.12164262906037887,0.2851408486858898,0.3694577704292969,0.5197629058866543,0.4977491277771893,0.20835868980238664,0.05477044416658729,0.5464994824749025,0.4415399262979149,0.42462563666944586,0.4281253663696925,0.7237466047750631,0.4285635536904042,0.32830933898901904,0.37938243566997665,0.31595608407855186,0.7334027682174646,0.45743011437986236,0.7527254406328888,0.2500794065488848,0.48046567508521565,0.321680047850924,0.3951994930091709,0.1081767734249794,0.31762800862395507,0.5940705956617384,0.5782368882477646,0.18417900132468612,0.40545765038305975,0.7923960630635131,0.46542373082288824,0.7641417465286434,0.7113211289585225,0.6156320944435291,0.105211734290933,0.7392730165959559,0.30899557178097814,0.5586600444464479,0.5835240296844172,0.4525379216453794,0.6162626818062846,0.4926392468174273,0.32625936365022923,0.8830079150374622,0.48979672257253865,0.5269626819567745,0.9633874721979587,0.8682780812412808,0.35354765901276075,0.5342409109794203,0.6244488551073897,0.30113802493274033,0.7217819685043624,0.3811804114215997,0.6314946864402609,0.7580853182147079,0.6429307396691056,0.19715153275207803,0.13627939091125882,0.16969556638132585,0.7371297618622412,0.7976637782492555,0.25983621371186605,0.21223921744449123,0.5514117581134003,0.2545198557999168,0.29959065960548625,0.4435919918519365,0.479491914506478,0.649129723689199,0.6946543424032136,0.4644265933240915,0.4385303799398052,0.2866761446724974,0.32903756454915417,0.3248285503180051,0.5381327218855235,0.8554334126061353,0.1323325629683591,0.6852702632643184,0.5324797516965024,0.9970655067320642,0.7423330343043048,0.2717753269630601,0.5116991430043761,0.3015005471981137,0.6015546785961549,0.6598473043084586,0.5934927805921262,0.3377009970768298,0.20913385755198127,0.7487474820814098,0.9722576374189348,0.8528721121156967,0.7900187994632909,0.34976785016864254,0.4607304950314831,0.3814101792614075,0.8134193274559792,0.6034712410443259,0.4164583046415229,0.9463574822795291,0.628402889749191,0.17145904021242891,0.7879215815685586,0.8023112618661227,0.10182279050687786,0.30163224913901937,0.3682142606449557,0.8731475419437271,0.4665701285897894,0.3961863164628086,0.5146859906287252,0.4412738654608661,0.5973150253917375,0.11577436713543154,0.2961160615424195,0.4722671490732712,0.41254406548995315,0.7941581650806059,0.5644052729302718,0.19594640773543653,0.10193544041342725,0.33055713136062487,0.16408292422416088,0.35124935361294507,0.42195595902769334,0.7968717860750494,0.6580949110185261,0.6762104750895189,0.7146508825410139,0.22863153884520127,0.6855416614287914,0.3073870265835071,0.8370998501953743,0.7621605629428484,0.25737918638708507,0.33843500925763914,0.8045534864851885,0.6797909978021992,0.8223984231829917,0.7311120412458607,0.3054425167881268,0.4876032944294878,0.4633349136726842,0.21154712567125186,0.4452292275739381,0.37719691319932325,0.388417647624072,0.1125462696946161,0.2394744818775305,0.5993878107889014,0.41569664957548513,0.224994162377506,0.5943727764857878,0.70196767347563,0.5855399018260025,0.2627189451238526,0.3292708222451807,0.2242436061445224,0.060307632698421966,0.43293099809978064,0.32060758787424637,0.6741822813624635,0.40944090394725324,0.23747688018632296,0.45955818521324665,0.6865036503447209,0.08155316871340108,0.923372596923963,0.21337252010202712,0.6355543158364171,0.8315177459730111,0.20490598362692178,0.49224398292360866,0.3756304159096863,0.2402041690827045,0.7211525475839037,0.3560301340694253,0.7519820126003876,0.4058441348357288,0.13857379959444122,0.76402195296293,0.582176442627514,0.6980098944564919,0.5145525649499937,0.6344026112713228,0.5071788679257944,0.22008850143988615,0.5007766899277777,0.6535846371981258,0.30365752381793865,0.7002219082501343,0.290973142510098,0.6594916630702127,0.33364665792653025,0.35602008500293675,0.6891849194688708,0.29026007298482365,0.5750826143843594,0.13291619607318123,0.5162309872640686,0.3076447431098306,0.1394052277779232,0.798598861653098,0.3850658234158584,0.13390310266931893,0.4889075870448013,0.45967477884167124,0.7034586032808088,0.37439611908434434,0.04536084763174147,0.5586561342032628,0.5051474678294182,0.0839364307451562,0.6861984278986488,0.5191506485901891,0.24532755355273295,0.697774703423627,0.5034199838939876,0.22637531395393293,0.4081364148795204,0.17837135328717482,0.579640533495896,0.27007728591199187,0.3662196950547806,0.4806671826599098,0.5204616184970776,0.02602260530775652,0.8557571722218559,1.0,0.15956168335173848,0.27328737251276447,0.527730855490007,0.5505574055447559,0.2877245275031935,0.5435332140153116,0.3512865619336758,0.3529082566550165,0.13741285746048232,0.7131321290633202,0.47425440150618353,0.7455202993113186,0.1324193910282083,0.6713688656097923,0.5696401069015957,0.23709655038122238,0.6500322109180686,0.13948597135490573,0.3836060316311979,0.5552044611623879,0.6237727305021749,0.27600443680581555,0.4812389911319088,0.3336401440765844,0.5936053922055856,0.7332106471142972,0.9312095100973454,0.32365947792215594,0.20246350467293522,0.3975901164304786,0.6929474037593202,0.43351085519853894,0.5478678495498374,0.32447229181159315,0.7510563490127009,0.6143159256020416,0.48867307066228693,0.19792836219983753,0.3574758276477921,0.268006552837604,0.611776552412223,0.5351326715500055,0.4056395478047269,0.5210969333616969]}},\"id\":\"3f023844-1e56-4428-a551-094d91501d03\",\"type\":\"ColumnDataSource\"},{\"attributes\":{},\"id\":\"9720aeca-f949-4a69-a0d8-7d5eed928666\",\"type\":\"BasicTicker\"},{\"attributes\":{\"dimension\":1,\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"20197a57-7180-4dba-a3f8-12a57f1aedd1\",\"type\":\"BasicTicker\"}},\"id\":\"6f9bf602-63a5-4def-a45d-b8d7d5517b4e\",\"type\":\"Grid\"},{\"attributes\":{\"callback\":null},\"id\":\"1921560f-a905-489e-b6cf-761048d9142d\",\"type\":\"DataRange1d\"},{\"attributes\":{},\"id\":\"7dcaa794-a580-402c-992d-7e817bb11318\",\"type\":\"ToolEvents\"},{\"attributes\":{\"bottom_units\":\"screen\",\"fill_alpha\":{\"value\":0.5},\"fill_color\":{\"value\":\"lightgrey\"},\"left_units\":\"screen\",\"level\":\"overlay\",\"line_alpha\":{\"value\":1.0},\"line_color\":{\"value\":\"black\"},\"line_dash\":[4,4],\"line_width\":{\"value\":2},\"plot\":null,\"render_mode\":\"css\",\"right_units\":\"screen\",\"top_units\":\"screen\"},\"id\":\"e291121b-79c6-40c5-b081-7371926c685a\",\"type\":\"BoxAnnotation\"},{\"attributes\":{},\"id\":\"f26e124b-b0b4-493f-b007-5e80685078a5\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"callback\":null},\"id\":\"ab1e5802-a479-4dbc-958f-520d5c45c00b\",\"type\":\"DataRange1d\"},{\"attributes\":{\"data_source\":{\"id\":\"ab0d71df-1008-4bd0-8ee8-b60394cda912\",\"type\":\"ColumnDataSource\"},\"glyph\":{\"id\":\"48a529e0-49c1-4985-8d95-028503b36abd\",\"type\":\"MultiLine\"},\"hover_glyph\":null,\"nonselection_glyph\":{\"id\":\"1a1f89ff-65f0-49a4-a490-2938aca9f648\",\"type\":\"MultiLine\"},\"selection_glyph\":null},\"id\":\"e3d2f80f-e634-437c-966b-6896c28eaf44\",\"type\":\"GlyphRenderer\"},{\"attributes\":{\"active_drag\":\"auto\",\"active_scroll\":\"auto\",\"active_tap\":\"auto\",\"tools\":[{\"id\":\"145c024b-5fa5-4086-871c-cd25f1d1ac7a\",\"type\":\"HoverTool\"},{\"id\":\"dee07948-35c4-4872-a632-62aedee74dcf\",\"type\":\"TapTool\"},{\"id\":\"60156367-73d9-4892-8324-eaa5c2ee576f\",\"type\":\"BoxZoomTool\"},{\"id\":\"5adc6f1b-6f56-486a-9aee-20ea3f45dd55\",\"type\":\"ResetTool\"}]},\"id\":\"f8b07d79-31cc-41d8-87c7-02367bbe3be0\",\"type\":\"Toolbar\"},{\"attributes\":{\"below\":[{\"id\":\"e43c1d7a-7174-4725-a05c-aecb2ecf6c29\",\"type\":\"LinearAxis\"}],\"left\":[{\"id\":\"c82cd6a8-c815-4d2a-848e-1e6052945a3c\",\"type\":\"LinearAxis\"}],\"plot_height\":400,\"plot_width\":800,\"renderers\":[{\"id\":\"e43c1d7a-7174-4725-a05c-aecb2ecf6c29\",\"type\":\"LinearAxis\"},{\"id\":\"7cddbcbd-7485-449e-9f4f-5bd9d4f56156\",\"type\":\"Grid\"},{\"id\":\"c82cd6a8-c815-4d2a-848e-1e6052945a3c\",\"type\":\"LinearAxis\"},{\"id\":\"6f9bf602-63a5-4def-a45d-b8d7d5517b4e\",\"type\":\"Grid\"},{\"id\":\"e291121b-79c6-40c5-b081-7371926c685a\",\"type\":\"BoxAnnotation\"},{\"id\":\"05c6bf18-f6a1-476c-b604-f3a5412b4df2\",\"type\":\"GlyphRenderer\"},{\"id\":\"e3d2f80f-e634-437c-966b-6896c28eaf44\",\"type\":\"GlyphRenderer\"}],\"title\":{\"id\":\"800ff3d4-6e8f-4a0b-87a3-6bc5122f7678\",\"type\":\"Title\"},\"tool_events\":{\"id\":\"7dcaa794-a580-402c-992d-7e817bb11318\",\"type\":\"ToolEvents\"},\"toolbar\":{\"id\":\"f8b07d79-31cc-41d8-87c7-02367bbe3be0\",\"type\":\"Toolbar\"},\"x_range\":{\"id\":\"ab1e5802-a479-4dbc-958f-520d5c45c00b\",\"type\":\"DataRange1d\"},\"y_range\":{\"id\":\"1921560f-a905-489e-b6cf-761048d9142d\",\"type\":\"DataRange1d\"}},\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{\"fill_color\":{\"field\":\"community_color\"},\"line_color\":{\"value\":\"blue\"},\"size\":{\"field\":\"centrality\",\"units\":\"screen\"},\"x\":{\"field\":\"x\"},\"y\":{\"field\":\"y\"}},\"id\":\"3d9732c3-0763-417f-86b3-6c19897b1851\",\"type\":\"Circle\"},{\"attributes\":{},\"id\":\"20197a57-7180-4dba-a3f8-12a57f1aedd1\",\"type\":\"BasicTicker\"},{\"attributes\":{\"data_source\":{\"id\":\"3f023844-1e56-4428-a551-094d91501d03\",\"type\":\"ColumnDataSource\"},\"glyph\":{\"id\":\"3d9732c3-0763-417f-86b3-6c19897b1851\",\"type\":\"Circle\"},\"hover_glyph\":null,\"level\":\"overlay\",\"nonselection_glyph\":{\"id\":\"a911e458-c64f-494c-8954-4b6214d3349f\",\"type\":\"Circle\"},\"selection_glyph\":null},\"id\":\"05c6bf18-f6a1-476c-b604-f3a5412b4df2\",\"type\":\"GlyphRenderer\"},{\"attributes\":{\"fill_alpha\":{\"value\":0.1},\"fill_color\":{\"value\":\"#1f77b4\"},\"line_alpha\":{\"value\":0.1},\"line_color\":{\"value\":\"#1f77b4\"},\"size\":{\"units\":\"screen\",\"value\":10},\"x\":{\"field\":\"x\"},\"y\":{\"field\":\"y\"}},\"id\":\"a911e458-c64f-494c-8954-4b6214d3349f\",\"type\":\"Circle\"},{\"attributes\":{\"callback\":null,\"column_names\":[\"ys\",\"alphas\",\"xs\"],\"data\":{\"alphas\":[0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.22,0.12000000000000001,0.2,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.18,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.22,0.16,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.3,0.12000000000000001,0.22,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.45999999999999996,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.18,0.18,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.24,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.24,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.18,0.12000000000000001,0.14,0.16,0.24,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.31999999999999995,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.2,0.12000000000000001,0.14,0.2,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.14,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.22,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.16,0.12000000000000001,0.16,0.12000000000000001,0.16,0.14,0.16,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.26,0.2,0.26,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.24,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.7,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.18,0.12000000000000001,0.16,0.12000000000000001,0.36,0.36,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.16,0.14,0.16,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.16,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.18,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.26,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.64,0.12000000000000001,0.14,0.12000000000000001,0.26,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.33999999999999997,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.2,0.18,0.14,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.16,0.12000000000000001,0.18,0.14,0.12000000000000001,0.16,0.12000000000000001,0.14,0.14,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.22,0.12000000000000001,0.16,0.12000000000000001,0.18,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.26,0.18,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.16,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.22,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.14,0.18,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.18,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.22,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.28,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.33999999999999997,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.14,0.12000000000000001,0.18,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.24,0.12000000000000001,0.18,0.12000000000000001,0.14,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.22,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.38,0.22,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.31999999999999995,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.2,0.14,0.16,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.22,0.16,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.16,0.14,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.33999999999999997,0.14,0.12000000000000001,0.14,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.16,0.12000000000000001,0.12000000000000001,0.14,0.3,0.12000000000000001,0.14,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.22,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001,0.2,0.12000000000000001,0.12000000000000001,0.14,0.12000000000000001,0.12000000000000001,0.28,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.12000000000000001,0.18,0.12000000000000001,0.12000000000000001],\"xs\":[[0.3354796280607799,0.37238772853881913],[0.3354796280607799,0.4529860888516215],[0.3354796280607799,0.4454174987254497],[0.3354796280607799,0.4184581518441556],[0.3354796280607799,0.4797842514091308],[0.8345012133036179,0.5273702911813317],[0.9359267969716011,0.8420677510419282],[0.9359267969716011,0.7680466001592029],[0.10861525817488801,0.3859002352702982],[0.5638629012589974,0.5273702911813317],[0.5638629012589974,0.5260875552648081],[0.27913978746429013,0.21176849404182965],[0.27913978746429013,0.2949650517770683],[0.27913978746429013,0.5273702911813317],[0.7145665609164941,0.5273702911813317],[0.3696102306509866,0.3859002352702982],[0.3696102306509866,0.30337140564146303],[0.3696102306509866,0.19349604237479048],[0.3696102306509866,0.5273702911813317],[0.3696102306509866,0.2668432841062252],[0.3696102306509866,0.3883046727706779],[0.3696102306509866,0.3696102306509866],[0.5992223660595205,0.5273702911813317],[0.5992223660595205,0.6591189655369051],[0.5992223660595205,0.6268508164927742],[0.6010403923593373,0.5273702911813317],[0.6010403923593373,0.5760663534786334],[0.6010403923593373,0.5966708414632891],[0.6010403923593373,0.642911896564152],[0.19349604237479048,0.3883046727706779],[0.4326081736583103,0.5273702911813317],[0.6051882508374126,0.6182294553862728],[0.6051882508374126,0.5273702911813317],[0.1843789805922721,0.2753690782443153],[0.1843789805922721,0.29134409322657606],[0.1843789805922721,0.32725306453715725],[0.31086305052919483,0.42859586363905927],[0.31086305052919483,0.5273702911813317],[0.31086305052919483,0.4021407240331482],[0.337805765625278,0.5273702911813317],[0.337805765625278,0.38529607741643523],[0.3296525707818188,0.3859002352702982],[0.3296525707818188,0.28258678170836293],[0.3296525707818188,0.2743397678659176],[0.3296525707818188,0.5177148447912643],[0.3296525707818188,0.4797842514091308],[0.8420677510419282,0.7680466001592029],[0.8420677510419282,0.5273702911813317],[0.38529607741643523,0.3859002352702982],[0.38529607741643523,0.21718748780794514],[0.38529607741643523,0.5273702911813317],[0.17743396243185067,0.05119568519436346],[0.17743396243185067,0.07356067020449042],[0.17743396243185067,0.5273702911813317],[0.8953123919280528,0.8751765679775968],[0.8953123919280528,0.5273702911813317],[0.006266469508740191,0.1322454057651943],[0.31671444199530546,0.36833004578891965],[0.31671444199530546,0.5273702911813317],[0.2984755496377469,0.42859586363905927],[0.2984755496377469,0.4409991471742692],[0.2984755496377469,0.3707113270994126],[0.2984755496377469,0.4077105934103404],[0.5735981203934972,0.5760663534786334],[0.5735981203934972,0.6080051629526841],[0.5735981203934972,0.5273702911813317],[0.5735981203934972,0.5878329508692572],[0.3185649993242489,0.10831624645503504],[0.3185649993242489,0.5273702911813317],[0.3185649993242489,0.2284611938858925],[0.4765462912646269,0.46725188988062477],[0.4765462912646269,0.5273702911813317],[0.4765462912646269,0.4797842514091308],[0.2991927802544625,0.5273702911813317],[0.5018163516447947,0.5200235387316209],[0.5018163516447947,0.544539004263694],[0.4630528834970288,0.47738724885640027],[0.4630528834970288,0.4907090195063411],[0.4630528834970288,0.4864261770589082],[0.4630528834970288,0.5273702911813317],[0.3959163596851933,0.07346649337272483],[0.3959163596851933,0.5096609465005195],[0.3959163596851933,0.5273702911813317],[0.3959163596851933,0.46232631932681983],[0.3959163596851933,0.396558598150051],[0.3959163596851933,0.4077105934103404],[0.43758201921451484,0.4864261770589082],[0.43758201921451484,0.5273702911813317],[0.28437605693851287,0.34822187064016563],[0.28437605693851287,0.4454174987254497],[0.28437605693851287,0.3570884139781243],[0.6473208358041451,0.5273702911813317],[0.6473208358041451,0.5448191465475354],[0.6690835875483784,0.6788475874745815],[0.6690835875483784,0.5273702911813317],[0.22900430309695666,0.30337140564146303],[0.22900430309695666,0.5273702911813317],[0.6338609228657242,0.6183173145362721],[0.6338609228657242,0.5273702911813317],[0.6338609228657242,0.6593906549121756],[0.8560536118270783,0.5273702911813317],[0.43309367370941704,0.3859002352702982],[0.43309367370941704,0.4864261770589082],[0.43309367370941704,0.5273702911813317],[0.43309367370941704,0.43197377845479096],[0.43309367370941704,0.3258229314629499],[0.43309367370941704,0.43309367370941704],[0.43309367370941704,0.34790904717371385],[0.43309367370941704,0.4239438713479811],[0.7404431308269849,0.5273702911813317],[0.7998254358498652,0.7618397943634078],[0.7998254358498652,0.6768329005466855],[0.7998254358498652,0.5273702911813317],[0.6154578014735469,0.5760663534786334],[0.6154578014735469,0.6080051629526841],[0.6154578014735469,0.5273702911813317],[0.6154578014735469,0.5878329508692572],[0.49425476008554386,0.46725188988062477],[0.49425476008554386,0.5273702911813317],[0.49425476008554386,0.4797842514091308],[0.45401224027153125,0.46725188988062477],[0.45401224027153125,0.5273702911813317],[0.45401224027153125,0.4797842514091308],[0.5008342945444857,0.5273702911813317],[0.6107355293327792,0.5988334756269038],[0.6107355293327792,0.6107355293327792],[0.6107355293327792,0.5273702911813317],[0.6107355293327792,0.6301227041720708],[0.6107355293327792,0.6986026475011937],[0.6107355293327792,0.6831222541558417],[0.6107355293327792,0.5855843530952799],[0.6107355293327792,0.6074710587608619],[0.6107355293327792,0.6591189655369051],[0.5819844791493612,0.3859002352702982],[0.5819844791493612,0.7560820530487513],[0.5819844791493612,0.5273702911813317],[0.3679874628262692,0.5096609465005195],[0.3679874628262692,0.5273702911813317],[0.3679874628262692,0.4077105934103404],[0.8199222308019513,0.5273702911813317],[0.8199222308019513,0.7328624564696022],[0.24820547587082087,0.14722407149633063],[0.24820547587082087,0.5273702911813317],[0.3835366836923065,0.47738724885640027],[0.3835366836923065,0.4864261770589082],[0.6505706726576815,0.5273702911813317],[0.6505706726576815,0.6629041068383162],[0.6505706726576815,0.62667991174485],[0.8168057606613124,0.5273702911813317],[0.8168057606613124,0.7328624564696022],[0.17952403456861613,0.18531482750887057],[0.17952403456861613,0.1893636514025236],[0.17952403456861613,0.5273702911813317],[0.8882892913147034,0.7847822765559535],[0.8882892913147034,0.7680466001592029],[0.8882892913147034,0.7344383643704192],[0.8882892913147034,0.7138964428690399],[0.5790707889827418,0.5273702911813317],[0.5790707889827418,0.5560658847433289],[0.27905603083075564,0.3859002352702982],[0.27905603083075564,0.16720049055701025],[0.27905603083075564,0.5273702911813317],[0.6423456766982111,0.5273702911813317],[0.4449409251161033,0.4530764629204581],[0.4449409251161033,0.46725188988062477],[0.4449409251161033,0.5273702911813317],[0.4322559884048272,0.4409991471742692],[0.4322559884048272,0.34599043477666275],[0.4322559884048272,0.5273702911813317],[0.4322559884048272,0.4077105934103404],[0.4322559884048272,0.42859586363905927],[0.4322559884048272,0.46741740038951296],[0.4322559884048272,0.3474967582324662],[0.4322559884048272,0.4021407240331482],[0.3707113270994126,0.42859586363905927],[0.3707113270994126,0.5273702911813317],[0.3707113270994126,0.4077105934103404],[0.6433428028976722,0.7125408561767473],[0.6433428028976722,0.8934477193344548],[0.6433428028976722,0.5273702911813317],[0.4460363754868059,0.5273702911813317],[0.4460363754868059,0.4232741731428999],[0.4562184002572107,0.5273702911813317],[0.30337140564146303,0.24043984372654761],[0.30337140564146303,0.42091930483654755],[0.30337140564146303,0.4189157068812568],[0.30337140564146303,0.42295945765243814],[0.30337140564146303,0.30337140564146303],[0.30337140564146303,0.014738104337967814],[0.30337140564146303,0.018422355054930853],[0.30337140564146303,0.5273702911813317],[0.30337140564146303,0.024692388236573402],[0.30337140564146303,0.01734191341632451],[0.30337140564146303,0.3883046727706779],[0.5277819773456729,0.5273702911813317],[0.5277819773456729,0.5260875552648081],[0.46562646714640893,0.5267863645195076],[0.7037922615792445,0.7131000611151268],[0.7037922615792445,0.5273702911813317],[0.43197377845479096,0.3859002352702982],[0.43197377845479096,0.36833004578891965],[0.43197377845479096,0.5273702911813317],[0.5972718337639362,0.6277876734099467],[0.5972718337639362,0.5096609465005195],[0.5972718337639362,0.5273702911813317],[0.5972718337639362,0.5972718337639362],[0.5972718337639362,0.6403023207536772],[0.5972718337639362,0.5907137988525875],[0.4797842514091308,0.46301048244358173],[0.4797842514091308,0.4797842514091308],[0.4797842514091308,0.37238772853881913],[0.4797842514091308,0.5332561504933538],[0.4797842514091308,0.4977382956718392],[0.4797842514091308,0.4454174987254497],[0.4797842514091308,0.39509450781332645],[0.4797842514091308,0.49699675212891453],[0.4797842514091308,0.44135240790243374],[0.4797842514091308,0.4390134984338319],[0.4797842514091308,0.5503692923694219],[0.4797842514091308,0.5048020132447048],[0.4797842514091308,0.510636052227933],[0.4797842514091308,0.559419831092162],[0.4797842514091308,0.4082859360018825],[0.4797842514091308,0.4133296998103043],[0.4797842514091308,0.5124618527636177],[0.4797842514091308,0.3859002352702982],[0.4797842514091308,0.567920962016376],[0.4797842514091308,0.5359688794021277],[0.4797842514091308,0.46608893696390463],[0.4797842514091308,0.40167020169332],[0.4797842514091308,0.48632283686369515],[0.4797842514091308,0.43136066141760676],[0.4797842514091308,0.5250628515459467],[0.4797842514091308,0.5475352476810662],[0.4797842514091308,0.5329057104081123],[0.4797842514091308,0.4184581518441556],[0.4797842514091308,0.5113462489571763],[0.4797842514091308,0.46725188988062477],[0.4797842514091308,0.5313109656023342],[0.4797842514091308,0.43175051267272974],[0.4797842514091308,0.5273702911813317],[0.42677214100651073,0.4530764629204581],[0.42677214100651073,0.46725188988062477],[0.42677214100651073,0.5273702911813317],[0.6788475874745815,0.717088586823395],[0.6788475874745815,0.7409999722997533],[0.6788475874745815,0.5273702911813317],[0.6788475874745815,0.6899260224655718],[0.6788475874745815,0.723708267997975],[0.6788475874745815,0.6978388426777503],[0.6788475874745815,0.5768091365055497],[0.6788475874745815,0.6685489782327163],[0.761224114805333,0.6277876734099467],[0.761224114805333,0.6649554871730126],[0.761224114805333,0.6403023207536772],[0.723708267997975,0.5273702911813317],[0.37686218083089046,0.3859002352702982],[0.37686218083089046,0.37686218083089046],[0.37686218083089046,0.5273702911813317],[0.37686218083089046,0.3567440019403381],[0.40246340244580703,0.42859586363905927],[0.40246340244580703,0.46741740038951296],[0.40246340244580703,0.5273702911813317],[0.40246340244580703,0.4077105934103404],[0.841436009225072,0.7560820530487513],[0.841436009225072,0.5273702911813317],[0.46301048244358173,0.36366893746276097],[0.46301048244358173,0.5273702911813317],[0.46301048244358173,0.5359688794021277],[0.46301048244358173,0.510636052227933],[0.46301048244358173,0.46725188988062477],[0.46301048244358173,0.4454174987254497],[0.46301048244358173,0.44135240790243374],[0.47242041926269346,0.5273702911813317],[0.8144674872146741,0.5273702911813317],[0.8144674872146741,0.7085157545233863],[0.4133296998103043,0.46725188988062477],[0.4133296998103043,0.5273702911813317],[0.8907052237673692,0.6649554871730126],[0.8907052237673692,0.7362508636476812],[0.4189157068812568,0.2668432841062252],[0.4189157068812568,0.5273702911813317],[0.6856612640188375,0.6080309874401345],[0.6856612640188375,0.6277656575160098],[0.6856612640188375,0.8045028091519743],[0.6856612640188375,0.5273702911813317],[0.18531482750887057,0.5273702911813317],[0.834430925358825,0.5273702911813317],[0.834430925358825,0.7328624564696022],[0.7409999722997533,0.5273702911813317],[0.6707908271840203,0.5855843530952799],[0.6707908271840203,0.5273702911813317],[0.7249121824073669,0.5273702911813317],[0.7249121824073669,0.7994834301821617],[0.4850450724209578,0.4530764629204581],[0.4850450724209578,0.46725188988062477],[0.4850450724209578,0.5273702911813317],[0.651783556975088,0.6182294553862728],[0.651783556975088,0.6861337059886096],[0.651783556975088,0.5273702911813317],[0.8245584052983008,0.7670459256438553],[0.8245584052983008,0.5273702911813317],[0.0,0.1322454057651943],[0.680297843895486,0.5855843530952799],[0.680297843895486,0.5273702911813317],[0.7749704651885716,0.5273702911813317],[0.7749704651885716,0.7388205894069465],[0.32725306453715725,0.2753690782443153],[0.32725306453715725,0.5273702911813317],[0.32725306453715725,0.29134409322657606],[0.8931697215832224,0.5273702911813317],[0.18139172755563043,0.3859002352702982],[0.18139172755563043,0.3567440019403381],[0.6277876734099467,0.5096609465005195],[0.6277876734099467,0.5273702911813317],[0.6277876734099467,0.6403023207536772],[0.6277876734099467,0.6649554871730126],[0.6277876734099467,0.5907137988525875],[0.6277876734099467,0.6520292797891475],[0.6277876734099467,0.7483810189890286],[0.717088586823395,0.5273702911813317],[0.8834912863072185,0.5273702911813317],[0.46608893696390463,0.46725188988062477],[0.46608893696390463,0.5273702911813317],[0.12861167176615745,0.3859002352702982],[0.7791414891415637,0.5273702911813317],[0.7791414891415637,0.6675537786814328],[0.37507348473355595,0.46725188988062477],[0.37507348473355595,0.5273702911813317],[0.37507348473355595,0.23434494729439112],[0.17512726011751575,0.0666376520597208],[0.17512726011751575,0.15719524760500456],[0.17512726011751575,0.1608098361767725],[0.17512726011751575,0.5273702911813317],[0.17512726011751575,0.17699789901213275],[0.17512726011751575,0.05440411351733689],[0.2408523952121474,0.5273702911813317],[0.6250611858264904,0.5649709653000902],[0.6250611858264904,0.5273702911813317],[0.6250611858264904,0.5966708414632891],[0.6250611858264904,0.5760663534786334],[0.4977382956718392,0.510636052227933],[0.4977382956718392,0.46725188988062477],[0.4977382956718392,0.5273702911813317],[0.4574369736626141,0.5273702911813317],[0.7274773978033486,0.9677721505314865],[0.7274773978033486,0.5273702911813317],[0.7274773978033486,0.6964366138893624],[0.4239438713479811,0.3859002352702982],[0.4239438713479811,0.4864261770589082],[0.4239438713479811,0.5273702911813317],[0.4239438713479811,0.2668432841062252],[0.4239438713479811,0.21176849404182965],[0.4239438713479811,0.2949650517770683],[0.4239438713479811,0.6675537786814328],[0.39925818847095174,0.20442646732631017],[0.39925818847095174,0.5273702911813317],[0.5988334756269038,0.5855843530952799],[0.5988334756269038,0.6074710587608619],[0.5988334756269038,0.5273702911813317],[0.5988334756269038,0.6591189655369051],[0.5761766725749653,0.5273702911813317],[0.5761766725749653,0.5177148447912643],[0.5761766725749653,0.5855843530952799],[0.5761766725749653,0.6074710587608619],[0.5761766725749653,0.6591189655369051],[0.5761766725749653,0.5529824335702461],[0.20568856869292532,0.46725188988062477],[0.20568856869292532,0.012345996632333186],[0.20568856869292532,0.5273702911813317],[0.20568856869292532,0.010924079583337212],[0.6861337059886096,0.6182294553862728],[0.6861337059886096,0.5760663534786334],[0.6899260224655718,0.5273702911813317],[0.22319313083257478,0.5273702911813317],[0.34948677156023716,0.5273702911813317],[0.6183173145362721,0.6593906549121756],[0.6183173145362721,0.5273702911813317],[0.6183173145362721,0.7180429321977851],[0.7761786220296911,0.8326603424290081],[0.7761786220296911,0.5273702911813317],[0.6329493711757243,0.5273702911813317],[0.812997251330952,0.812997251330952],[0.812997251330952,0.7928027598163593],[0.812997251330952,0.5273702911813317],[0.1608098361767725,0.0666376520597208],[0.1608098361767725,0.15719524760500456],[0.1608098361767725,0.5273702911813317],[0.1608098361767725,0.17699789901213275],[0.1608098361767725,0.05440411351733689],[0.5217992519770993,0.5273702911813317],[0.8751765679775968,0.5273702911813317],[0.32306974830188095,0.3738634677907164],[0.32306974830188095,0.5273702911813317],[0.642911896564152,0.5760663534786334],[0.642911896564152,0.5966708414632891],[0.16720049055701025,0.3859002352702982],[0.16720049055701025,0.3898214122008547],[0.4409991471742692,0.4409991471742692],[0.4409991471742692,0.34599043477666275],[0.4409991471742692,0.5273702911813317],[0.4409991471742692,0.4077105934103404],[0.4409991471742692,0.42859586363905927],[0.4409991471742692,0.46741740038951296],[0.4409991471742692,0.3474967582324662],[0.4409991471742692,0.4021407240331482],[0.24092592363167847,0.5273702911813317],[0.653308244231644,0.5760663534786334],[0.27087086409615146,0.3859002352702982],[0.27087086409615146,0.5273702911813317],[0.5376504568319638,0.4530764629204581],[0.5376504568319638,0.46725188988062477],[0.5376504568319638,0.5273702911813317],[0.3859002352702982,0.15719524760500456],[0.3859002352702982,0.2580476450823534],[0.3859002352702982,0.2570141524214476],[0.3859002352702982,0.34790904717371385],[0.3859002352702982,0.09238113774550924],[0.3859002352702982,0.21718748780794514],[0.3859002352702982,0.3258229314629499],[0.3859002352702982,0.4715396132256285],[0.3859002352702982,0.28258678170836293],[0.3859002352702982,0.5177148447912643],[0.3859002352702982,0.37618345634908607],[0.3859002352702982,0.2981618960890701],[0.3859002352702982,0.3567440019403381],[0.3859002352702982,0.42295945765243814],[0.3859002352702982,0.28311721776637655],[0.3859002352702982,0.32937314578834825],[0.3859002352702982,0.5169218248929459],[0.3859002352702982,0.5273702911813317],[0.3859002352702982,0.2743397678659176],[0.3859002352702982,0.3093605027419721],[0.3859002352702982,0.28638920473736407],[0.2941857964504337,0.5273702911813317],[0.4077105934103404,0.396558598150051],[0.4077105934103404,0.5096609465005195],[0.4077105934103404,0.3474967582324662],[0.4077105934103404,0.34599043477666275],[0.4077105934103404,0.3898214122008547],[0.4077105934103404,0.1517748264614068],[0.4077105934103404,0.42859586363905927],[0.4077105934103404,0.5273702911813317],[0.4077105934103404,0.46741740038951296],[0.4077105934103404,0.12481825518894532],[0.2570141524214476,0.5273702911813317],[0.271838772675641,0.5273702911813317],[0.7680466001592029,0.7847822765559535],[0.7680466001592029,0.5273702911813317],[0.7680466001592029,0.7344383643704192],[0.7680466001592029,0.7138964428690399],[0.4021407240331482,0.42859586363905927],[0.4021407240331482,0.5273702911813317],[0.4021407240331482,0.396558598150051],[0.3474967582324662,0.3898214122008547],[0.3474967582324662,0.2879879844646292],[0.3474967582324662,0.42859586363905927],[0.3474967582324662,0.28620078997995535],[0.42703531786246235,0.5273702911813317],[0.62667991174485,0.5273702911813317],[0.62667991174485,0.6629041068383162],[0.559419831092162,0.46725188988062477],[0.559419831092162,0.5273702911813317],[0.6527603423114108,0.7452906139267168],[0.6527603423114108,0.6717153141828879],[0.6527603423114108,0.5273702911813317],[0.6527603423114108,0.6527603423114108],[0.6527603423114108,0.7560820530487513],[0.6527603423114108,0.567920962016376],[0.2981618960890701,0.5273702911813317],[0.8438595465067269,0.7560820530487513],[0.8438595465067269,0.5273702911813317],[0.8392903505932183,0.5273702911813317],[0.8324764569733091,0.5273702911813317],[0.8324764569733091,0.7328624564696022],[0.7916796401593695,0.5273702911813317],[0.7916796401593695,0.6675537786814328],[0.3350585537496382,0.21176849404182965],[0.3350585537496382,0.2949650517770683],[0.3350585537496382,0.5273702911813317],[0.6403023207536772,0.7670459256438553],[0.6403023207536772,0.5096609465005195],[0.6403023207536772,0.5273702911813317],[0.6403023207536772,0.6520292797891475],[0.6403023207536772,0.6649554871730126],[0.6403023207536772,0.7483810189890286],[0.430521278698538,0.47738724885640027],[0.430521278698538,0.4864261770589082],[0.430521278698538,0.5273702911813317],[0.39436003118292895,0.4454174987254497],[0.39436003118292895,0.39436003118292895],[0.39436003118292895,0.5273702911813317],[0.48540992073820394,0.5273702911813317],[0.5475352476810662,0.46725188988062477],[0.5475352476810662,0.5273702911813317],[0.4184581518441556,0.4184581518441556],[0.4184581518441556,0.4454174987254497],[0.4184581518441556,0.37238772853881913],[0.4184581518441556,0.5273702911813317],[0.8639999622738026,0.5273702911813317],[0.8639999622738026,0.9564087420034828],[0.6675537786814328,0.5594875154588832],[0.6675537786814328,0.7622356439433351],[0.6675537786814328,0.6649554871730126],[0.6675537786814328,0.5260875552648081],[0.6675537786814328,0.7710731504157251],[0.6675537786814328,0.651284678747614],[0.6675537786814328,0.7469397426983816],[0.6675537786814328,0.8010814415715746],[0.6675537786814328,0.6757251420711579],[0.6675537786814328,0.7272638538465169],[0.6675537786814328,0.7495572849740229],[0.6675537786814328,0.5448191465475354],[0.6675537786814328,0.5273702911813317],[0.7928027598163593,0.5273702911813317],[0.7531227867440443,0.7042899634519145],[0.7622356439433351,0.5273702911813317],[0.34790904717371385,0.5273702911813317],[0.8366710372490394,0.5273702911813317],[0.4530764629204581,0.5167072560318462],[0.4530764629204581,0.44931378564384283],[0.4530764629204581,0.40997393568107054],[0.4530764629204581,0.4658322959020708],[0.4530764629204581,0.4871078639740247],[0.4530764629204581,0.46725188988062477],[0.4530764629204581,0.5085355089048774],[0.877096902978967,0.5273702911813317],[0.3738634677907164,0.3962128954605851],[0.3738634677907164,0.40731554504571377],[0.3738634677907164,0.35594095814264237],[0.3738634677907164,0.36329127930353833],[0.3738634677907164,0.339490529991326],[0.3738634677907164,0.3767405480752065],[0.3738634677907164,0.5273702911813317],[0.8550325710422679,0.5273702911813317],[0.5855843530952799,0.6401117262934481],[0.5855843530952799,0.6968954957038507],[0.5855843530952799,0.7167019153870717],[0.5855843530952799,0.6831222541558417],[0.5855843530952799,0.7871751446700895],[0.5855843530952799,0.7106268413894079],[0.5855843530952799,0.5594875154588832],[0.5855843530952799,0.6180153563450871],[0.5855843530952799,0.6301227041720708],[0.5855843530952799,0.5177148447912643],[0.5855843530952799,0.6986026475011937],[0.5855843530952799,0.6649554871730126],[0.5855843530952799,0.7243670816727983],[0.5855843530952799,0.4864261770589082],[0.5855843530952799,0.5273702911813317],[0.5855843530952799,0.46725188988062477],[0.5855843530952799,0.6074710587608619],[0.5855843530952799,0.6591189655369051],[0.5855843530952799,0.5529824335702461],[0.4715396132256285,0.5273702911813317],[0.4715396132256285,0.5768091365055497],[0.7483810189890286,0.6649554871730126],[0.7670459256438553,0.8189600654341986],[0.7670459256438553,0.6925271287281928],[0.7670459256438553,0.5273702911813317],[0.7670459256438553,0.7935304655073256],[0.7670459256438553,0.8105537647772262],[0.7670459256438553,0.7754670377276417],[0.6182294553862728,0.5273702911813317],[0.6182294553862728,0.5760663534786334],[0.8182375006568635,0.5273702911813317],[0.5200235387316209,0.544539004263694],[0.5200235387316209,0.5273702911813317],[0.396558598150051,0.5273702911813317],[0.396558598150051,0.46232631932681983],[0.396558598150051,0.42859586363905927],[0.8999153118864638,0.5273702911813317],[0.40167020169332,0.46725188988062477],[0.40167020169332,0.5273702911813317],[0.5760663534786334,0.5649709653000902],[0.5760663534786334,0.4864261770589082],[0.5760663534786334,0.5946504680499989],[0.5760663534786334,0.5169218248929459],[0.5760663534786334,0.5878329508692572],[0.5760663534786334,0.5966708414632891],[0.5760663534786334,0.5447150666945445],[0.5760663534786334,0.4850507051728439],[0.5760663534786334,0.6080051629526841],[0.5760663534786334,0.5273702911813317],[0.5760663534786334,0.5987207378759382],[0.5760663534786334,0.6268218014615353],[0.36366893746276097,0.4454174987254497],[0.36366893746276097,0.44135240790243374],[0.5028661165493689,0.5594875154588832],[0.5028661165493689,0.4864261770589082],[0.5028661165493689,0.49714673323819925],[0.5028661165493689,0.49592377787927816],[0.5028661165493689,0.5273702911813317],[0.5028661165493689,0.46232631932681983],[0.5028661165493689,0.5034422420528094],[0.5028661165493689,0.5260875552648081],[0.5028661165493689,0.42091930483654755],[0.339490529991326,0.5273702911813317],[0.43175051267272974,0.46725188988062477],[0.43175051267272974,0.44135240790243374],[0.43175051267272974,0.5273702911813317],[0.44931378564384283,0.46725188988062477],[0.44931378564384283,0.5273702911813317],[0.5034422420528094,0.5594875154588832],[0.5034422420528094,0.49714673323819925],[0.5034422420528094,0.5273702911813317],[0.5034422420528094,0.5260875552648081],[0.5034422420528094,0.42091930483654755],[0.10831624645503504,0.2284611938858925],[0.40731554504571377,0.5273702911813317],[0.6964366138893624,0.5273702911813317],[0.5768091365055497,0.5273702911813317],[0.651284678747614,0.7866984440999546],[0.651284678747614,0.5273702911813317],[0.5350126454523644,0.4864261770589082],[0.5350126454523644,0.4850507051728439],[0.5350126454523644,0.5273702911813317],[0.003015380849707185,0.13777514371507615],[0.6167832479852217,0.596605921943523],[0.6167832479852217,0.5273702911813317],[0.6122920872296445,0.5273702911813317],[0.28258678170836293,0.5273702911813317],[0.21728377584402567,0.5273702911813317],[0.7495572849740229,0.5273702911813317],[0.7847822765559535,0.7847822765559535],[0.7847822765559535,0.5273702911813317],[0.7847822765559535,0.7344383643704192],[0.7847822765559535,0.7138964428690399],[0.24043984372654761,0.5273702911813317],[0.8929393822206129,0.5273702911813317],[0.37618345634908607,0.32466549841724035],[0.37618345634908607,0.33634272929883396],[0.37618345634908607,0.5273702911813317],[0.6831222541558417,0.5273702911813317],[0.5447150666945445,0.5447150666945445],[0.5447150666945445,0.5267863645195076],[0.5447150666945445,0.6080051629526841],[0.5447150666945445,0.5458348865235372],[0.5447150666945445,0.5878329508692572],[0.5447150666945445,0.5260875552648081],[0.5447150666945445,0.5505241768390209],[0.5447150666945445,0.5273702911813317],[0.2526976678148345,0.5273702911813317],[0.5313109656023342,0.46725188988062477],[0.5313109656023342,0.5273702911813317],[0.7415379765400981,0.6277656575160098],[0.7415379765400981,0.5273702911813317],[0.8105537647772262,0.5273702911813317],[0.7388205894069465,0.5273702911813317],[0.7388205894069465,0.6685489782327163],[0.46725188988062477,0.4871078639740247],[0.46725188988062477,0.4658322959020708],[0.46725188988062477,0.510636052227933],[0.46725188988062477,0.5503692923694219],[0.46725188988062477,0.5048020132447048],[0.46725188988062477,0.4082859360018825],[0.46725188988062477,0.5124618527636177],[0.46725188988062477,0.5085355089048774],[0.46725188988062477,0.5332561504933538],[0.46725188988062477,0.43136066141760676],[0.46725188988062477,0.5250628515459467],[0.46725188988062477,0.5273702911813317],[0.46725188988062477,0.5113462489571763],[0.46725188988062477,0.39509450781332645],[0.46725188988062477,0.49699675212891453],[0.46725188988062477,0.4454174987254497],[0.46725188988062477,0.44135240790243374],[0.46725188988062477,0.40997393568107054],[0.46725188988062477,0.4390134984338319],[0.46725188988062477,0.48632283686369515],[0.46725188988062477,0.5329057104081123],[0.46725188988062477,0.5167072560318462],[0.7946978866221922,0.8458135821758563],[0.7946978866221922,0.5273702911813317],[0.7814198436314305,0.7125408561767473],[0.7814198436314305,0.5273702911813317],[0.5529824335702461,0.5273702911813317],[0.5529824335702461,0.5177148447912643],[0.5529824335702461,0.5529824335702461],[0.5649709653000902,0.6080051629526841],[0.5649709653000902,0.5273702911813317],[0.5649709653000902,0.5260875552648081],[0.5649709653000902,0.5878329508692572],[0.8263847481724219,0.5273702911813317],[0.5267863645195076,0.5505241768390209],[0.5267863645195076,0.5273702911813317],[0.5267863645195076,0.5260875552648081],[0.5267863645195076,0.5458348865235372],[0.761656859121696,0.5273702911813317],[0.7872166262798496,0.7618397943634078],[0.7872166262798496,0.5273702911813317],[0.7872166262798496,0.6768329005466855],[0.29952075887699614,0.36833004578891965],[0.29952075887699614,0.5273702911813317],[0.4082859360018825,0.44135240790243374],[0.4082859360018825,0.5273702911813317],[0.19650212578825868,0.0004072719444873302],[0.19650212578825868,0.3883046727706779],[0.19650212578825868,0.5273702911813317],[0.42091930483654755,0.5260875552648081],[0.42091930483654755,0.5273702911813317],[0.42295945765243814,0.5273702911813317],[0.42295945765243814,0.5260875552648081],[0.6080051629526841,0.5946504680499989],[0.5260875552648081,0.5594875154588832],[0.5260875552648081,0.4962091998987209],[0.5260875552648081,0.49714673323819925],[0.5260875552648081,0.5273702911813317],[0.5260875552648081,0.4864261770589082],[0.5260875552648081,0.5505241768390209],[0.7362508636476812,0.5273702911813317],[0.761813628266647,0.6080309874401345],[0.761813628266647,0.5273702911813317],[0.7452906139267168,0.6717153141828879],[0.7452906139267168,0.5273702911813317],[0.2580476450823534,0.5273702911813317],[0.5693465742587844,0.5273702911813317],[0.3567440019403381,0.5273702911813317],[0.4907090195063411,0.47738724885640027],[0.4907090195063411,0.4864261770589082],[0.4907090195063411,0.5273702911813317],[0.4907090195063411,0.5448191465475354],[0.7866984440999546,0.5273702911813317],[0.8109428641580553,0.5273702911813317],[0.7710731504157251,0.5273702911813317],[0.6593906549121756,0.5273702911813317],[0.17699789901213275,0.0666376520597208],[0.17699789901213275,0.15719524760500456],[0.17699789901213275,0.5273702911813317],[0.17699789901213275,0.17699789901213275],[0.17699789901213275,0.05440411351733689],[0.40997393568107054,0.5273702911813317],[0.5071638873750163,0.5273702911813317],[0.5071638873750163,0.49944412323518156],[0.6757251420711579,0.5273702911813317],[0.3258229314629499,0.5273702911813317],[0.3451810016352063,0.36833004578891965],[0.3451810016352063,0.5273702911813317],[0.7138964428690399,0.5273702911813317],[0.7138964428690399,0.7344383643704192],[0.7138964428690399,0.7138964428690399],[0.5946504680499989,0.5273702911813317],[0.5946504680499989,0.5878329508692572],[0.6180153563450871,0.5273702911813317],[0.567920962016376,0.6717153141828879],[0.567920962016376,0.5273702911813317],[0.567920962016376,0.5359688794021277],[0.567920962016376,0.510636052227933],[0.6565697794292283,0.5273702911813317],[0.8556121857527282,0.5273702911813317],[0.33634272929883396,0.5273702911813317],[0.33634272929883396,0.3130781698377906],[0.33634272929883396,0.26121459320914797],[0.6768329005466855,0.7618397943634078],[0.6768329005466855,0.5273702911813317],[0.4232741731428999,0.5273702911813317],[0.6200866052863462,0.5895173731766337],[0.6200866052863462,0.5273702911813317],[0.6717153141828879,0.5273702911813317],[0.3898214122008547,0.42859586363905927],[0.3898214122008547,0.256898169164969],[0.3898214122008547,0.5273702911813317],[0.7935304655073256,0.5273702911813317],[0.28620078997995535,0.42859586363905927],[0.28620078997995535,0.5273702911813317],[0.3337395622473997,0.5273702911813317],[0.3337395622473997,0.2622240439629714],[0.3337395622473997,0.3094196801466035],[0.6968954957038507,0.5273702911813317],[0.8189600654341986,0.5273702911813317],[0.5593387736680957,0.5273702911813317],[0.7085157545233863,0.6277656575160098],[0.7085157545233863,0.5273702911813317],[0.48393231337562054,0.5273702911813317],[0.7675582807520264,0.5273702911813317],[0.7344383643704192,0.5273702911813317],[0.7344383643704192,0.7328624564696022],[0.7344383643704192,0.7344383643704192],[0.4523018886875211,0.4864261770589082],[0.4523018886875211,0.4850507051728439],[0.4523018886875211,0.5273702911813317],[0.3094196801466035,0.5273702911813317],[0.3094196801466035,0.2622240439629714],[0.5048020132447048,0.510636052227933],[0.5048020132447048,0.5273702911813317],[0.2632069130739772,0.21176849404182965],[0.2632069130739772,0.2949650517770683],[0.2632069130739772,0.5273702911813317],[0.7859863180590075,0.5273702911813317],[0.7004173260385501,0.5273702911813317],[0.7004173260385501,0.7328624564696022],[0.6520292797891475,0.5659837781046475],[0.6520292797891475,0.5273702911813317],[0.2668432841062252,0.3661621372044959],[0.2668432841062252,0.3883046727706779],[0.2668432841062252,0.21808878860540684],[0.8673087402297465,0.5273702911813317],[0.21176849404182965,0.2949650517770683],[0.21176849404182965,0.25937843210368355],[0.21176849404182965,0.25536819436085423],[0.4850507051728439,0.4864261770589082],[0.4850507051728439,0.4850507051728439],[0.4850507051728439,0.5273702911813317],[0.4850507051728439,0.3883046727706779],[0.49714673323819925,0.5273702911813317],[0.2170270862194745,0.5273702911813317],[0.3661621372044959,0.5273702911813317],[0.8045028091519743,0.5273702911813317],[0.4454174987254497,0.4454174987254497],[0.4454174987254497,0.3570884139781243],[0.4454174987254497,0.34822187064016563],[0.4454174987254497,0.37238772853881913],[0.4454174987254497,0.44135240790243374],[0.4454174987254497,0.510636052227933],[0.4454174987254497,0.42179931848929575],[0.4454174987254497,0.5273702911813317],[0.6978388426777503,0.5273702911813317],[0.9009080692474105,0.5273702911813317],[0.19425256693751614,0.5273702911813317],[0.7266454077620865,0.7052668737315834],[0.3130781698377906,0.38710514416806735],[0.15719524760500456,0.1956204643491215],[0.5276767715252405,0.5273702911813317],[0.510636052227933,0.5359688794021277],[0.510636052227933,0.5332561504933538],[0.510636052227933,0.5329057104081123],[0.510636052227933,0.5273702911813317],[0.510636052227933,0.510636052227933],[0.510636052227933,0.5124618527636177],[0.5124618527636177,0.5273702911813317],[0.5124618527636177,0.5359688794021277],[0.627272250059462,0.5273702911813317],[0.8429349676089558,0.7560820530487513],[0.8429349676089558,0.5273702911813317],[0.42179931848929575,0.5273702911813317],[0.6824933772230014,0.7131000611151268],[0.6824933772230014,0.5273702911813317],[0.7243670816727983,0.5273702911813317],[0.7516747463259655,0.5273702911813317],[0.5329057104081123,0.5273702911813317],[0.46232631932681983,0.4864261770589082],[0.46232631932681983,0.5096609465005195],[0.46232631932681983,0.5273702911813317],[0.46232631932681983,0.46232631932681983],[0.166819139529403,0.03387804922264454],[0.166819139529403,0.5273702911813317],[0.34822187064016563,0.34822187064016563],[0.34822187064016563,0.5273702911813317],[0.34822187064016563,0.3570884139781243],[0.25536819436085423,0.2949650517770683],[0.25536819436085423,0.5273702911813317],[0.8010814415715746,0.5273702911813317],[0.6401117262934481,0.5273702911813317],[0.13777514371507615,0.01491152415878895],[0.13777514371507615,0.5273702911813317],[0.5659837781046475,0.46741740038951296],[0.5659837781046475,0.5273702911813317],[0.4536149058326496,0.36833004578891965],[0.4536149058326496,0.5273702911813317],[0.7052668737315834,0.5273702911813317],[0.5332561504933538,0.5273702911813317],[0.7042899634519145,0.5273702911813317],[0.5961847279537155,0.5273702911813317],[0.2753690782443153,0.5273702911813317],[0.4658322959020708,0.5273702911813317],[0.8636362988904436,0.5273702911813317],[0.29134409322657606,0.5273702911813317],[0.8764029275146705,0.5273702911813317],[0.869789378211215,0.5273702911813317],[0.7106268413894079,0.5273702911813317],[0.5907137988525875,0.5096609465005195],[0.5907137988525875,0.5273702911813317],[0.28602282595682754,0.5273702911813317],[0.2284611938858925,0.5273702911813317],[0.5985644739547227,0.5273702911813317],[0.6649554871730126,0.5273702911813317],[0.6649554871730126,0.6080309874401345],[0.25937843210368355,0.2949650517770683],[0.25937843210368355,0.5273702911813317],[0.2358727100151212,0.5273702911813317],[0.8790374985140805,0.5273702911813317],[0.44810173436769446,0.5273702911813317],[0.5250628515459467,0.5273702911813317],[0.256898169164969,0.5273702911813317],[0.39509450781332645,0.5273702911813317],[0.2949650517770683,0.5273702911813317],[0.3883046727706779,0.4864261770589082],[0.3883046727706779,0.5273702911813317],[0.6781321865441622,0.5273702911813317],[0.7167019153870717,0.5273702911813317],[0.5966708414632891,0.5273702911813317],[0.44135240790243374,0.5273702911813317],[0.44135240790243374,0.48632283686369515],[0.6518500628476263,0.5273702911813317],[0.42859586363905927,0.2879879844646292],[0.42859586363905927,0.5096609465005195],[0.42859586363905927,0.5273702911813317],[0.42859586363905927,0.42859586363905927],[0.42859586363905927,0.46741740038951296],[0.7131000611151268,0.726770167517955],[0.7131000611151268,0.5273702911813317],[0.5085355089048774,0.5273702911813317],[0.35660111712708964,0.5273702911813317],[0.5113462489571763,0.5273702911813317],[0.726770167517955,0.5273702911813317],[0.6080309874401345,0.6277656575160098],[0.6080309874401345,0.5273702911813317],[0.6080309874401345,0.7328624564696022],[0.2340754405001311,0.5273702911813317],[0.7754670377276417,0.5273702911813317],[0.47738724885640027,0.5594875154588832],[0.47738724885640027,0.4864261770589082],[0.47738724885640027,0.47738724885640027],[0.47738724885640027,0.5273702911813317],[0.8628547242807124,0.5273702911813317],[0.6925271287281928,0.6925271287281928],[0.6925271287281928,0.5273702911813317],[0.23564451833165584,0.5273702911813317],[0.20315850054990733,0.5273702911813317],[0.5359688794021277,0.5273702911813317],[0.36329127930353833,0.5273702911813317],[0.6986026475011937,0.5273702911813317],[0.7560820530487513,0.5273702911813317],[0.35594095814264237,0.5273702911813317],[0.28311721776637655,0.5273702911813317],[0.4962091998987209,0.5273702911813317],[0.2879879844646292,0.5273702911813317],[0.49699675212891453,0.5273702911813317],[0.5167072560318462,0.5273702911813317],[0.26121459320914797,0.32466549841724035],[0.4529860888516215,0.4864261770589082],[0.4529860888516215,0.5273702911813317],[0.4529860888516215,0.5448191465475354],[0.4016712656772196,0.4864261770589082],[0.4016712656772196,0.5273702911813317],[0.4871078639740247,0.5273702911813317],[0.5169218248929459,0.5273702911813317],[0.596605921943523,0.5273702911813317],[0.5413675166391315,0.5273702911813317],[0.37238772853881913,0.5273702911813317],[0.21808878860540684,0.5273702911813317],[0.38710514416806735,0.5273702911813317],[0.3962128954605851,0.5273702911813317],[0.3706081060186885,0.5273702911813317],[0.5503692923694219,0.5273702911813317],[0.46741740038951296,0.5273702911813317],[0.46741740038951296,0.46741740038951296],[0.1893636514025236,0.5273702911813317],[0.40801296993013914,0.5273702911813317],[0.4864261770589082,0.49592377787927816],[0.4864261770589082,0.5594875154588832],[0.4864261770589082,0.4864261770589082],[0.4864261770589082,0.5273702911813317],[0.4864261770589082,0.5448191465475354],[0.5895173731766337,0.5273702911813317],[0.6685489782327163,0.5273702911813317],[0.6301227041720708,0.5273702911813317],[0.36833004578891965,0.5273702911813317],[0.43136066141760676,0.5273702911813317],[0.32937314578834825,0.5273702911813317],[0.34599043477666275,0.5273702911813317],[0.2743397678659176,0.5273702911813317],[0.5273702911813317,0.7272638538465169],[0.5273702911813317,0.6074710587608619],[0.5273702911813317,0.6293972386035256],[0.5273702911813317,0.7994834301821617],[0.5273702911813317,0.8074746819308689],[0.5273702911813317,0.6924426591714892],[0.5273702911813317,0.5273702911813317],[0.5273702911813317,0.25876633382212216],[0.5273702911813317,0.7328624564696022],[0.5273702911813317,0.4390134984338319],[0.5273702911813317,0.5096609465005195],[0.5273702911813317,0.5505241768390209],[0.5273702911813317,0.28638920473736407],[0.5273702911813317,0.1322454057651943],[0.5273702911813317,0.3767405480752065],[0.5273702911813317,0.49592377787927816],[0.5273702911813317,0.32466549841724035],[0.5273702911813317,0.6277656575160098],[0.5273702911813317,0.7469397426983816],[0.5273702911813317,0.1956204643491215],[0.5273702911813317,0.7125408561767473],[0.5273702911813317,0.5594875154588832],[0.5273702911813317,0.8867889565968607],[0.5273702911813317,0.3570884139781243],[0.5273702911813317,0.5177148447912643],[0.5273702911813317,0.7618397943634078],[0.5273702911813317,0.544539004263694],[0.5273702911813317,0.48632283686369515],[0.5273702911813317,0.6522806171755322],[0.5273702911813317,0.3093605027419721],[0.5273702911813317,0.5448191465475354],[0.5273702911813317,0.8514221020669225],[0.5096609465005195,0.5096609465005195],[0.5505241768390209,0.5458348865235372],[0.6277656575160098,0.6277656575160098],[0.6591189655369051,0.6074710587608619],[0.5177148447912643,0.5177148447912643],[0.6074710587608619,0.6074710587608619],[0.7618397943634078,0.7618397943634078]],\"ys\":[[0.660432871437816,0.6580949110185261],[0.660432871437816,0.48046567508521565],[0.660432871437816,0.6034712410443259],[0.660432871437816,0.6156320944435291],[0.660432871437816,0.6143159256020416],[0.25983621371186605,0.4644265933240915],[0.7332106471142972,0.6555924748004226],[0.7332106471142972,0.5884439725024153],[0.24383610004311296,0.41569664957548513],[0.3073870265835071,0.4644265933240915],[0.3073870265835071,0.33055713136062487],[0.6713688656097923,0.6762104750895189],[0.6713688656097923,0.6177264302342022],[0.6713688656097923,0.4644265933240915],[0.16408292422416088,0.4644265933240915],[0.4415399262979149,0.41569664957548513],[0.4415399262979149,0.5007766899277777],[0.4415399262979149,0.3872220465602767],[0.4415399262979149,0.4644265933240915],[0.4415399262979149,0.468087975974438],[0.4415399262979149,0.43293099809978064],[0.4415399262979149,0.4415399262979149],[0.7392730165959559,0.4644265933240915],[0.7392730165959559,0.7113211289585225],[0.7392730165959559,0.9830068707539786],[0.19792836219983753,0.4644265933240915],[0.19792836219983753,0.268006552837604],[0.19792836219983753,0.24086342723742865],[0.19792836219983753,0.0839364307451562],[0.3872220465602767,0.43293099809978064],[0.1125462696946161,0.4644265933240915],[0.30365752381793865,0.2627189451238526],[0.30365752381793865,0.4644265933240915],[0.8682780812412808,0.7444164662901014],[0.8682780812412808,0.7580853182147079],[0.8682780812412808,0.6819393646825664],[0.5435332140153116,0.5146859906287252],[0.5435332140153116,0.4644265933240915],[0.5435332140153116,0.5191506485901891],[0.25737918638708507,0.4644265933240915],[0.25737918638708507,0.35354765901276075],[0.4926392468174273,0.41569664957548513],[0.4926392468174273,0.4198032904377029],[0.4926392468174273,0.4435919918519365],[0.4926392468174273,0.5210969333616969],[0.4926392468174273,0.6143159256020416],[0.6555924748004226,0.5884439725024153],[0.6555924748004226,0.4644265933240915],[0.35354765901276075,0.41569664957548513],[0.35354765901276075,0.2866761446724974],[0.35354765901276075,0.4644265933240915],[0.29026007298482365,0.27779010446024777],[0.29026007298482365,0.23747688018632296],[0.29026007298482365,0.4644265933240915],[0.5034199838939876,0.49224398292360866],[0.5034199838939876,0.4644265933240915],[0.4164583046415229,0.4525379216453794],[0.2242436061445224,0.27007728591199187],[0.2242436061445224,0.4644265933240915],[0.5862690940697507,0.5146859906287252],[0.5862690940697507,0.5204616184970776],[0.5862690940697507,0.5351326715500055],[0.5862690940697507,0.5411998098354136],[0.15956168335173848,0.268006552837604],[0.15956168335173848,0.08710036054342263],[0.15956168335173848,0.4644265933240915],[0.15956168335173848,0.08155316871340108],[0.4081364148795204,0.3512865619336758],[0.4081364148795204,0.4644265933240915],[0.4081364148795204,0.3788913931950467],[0.7423330343043048,0.6904226612863027],[0.7423330343043048,0.4644265933240915],[0.7423330343043048,0.6143159256020416],[0.7119263878031391,0.4644265933240915],[1.0,0.8557571722218559],[1.0,0.8528721121156967],[0.23709655038122238,0.30604823057945385],[0.23709655038122238,0.2678319918497413],[0.23709655038122238,0.3694577704292969],[0.23709655038122238,0.4644265933240915],[0.479491914506478,0.42462563666944586],[0.479491914506478,0.5782368882477646],[0.479491914506478,0.4644265933240915],[0.479491914506478,0.45250458946179123],[0.479491914506478,0.4977491277771893],[0.479491914506478,0.5411998098354136],[0.224994162377506,0.3694577704292969],[0.224994162377506,0.4644265933240915],[0.831282443778007,0.6980098944564919],[0.831282443778007,0.6034712410443259],[0.831282443778007,0.7146508825410139],[0.2694545569779559,0.4644265933240915],[0.2694545569779559,0.39651518609686176],[0.19594640773543653,0.2394744818775305],[0.19594640773543653,0.4644265933240915],[0.4507684163240844,0.5007766899277777],[0.4507684163240844,0.4644265933240915],[0.7519820126003876,0.691886326565762],[0.7519820126003876,0.4644265933240915],[0.7519820126003876,0.7455202993113186],[0.37938243566997665,0.4644265933240915],[0.40944090394725324,0.41569664957548513],[0.40944090394725324,0.3694577704292969],[0.40944090394725324,0.4644265933240915],[0.40944090394725324,0.3574758276477921],[0.40944090394725324,0.35319012821601903],[0.40944090394725324,0.40944090394725324],[0.40944090394725324,0.321680047850924],[0.40944090394725324,0.48979672257253865],[0.16969556638132585,0.4644265933240915],[0.40775345452754036,0.4058441348357288],[0.40775345452754036,0.4285635536904042],[0.40775345452754036,0.4644265933240915],[0.16036723110733567,0.268006552837604],[0.16036723110733567,0.08710036054342263],[0.16036723110733567,0.4644265933240915],[0.16036723110733567,0.08155316871340108],[0.7164114852181838,0.6904226612863027],[0.7164114852181838,0.4644265933240915],[0.7164114852181838,0.6143159256020416],[0.7474388513889462,0.6904226612863027],[0.7474388513889462,0.4644265933240915],[0.7474388513889462,0.6143159256020416],[0.13390310266931893,0.4644265933240915],[0.5716356784561741,0.5936053922055856],[0.5716356784561741,0.5716356784561741],[0.5716356784561741,0.4644265933240915],[0.5716356784561741,0.5750826143843594],[0.5716356784561741,0.6017510295555455],[0.5716356784561741,0.6314946864402609],[0.5716356784561741,0.5505574055447559],[0.5716356784561741,0.6386468337920613],[0.5716356784561741,0.7113211289585225],[0.42047350559793945,0.41569664957548513],[0.42047350559793945,0.46463118186664565],[0.42047350559793945,0.4644265933240915],[0.6279263550325983,0.5782368882477646],[0.6279263550325983,0.4644265933240915],[0.6279263550325983,0.5411998098354136],[0.5478678495498374,0.4644265933240915],[0.5478678495498374,0.5140240042309399],[0.7357940507538124,0.8554334126061353],[0.7357940507538124,0.4644265933240915],[0.10193544041342725,0.30604823057945385],[0.10193544041342725,0.3694577704292969],[0.8315177459730111,0.4644265933240915],[0.8315177459730111,0.9722576374189348],[0.8315177459730111,0.8370998501953743],[0.5704206344468208,0.4644265933240915],[0.5704206344468208,0.5140240042309399],[0.4665701285897894,0.4935214922361755],[0.4665701285897894,0.42664086597482787],[0.4665701285897894,0.4644265933240915],[0.6114884559743814,0.5661247818553705],[0.6114884559743814,0.5884439725024153],[0.6114884559743814,0.5476713970682007],[0.6114884559743814,0.5392331611303647],[0.8480644043231941,0.4644265933240915],[0.8480644043231941,0.9970655067320642],[0.3836060316311979,0.41569664957548513],[0.3836060316311979,0.3642910540840711],[0.3836060316311979,0.4644265933240915],[0.48867307066228693,0.4644265933240915],[0.8129565908543038,0.8830079150374622],[0.8129565908543038,0.6904226612863027],[0.8129565908543038,0.4644265933240915],[0.5457359122517992,0.5204616184970776],[0.5457359122517992,0.5756934843630539],[0.5457359122517992,0.4644265933240915],[0.5457359122517992,0.5411998098354136],[0.5457359122517992,0.5146859906287252],[0.5457359122517992,0.5324797516965024],[0.5457359122517992,0.5464994824749025],[0.5457359122517992,0.5191506485901891],[0.5351326715500055,0.5146859906287252],[0.5351326715500055,0.4644265933240915],[0.5351326715500055,0.5411998098354136],[0.3744413623546023,0.27600443680581555],[0.3744413623546023,0.20246350467293522],[0.3744413623546023,0.4644265933240915],[0.1680352984790842,0.4644265933240915],[0.1680352984790842,0.15031846957277747],[0.28765897036398186,0.4644265933240915],[0.5007766899277777,0.5071788679257944],[0.5007766899277777,0.37439611908434434],[0.5007766899277777,0.4598101669700343],[0.5007766899277777,0.41747798898431937],[0.5007766899277777,0.5007766899277777],[0.5007766899277777,0.582176442627514],[0.5007766899277777,0.6015546785961549],[0.5007766899277777,0.4644265933240915],[0.5007766899277777,0.6237727305021749],[0.5007766899277777,0.5655243837424004],[0.5007766899277777,0.43293099809978064],[0.19933334488961252,0.4644265933240915],[0.19933334488961252,0.33055713136062487],[0.002798961435541578,0.24488037792617978],[0.7641417465286434,0.7371297618622412],[0.7641417465286434,0.4644265933240915],[0.3574758276477921,0.41569664957548513],[0.3574758276477921,0.27007728591199187],[0.3574758276477921,0.4644265933240915],[0.6745803882193274,0.6429307396691056],[0.6745803882193274,0.5782368882477646],[0.6745803882193274,0.4644265933240915],[0.6745803882193274,0.6745803882193274],[0.6745803882193274,0.6191203260359933],[0.6745803882193274,0.70196767347563],[0.6143159256020416,0.6162626818062846],[0.6143159256020416,0.6143159256020416],[0.6143159256020416,0.6580949110185261],[0.6143159256020416,0.6355543158364171],[0.6143159256020416,0.5633846671937589],[0.6143159256020416,0.6034712410443259],[0.6143159256020416,0.7311120412458607],[0.6143159256020416,0.7510563490127009],[0.6143159256020416,0.6500322109180686],[0.6143159256020416,0.7211525475839037],[0.6143159256020416,0.7088679714710461],[0.6143159256020416,0.6891849194688708],[0.6143159256020416,0.5993878107889014],[0.6143159256020416,0.7321686807058896],[0.6143159256020416,0.6852702632643184],[0.6143159256020416,0.7334027682174646],[0.6143159256020416,0.6318110145695137],[0.6143159256020416,0.41569664957548513],[0.6143159256020416,0.5671348921371102],[0.6143159256020416,0.6085669803114362],[0.6143159256020416,0.7193167344323413],[0.6143159256020416,0.7089756923612295],[0.6143159256020416,0.6424909535271728],[0.6143159256020416,0.7452829125960218],[0.6143159256020416,0.7527254406328888],[0.6143159256020416,0.7504090640510136],[0.6143159256020416,0.6861984278986488],[0.6143159256020416,0.6156320944435291],[0.6143159256020416,0.7310000899182425],[0.6143159256020416,0.6904226612863027],[0.6143159256020416,0.7217819685043624],[0.6143159256020416,0.6958513172750607],[0.6143159256020416,0.4644265933240915],[0.7995760532528451,0.8830079150374622],[0.7995760532528451,0.6904226612863027],[0.7995760532528451,0.4644265933240915],[0.2394744818775305,0.22637531395393293],[0.2394744818775305,0.2197776096402575],[0.2394744818775305,0.4644265933240915],[0.2394744818775305,0.17837135328717482],[0.2394744818775305,0.19584745008425958],[0.2394744818775305,0.20490598362692178],[0.2394744818775305,0.33843500925763914],[0.2394744818775305,0.30898003112970135],[0.7345271082885712,0.6429307396691056],[0.7345271082885712,0.5681739762661152],[0.7345271082885712,0.6191203260359933],[0.19584745008425958,0.4644265933240915],[0.3850658234158584,0.41569664957548513],[0.3850658234158584,0.3850658234158584],[0.3850658234158584,0.4644265933240915],[0.3850658234158584,0.3975901164304786],[0.5634640869349782,0.5146859906287252],[0.5634640869349782,0.5324797516965024],[0.5634640869349782,0.4644265933240915],[0.5634640869349782,0.5411998098354136],[0.42687603977834965,0.46463118186664565],[0.42687603977834965,0.4644265933240915],[0.6162626818062846,0.8078391955329095],[0.6162626818062846,0.4644265933240915],[0.6162626818062846,0.6085669803114362],[0.6162626818062846,0.5993878107889014],[0.6162626818062846,0.6904226612863027],[0.6162626818062846,0.6034712410443259],[0.6162626818062846,0.6500322109180686],[0.1323325629683591,0.4644265933240915],[0.43351085519853894,0.4644265933240915],[0.43351085519853894,0.4412738654608661],[0.7334027682174646,0.6904226612863027],[0.7334027682174646,0.4644265933240915],[0.6929474037593202,0.5681739762661152],[0.6929474037593202,0.579640533495896],[0.4598101669700343,0.468087975974438],[0.4598101669700343,0.4644265933240915],[0.4876032944294878,0.48453723694984574],[0.4876032944294878,0.45967477884167124],[0.4876032944294878,0.4812389911319088],[0.4876032944294878,0.4644265933240915],[0.4935214922361755,0.4644265933240915],[0.5332065483951346,0.4644265933240915],[0.5332065483951346,0.5140240042309399],[0.2197776096402575,0.4644265933240915],[0.6865036503447209,0.5505574055447559],[0.6865036503447209,0.4644265933240915],[0.4889075870448013,0.4644265933240915],[0.4889075870448013,0.5116991430043761],[0.816696387794036,0.8830079150374622],[0.816696387794036,0.6904226612863027],[0.816696387794036,0.4644265933240915],[0.17145904021242891,0.2627189451238526],[0.17145904021242891,0.09014206234609701],[0.17145904021242891,0.4644265933240915],[0.6026806938089542,0.628402889749191],[0.6026806938089542,0.4644265933240915],[0.47425440150618353,0.4525379216453794],[0.6624697707834359,0.5505574055447559],[0.6624697707834359,0.4644265933240915],[0.24484892440599748,0.4644265933240915],[0.24484892440599748,0.2545198557999168],[0.6819393646825664,0.7444164662901014],[0.6819393646825664,0.4644265933240915],[0.6819393646825664,0.7580853182147079],[0.532079273991722,0.4644265933240915],[0.3248285503180051,0.41569664957548513],[0.3248285503180051,0.3975901164304786],[0.6429307396691056,0.5782368882477646],[0.6429307396691056,0.4644265933240915],[0.6429307396691056,0.6191203260359933],[0.6429307396691056,0.5681739762661152],[0.6429307396691056,0.70196767347563],[0.6429307396691056,0.649129723689199],[0.6429307396691056,0.74877366793852],[0.22637531395393293,0.4644265933240915],[0.5586561342032628,0.4644265933240915],[0.7193167344323413,0.6904226612863027],[0.7193167344323413,0.4644265933240915],[0.21154712567125186,0.41569664957548513],[0.32830933898901904,0.4644265933240915],[0.32830933898901904,0.3814101792614075],[0.7002219082501343,0.6904226612863027],[0.7002219082501343,0.4644265933240915],[0.7002219082501343,0.923372596923963],[0.637701616562345,0.7462947759422153],[0.637701616562345,0.5269626819567745],[0.637701616562345,0.630801416528471],[0.637701616562345,0.4644265933240915],[0.637701616562345,0.6535846371981258],[0.637701616562345,0.7237466047750631],[0.24375376247989744,0.4644265933240915],[0.20963739924688715,0.2576482912815104],[0.20963739924688715,0.4644265933240915],[0.20963739924688715,0.24086342723742865],[0.20963739924688715,0.268006552837604],[0.5633846671937589,0.5993878107889014],[0.5633846671937589,0.6904226612863027],[0.5633846671937589,0.4644265933240915],[0.10182279050687786,0.4644265933240915],[0.3961863164628086,0.32811574748523936],[0.3961863164628086,0.4644265933240915],[0.3961863164628086,0.3756304159096863],[0.48979672257253865,0.41569664957548513],[0.48979672257253865,0.3694577704292969],[0.48979672257253865,0.4644265933240915],[0.48979672257253865,0.468087975974438],[0.48979672257253865,0.6762104750895189],[0.48979672257253865,0.6177264302342022],[0.48979672257253865,0.3814101792614075],[0.31762800862395507,0.1081767734249794],[0.31762800862395507,0.4644265933240915],[0.5936053922055856,0.5505574055447559],[0.5936053922055856,0.6386468337920613],[0.5936053922055856,0.4644265933240915],[0.5936053922055856,0.7113211289585225],[0.5835240296844172,0.4644265933240915],[0.5835240296844172,0.5210969333616969],[0.5835240296844172,0.5505574055447559],[0.5835240296844172,0.6386468337920613],[0.5835240296844172,0.7113211289585225],[0.5835240296844172,0.5371251862374531],[0.5973150253917375,0.6904226612863027],[0.5973150253917375,0.5342409109794203],[0.5973150253917375,0.4644265933240915],[0.5973150253917375,0.5552044611623879],[0.09014206234609701,0.2627189451238526],[0.09014206234609701,0.268006552837604],[0.17837135328717482,0.4644265933240915],[0.5354332583594661,0.4644265933240915],[0.49321589761667906,0.4644265933240915],[0.691886326565762,0.7455202993113186],[0.691886326565762,0.4644265933240915],[0.691886326565762,0.9463574822795291],[0.7612193446686886,0.8731475419437271],[0.7612193446686886,0.4644265933240915],[0.31595608407855186,0.4644265933240915],[0.24019339361525108,0.24019339361525108],[0.24019339361525108,0.22863153884520127],[0.24019339361525108,0.4644265933240915],[0.630801416528471,0.7462947759422153],[0.630801416528471,0.5269626819567745],[0.630801416528471,0.4644265933240915],[0.630801416528471,0.6535846371981258],[0.630801416528471,0.7237466047750631],[0.12164262906037887,0.4644265933240915],[0.49224398292360866,0.4644265933240915],[0.18969589121840597,0.18221201116375585],[0.18969589121840597,0.4644265933240915],[0.0839364307451562,0.268006552837604],[0.0839364307451562,0.24086342723742865],[0.3642910540840711,0.41569664957548513],[0.3642910540840711,0.4607304950314831],[0.5204616184970776,0.5204616184970776],[0.5204616184970776,0.5756934843630539],[0.5204616184970776,0.4644265933240915],[0.5204616184970776,0.5411998098354136],[0.5204616184970776,0.5146859906287252],[0.5204616184970776,0.5324797516965024],[0.5204616184970776,0.5464994824749025],[0.5204616184970776,0.5191506485901891],[0.5803926327104053,0.4644265933240915],[0.02602260530775652,0.268006552837604],[0.32625936365022923,0.41569664957548513],[0.32625936365022923,0.4644265933240915],[0.8023112618661227,0.8830079150374622],[0.8023112618661227,0.6904226612863027],[0.8023112618661227,0.4644265933240915],[0.41569664957548513,0.5269626819567745],[0.41569664957548513,0.35091370069078043],[0.41569664957548513,0.3811804114215997],[0.41569664957548513,0.321680047850924],[0.41569664957548513,0.2877245275031935],[0.41569664957548513,0.2866761446724974],[0.41569664957548513,0.35319012821601903],[0.41569664957548513,0.36705657941491054],[0.41569664957548513,0.4198032904377029],[0.41569664957548513,0.5210969333616969],[0.41569664957548513,0.611776552412223],[0.41569664957548513,0.32903756454915417],[0.41569664957548513,0.3975901164304786],[0.41569664957548513,0.41747798898431937],[0.41569664957548513,0.35372947827716217],[0.41569664957548513,0.28967045807142405],[0.41569664957548513,0.39723488268211155],[0.41569664957548513,0.4644265933240915],[0.41569664957548513,0.4435919918519365],[0.41569664957548513,0.3015005471981137],[0.41569664957548513,0.30163224913901937],[0.18417900132468612,0.4644265933240915],[0.5411998098354136,0.4977491277771893],[0.5411998098354136,0.5782368882477646],[0.5411998098354136,0.5464994824749025],[0.5411998098354136,0.5756934843630539],[0.5411998098354136,0.4607304950314831],[0.5411998098354136,0.7487474820814098],[0.5411998098354136,0.5146859906287252],[0.5411998098354136,0.4644265933240915],[0.5411998098354136,0.5324797516965024],[0.5411998098354136,0.7131321290633202],[0.3811804114215997,0.4644265933240915],[0.23966908896035619,0.4644265933240915],[0.5884439725024153,0.5661247818553705],[0.5884439725024153,0.4644265933240915],[0.5884439725024153,0.5476713970682007],[0.5884439725024153,0.5392331611303647],[0.5191506485901891,0.5146859906287252],[0.5191506485901891,0.4644265933240915],[0.5191506485901891,0.4977491277771893],[0.5464994824749025,0.4607304950314831],[0.5464994824749025,0.5586600444464479],[0.5464994824749025,0.5146859906287252],[0.5464994824749025,0.527730855490007],[0.3054425167881268,0.4644265933240915],[0.8370998501953743,0.4644265933240915],[0.8370998501953743,0.9722576374189348],[0.7321686807058896,0.6904226612863027],[0.7321686807058896,0.4644265933240915],[0.5381327218855235,0.6244488551073897],[0.5381327218855235,0.5999866263324974],[0.5381327218855235,0.4644265933240915],[0.5381327218855235,0.5381327218855235],[0.5381327218855235,0.46463118186664565],[0.5381327218855235,0.5671348921371102],[0.32903756454915417,0.4644265933240915],[0.45567894400574516,0.46463118186664565],[0.45567894400574516,0.4644265933240915],[0.3336401440765844,0.4644265933240915],[0.5091876625107056,0.4644265933240915],[0.5091876625107056,0.5140240042309399],[0.3461691993004907,0.4644265933240915],[0.3461691993004907,0.3814101792614075],[0.5940705956617384,0.6762104750895189],[0.5940705956617384,0.6177264302342022],[0.5940705956617384,0.4644265933240915],[0.6191203260359933,0.628402889749191],[0.6191203260359933,0.5782368882477646],[0.6191203260359933,0.4644265933240915],[0.6191203260359933,0.649129723689199],[0.6191203260359933,0.5681739762661152],[0.6191203260359933,0.74877366793852],[0.2500794065488848,0.30604823057945385],[0.2500794065488848,0.3694577704292969],[0.2500794065488848,0.4644265933240915],[0.657086202431473,0.6034712410443259],[0.657086202431473,0.657086202431473],[0.657086202431473,0.4644265933240915],[0.105211734290933,0.4644265933240915],[0.7504090640510136,0.6904226612863027],[0.7504090640510136,0.4644265933240915],[0.6156320944435291,0.6156320944435291],[0.6156320944435291,0.6034712410443259],[0.6156320944435291,0.6580949110185261],[0.6156320944435291,0.4644265933240915],[0.6355438452819554,0.4644265933240915],[0.6355438452819554,0.7034586032808088],[0.3814101792614075,0.388417647624072],[0.3814101792614075,0.35124935361294507],[0.3814101792614075,0.5681739762661152],[0.3814101792614075,0.33055713136062487],[0.3814101792614075,0.3076447431098306],[0.3814101792614075,0.4452292275739381],[0.3814101792614075,0.32365947792215594],[0.3814101792614075,0.3662196950547806],[0.3814101792614075,0.3529082566550165],[0.3814101792614075,0.29959065960548625],[0.3814101792614075,0.290973142510098],[0.3814101792614075,0.39651518609686176],[0.3814101792614075,0.4644265933240915],[0.22863153884520127,0.4644265933240915],[0.9312095100973454,0.8086494090192747],[0.35124935361294507,0.4644265933240915],[0.321680047850924,0.4644265933240915],[0.2851408486858898,0.4644265933240915],[0.8830079150374622,0.7968717860750494],[0.8830079150374622,0.7900187994632909],[0.8830079150374622,0.7890076050183971],[0.8830079150374622,0.8045534864851885],[0.8830079150374622,0.7941581650806059],[0.8830079150374622,0.6904226612863027],[0.8830079150374622,0.8134193274559792],[0.4281253663696925,0.4644265933240915],[0.18221201116375585,0.15869576594179613],[0.18221201116375585,0.18444928769237487],[0.18221201116375585,0.19731172210428197],[0.18221201116375585,0.16016274624505258],[0.18221201116375585,0.16852785115334742],[0.18221201116375585,0.13741285746048232],[0.18221201116375585,0.4644265933240915],[0.5943727764857878,0.4644265933240915],[0.5505574055447559,0.6946543424032136],[0.5505574055447559,0.6797349754383587],[0.5505574055447559,0.6383001874738673],[0.5505574055447559,0.6314946864402609],[0.5505574055447559,0.8223984231829917],[0.5505574055447559,0.6594916630702127],[0.5505574055447559,0.388417647624072],[0.5505574055447559,0.5145525649499937],[0.5505574055447559,0.5750826143843594],[0.5505574055447559,0.5210969333616969],[0.5505574055447559,0.6017510295555455],[0.5505574055447559,0.5681739762661152],[0.5505574055447559,0.608632763773559],[0.5505574055447559,0.3694577704292969],[0.5505574055447559,0.4644265933240915],[0.5505574055447559,0.6904226612863027],[0.5505574055447559,0.6386468337920613],[0.5505574055447559,0.7113211289585225],[0.5505574055447559,0.5371251862374531],[0.36705657941491054,0.4644265933240915],[0.36705657941491054,0.33843500925763914],[0.74877366793852,0.5681739762661152],[0.628402889749191,0.6399926936563858],[0.628402889749191,0.5514117581134003],[0.628402889749191,0.4644265933240915],[0.628402889749191,0.6586521543222597],[0.628402889749191,0.6210846640660135],[0.628402889749191,0.6797909978021992],[0.2627189451238526,0.4644265933240915],[0.2627189451238526,0.268006552837604],[0.6741822813624635,0.4644265933240915],[0.8557571722218559,0.8528721121156967],[0.8557571722218559,0.4644265933240915],[0.4977491277771893,0.4644265933240915],[0.4977491277771893,0.45250458946179123],[0.4977491277771893,0.5146859906287252],[0.4393404746789394,0.4644265933240915],[0.7089756923612295,0.6904226612863027],[0.7089756923612295,0.4644265933240915],[0.268006552837604,0.2576482912815104],[0.268006552837604,0.3694577704292969],[0.268006552837604,0.16173073020245696],[0.268006552837604,0.39723488268211155],[0.268006552837604,0.08155316871340108],[0.268006552837604,0.24086342723742865],[0.268006552837604,0.27420827225574895],[0.268006552837604,0.33364665792653025],[0.268006552837604,0.08710036054342263],[0.268006552837604,0.4644265933240915],[0.268006552837604,0.012014781810010287],[0.268006552837604,0.04536084763174147],[0.8078391955329095,0.6034712410443259],[0.8078391955329095,0.6500322109180686],[0.3682142606449557,0.388417647624072],[0.3682142606449557,0.3694577704292969],[0.3682142606449557,0.2402041690827045],[0.3682142606449557,0.4030728953171881],[0.3682142606449557,0.4644265933240915],[0.3682142606449557,0.45250458946179123],[0.3682142606449557,0.2961160615424195],[0.3682142606449557,0.33055713136062487],[0.3682142606449557,0.37439611908434434],[0.16852785115334742,0.4644265933240915],[0.6958513172750607,0.6904226612863027],[0.6958513172750607,0.6500322109180686],[0.6958513172750607,0.4644265933240915],[0.7900187994632909,0.6904226612863027],[0.7900187994632909,0.4644265933240915],[0.2961160615424195,0.388417647624072],[0.2961160615424195,0.2402041690827045],[0.2961160615424195,0.4644265933240915],[0.2961160615424195,0.33055713136062487],[0.2961160615424195,0.37439611908434434],[0.3512865619336758,0.3788913931950467],[0.18444928769237487,0.4644265933240915],[0.3756304159096863,0.4644265933240915],[0.33843500925763914,0.4644265933240915],[0.4452292275739381,0.444027353342111],[0.4452292275739381,0.4644265933240915],[0.35537686614228586,0.3694577704292969],[0.35537686614228586,0.33364665792653025],[0.35537686614228586,0.4644265933240915],[0.4385303799398052,0.41254406548995315],[0.3377009970768298,0.3698943178774708],[0.3377009970768298,0.4644265933240915],[0.3951994930091709,0.4644265933240915],[0.4198032904377029,0.4644265933240915],[0.3292708222451807,0.4644265933240915],[0.290973142510098,0.4644265933240915],[0.5661247818553705,0.5661247818553705],[0.5661247818553705,0.4644265933240915],[0.5661247818553705,0.5476713970682007],[0.5661247818553705,0.5392331611303647],[0.5071788679257944,0.4644265933240915],[0.4049271448617068,0.4644265933240915],[0.611776552412223,0.76402195296293],[0.611776552412223,0.7976637782492555],[0.611776552412223,0.4644265933240915],[0.6314946864402609,0.4644265933240915],[0.27420827225574895,0.27420827225574895],[0.27420827225574895,0.24488037792617978],[0.27420827225574895,0.08710036054342263],[0.27420827225574895,0.13366888995334028],[0.27420827225574895,0.08155316871340108],[0.27420827225574895,0.33055713136062487],[0.27420827225574895,0.20835868980238664],[0.27420827225574895,0.4644265933240915],[0.2669192248469852,0.4644265933240915],[0.7217819685043624,0.6904226612863027],[0.7217819685043624,0.4644265933240915],[0.4388313367196233,0.45967477884167124],[0.4388313367196233,0.4644265933240915],[0.6210846640660135,0.4644265933240915],[0.2545198557999168,0.4644265933240915],[0.2545198557999168,0.30898003112970135],[0.6904226612863027,0.7941581650806059],[0.6904226612863027,0.8045534864851885],[0.6904226612863027,0.5993878107889014],[0.6904226612863027,0.7088679714710461],[0.6904226612863027,0.6891849194688708],[0.6904226612863027,0.6852702632643184],[0.6904226612863027,0.6318110145695137],[0.6904226612863027,0.8134193274559792],[0.6904226612863027,0.6355543158364171],[0.6904226612863027,0.7452829125960218],[0.6904226612863027,0.7527254406328888],[0.6904226612863027,0.4644265933240915],[0.6904226612863027,0.7310000899182425],[0.6904226612863027,0.7311120412458607],[0.6904226612863027,0.7510563490127009],[0.6904226612863027,0.6034712410443259],[0.6904226612863027,0.6500322109180686],[0.6904226612863027,0.7890076050183971],[0.6904226612863027,0.7211525475839037],[0.6904226612863027,0.6424909535271728],[0.6904226612863027,0.6861984278986488],[0.6904226612863027,0.7968717860750494],[0.19715153275207803,0.1394052277779232],[0.19715153275207803,0.4644265933240915],[0.2717753269630601,0.27600443680581555],[0.2717753269630601,0.4644265933240915],[0.5371251862374531,0.4644265933240915],[0.5371251862374531,0.5210969333616969],[0.5371251862374531,0.5371251862374531],[0.2576482912815104,0.08710036054342263],[0.2576482912815104,0.4644265933240915],[0.2576482912815104,0.33055713136062487],[0.2576482912815104,0.08155316871340108],[0.30899557178097814,0.4644265933240915],[0.24488037792617978,0.20835868980238664],[0.24488037792617978,0.4644265933240915],[0.24488037792617978,0.33055713136062487],[0.24488037792617978,0.13366888995334028],[0.18497468648403095,0.4644265933240915],[0.38789225754056694,0.4058441348357288],[0.38789225754056694,0.4644265933240915],[0.38789225754056694,0.4285635536904042],[0.24740263237564292,0.27007728591199187],[0.24740263237564292,0.4644265933240915],[0.6852702632643184,0.6500322109180686],[0.6852702632643184,0.4644265933240915],[0.45743011437986236,0.5051474678294182],[0.45743011437986236,0.43293099809978064],[0.45743011437986236,0.4644265933240915],[0.37439611908434434,0.33055713136062487],[0.37439611908434434,0.4644265933240915],[0.41747798898431937,0.4644265933240915],[0.41747798898431937,0.33055713136062487],[0.08710036054342263,0.16173073020245696],[0.33055713136062487,0.388417647624072],[0.33055713136062487,0.2030813546636055],[0.33055713136062487,0.2402041690827045],[0.33055713136062487,0.4644265933240915],[0.33055713136062487,0.3694577704292969],[0.33055713136062487,0.20835868980238664],[0.579640533495896,0.4644265933240915],[0.5059293859544223,0.48453723694984574],[0.5059293859544223,0.4644265933240915],[0.6244488551073897,0.5999866263324974],[0.6244488551073897,0.4644265933240915],[0.35091370069078043,0.4644265933240915],[0.11577436713543154,0.4644265933240915],[0.3975901164304786,0.4644265933240915],[0.2678319918497413,0.30604823057945385],[0.2678319918497413,0.3694577704292969],[0.2678319918497413,0.4644265933240915],[0.2678319918497413,0.39651518609686176],[0.444027353342111,0.4644265933240915],[0.27328737251276447,0.4644265933240915],[0.3076447431098306,0.4644265933240915],[0.7455202993113186,0.4644265933240915],[0.6535846371981258,0.7462947759422153],[0.6535846371981258,0.5269626819567745],[0.6535846371981258,0.4644265933240915],[0.6535846371981258,0.6535846371981258],[0.6535846371981258,0.7237466047750631],[0.7890076050183971,0.4644265933240915],[0.08797376753696164,0.4644265933240915],[0.08797376753696164,0.0],[0.3529082566550165,0.4644265933240915],[0.35319012821601903,0.4644265933240915],[0.22008850143988615,0.27007728591199187],[0.22008850143988615,0.4644265933240915],[0.5392331611303647,0.4644265933240915],[0.5392331611303647,0.5476713970682007],[0.5392331611303647,0.5392331611303647],[0.16173073020245696,0.4644265933240915],[0.16173073020245696,0.08155316871340108],[0.5145525649499937,0.4644265933240915],[0.5671348921371102,0.5999866263324974],[0.5671348921371102,0.4644265933240915],[0.5671348921371102,0.6085669803114362],[0.5671348921371102,0.5993878107889014],[0.7879215815685586,0.4644265933240915],[0.3011411395091858,0.4644265933240915],[0.7976637782492555,0.4644265933240915],[0.7976637782492555,0.9633874721979587],[0.7976637782492555,0.9379828427440832],[0.4285635536904042,0.4058441348357288],[0.4285635536904042,0.4644265933240915],[0.15031846957277747,0.4644265933240915],[0.13291619607318123,0.1331731863459878],[0.13291619607318123,0.4644265933240915],[0.5999866263324974,0.4644265933240915],[0.4607304950314831,0.5146859906287252],[0.4607304950314831,0.42195595902769334],[0.4607304950314831,0.4644265933240915],[0.6586521543222597,0.4644265933240915],[0.527730855490007,0.5146859906287252],[0.527730855490007,0.4644265933240915],[0.1324193910282083,0.4644265933240915],[0.1324193910282083,0.060307632698421966],[0.1324193910282083,0.15065641730078955],[0.6797349754383587,0.4644265933240915],[0.6399926936563858,0.4644265933240915],[0.4633349136726842,0.4644265933240915],[0.4412738654608661,0.45967477884167124],[0.4412738654608661,0.4644265933240915],[0.15968467616016585,0.4644265933240915],[0.21223921744449123,0.4644265933240915],[0.5476713970682007,0.4644265933240915],[0.5476713970682007,0.5140240042309399],[0.5476713970682007,0.5476713970682007],[0.32060758787424637,0.3694577704292969],[0.32060758787424637,0.33364665792653025],[0.32060758787424637,0.4644265933240915],[0.15065641730078955,0.4644265933240915],[0.15065641730078955,0.060307632698421966],[0.6891849194688708,0.5993878107889014],[0.6891849194688708,0.4644265933240915],[0.6855416614287914,0.6762104750895189],[0.6855416614287914,0.6177264302342022],[0.6855416614287914,0.4644265933240915],[0.7117538031098491,0.4644265933240915],[0.4710846877627917,0.4644265933240915],[0.4710846877627917,0.5140240042309399],[0.649129723689199,0.5197629058866543],[0.649129723689199,0.4644265933240915],[0.468087975974438,0.46542373082288824],[0.468087975974438,0.43293099809978064],[0.468087975974438,0.4806671826599098],[0.32447229181159315,0.4644265933240915],[0.6762104750895189,0.6177264302342022],[0.6762104750895189,0.6344026112713228],[0.6762104750895189,0.6598473043084586],[0.33364665792653025,0.3694577704292969],[0.33364665792653025,0.33364665792653025],[0.33364665792653025,0.4644265933240915],[0.33364665792653025,0.43293099809978064],[0.2402041690827045,0.4644265933240915],[0.5644052729302718,0.4644265933240915],[0.46542373082288824,0.4644265933240915],[0.4812389911319088,0.4644265933240915],[0.6034712410443259,0.6034712410443259],[0.6034712410443259,0.7146508825410139],[0.6034712410443259,0.6980098944564919],[0.6034712410443259,0.6580949110185261],[0.6034712410443259,0.6500322109180686],[0.6034712410443259,0.5993878107889014],[0.6034712410443259,0.5855399018260025],[0.6034712410443259,0.4644265933240915],[0.20490598362692178,0.4644265933240915],[0.4722671490732712,0.4644265933240915],[0.5452245805654169,0.4644265933240915],[0.05477044416658729,0.13627939091125882],[0.9633874721979587,0.8321147999922618],[0.5269626819567745,0.5162309872640686],[0.15419286639427188,0.4644265933240915],[0.5993878107889014,0.6085669803114362],[0.5993878107889014,0.6355543158364171],[0.5993878107889014,0.6861984278986488],[0.5993878107889014,0.4644265933240915],[0.5993878107889014,0.5993878107889014],[0.5993878107889014,0.6318110145695137],[0.6318110145695137,0.4644265933240915],[0.6318110145695137,0.6085669803114362],[0.7923960630635131,0.4644265933240915],[0.48090941535909565,0.46463118186664565],[0.48090941535909565,0.4644265933240915],[0.5855399018260025,0.4644265933240915],[0.7726065575391908,0.7371297618622412],[0.7726065575391908,0.4644265933240915],[0.608632763773559,0.4644265933240915],[0.7045574966363791,0.4644265933240915],[0.6861984278986488,0.4644265933240915],[0.45250458946179123,0.3694577704292969],[0.45250458946179123,0.5782368882477646],[0.45250458946179123,0.4644265933240915],[0.45250458946179123,0.45250458946179123],[0.5934927805921262,0.6831448909424619],[0.5934927805921262,0.4644265933240915],[0.6980098944564919,0.6980098944564919],[0.6980098944564919,0.4644265933240915],[0.6980098944564919,0.7146508825410139],[0.6598473043084586,0.6177264302342022],[0.6598473043084586,0.4644265933240915],[0.3662196950547806,0.4644265933240915],[0.6946543424032136,0.4644265933240915],[0.41254406548995315,0.3756071601170002],[0.41254406548995315,0.4644265933240915],[0.5197629058866543,0.5324797516965024],[0.5197629058866543,0.4644265933240915],[0.3784550836111945,0.27007728591199187],[0.3784550836111945,0.4644265933240915],[0.13627939091125882,0.4644265933240915],[0.6355543158364171,0.4644265933240915],[0.8086494090192747,0.4644265933240915],[0.44720670796608125,0.4644265933240915],[0.7444164662901014,0.4644265933240915],[0.8045534864851885,0.4644265933240915],[0.5696401069015957,0.4644265933240915],[0.7580853182147079,0.4644265933240915],[0.45955818521324665,0.4644265933240915],[0.5283913703426419,0.4644265933240915],[0.6594916630702127,0.4644265933240915],[0.70196767347563,0.5782368882477646],[0.70196767347563,0.4644265933240915],[0.20913385755198127,0.4644265933240915],[0.3788913931950467,0.4644265933240915],[0.798598861653098,0.4644265933240915],[0.5681739762661152,0.4644265933240915],[0.5681739762661152,0.48453723694984574],[0.6344026112713228,0.6177264302342022],[0.6344026112713228,0.4644265933240915],[0.30113802493274033,0.4644265933240915],[0.34976785016864254,0.4644265933240915],[0.13857379959444122,0.4644265933240915],[0.7527254406328888,0.4644265933240915],[0.42195595902769334,0.4644265933240915],[0.7311120412458607,0.4644265933240915],[0.6177264302342022,0.4644265933240915],[0.43293099809978064,0.3694577704292969],[0.43293099809978064,0.4644265933240915],[0.1486026017777609,0.4644265933240915],[0.6383001874738673,0.4644265933240915],[0.24086342723742865,0.4644265933240915],[0.6500322109180686,0.4644265933240915],[0.6500322109180686,0.6424909535271728],[0.3393929547320893,0.4644265933240915],[0.5146859906287252,0.5586600444464479],[0.5146859906287252,0.5782368882477646],[0.5146859906287252,0.4644265933240915],[0.5146859906287252,0.5146859906287252],[0.5146859906287252,0.5324797516965024],[0.7371297618622412,0.7595767097293317],[0.7371297618622412,0.4644265933240915],[0.8134193274559792,0.4644265933240915],[0.7621605629428484,0.4644265933240915],[0.7310000899182425,0.4644265933240915],[0.7595767097293317,0.4644265933240915],[0.48453723694984574,0.45967477884167124],[0.48453723694984574,0.4644265933240915],[0.48453723694984574,0.5140240042309399],[0.637727285059424,0.4644265933240915],[0.6797909978021992,0.4644265933240915],[0.30604823057945385,0.388417647624072],[0.30604823057945385,0.3694577704292969],[0.30604823057945385,0.30604823057945385],[0.30604823057945385,0.4644265933240915],[0.40258749171673497,0.4644265933240915],[0.5514117581134003,0.5514117581134003],[0.5514117581134003,0.4644265933240915],[0.6074850831813735,0.4644265933240915],[0.4056395478047269,0.4644265933240915],[0.6085669803114362,0.4644265933240915],[0.16016274624505258,0.4644265933240915],[0.6017510295555455,0.4644265933240915],[0.46463118186664565,0.4644265933240915],[0.19731172210428197,0.4644265933240915],[0.35372947827716217,0.4644265933240915],[0.2030813546636055,0.4644265933240915],[0.5586600444464479,0.4644265933240915],[0.7510563490127009,0.4644265933240915],[0.7968717860750494,0.4644265933240915],[0.9379828427440832,0.76402195296293],[0.48046567508521565,0.3694577704292969],[0.48046567508521565,0.4644265933240915],[0.48046567508521565,0.39651518609686176],[0.24532755355273295,0.3694577704292969],[0.24532755355273295,0.4644265933240915],[0.7941581650806059,0.4644265933240915],[0.39723488268211155,0.4644265933240915],[0.3698943178774708,0.4644265933240915],[0.10224652605134109,0.4644265933240915],[0.6580949110185261,0.4644265933240915],[0.4806671826599098,0.4644265933240915],[0.8321147999922618,0.4644265933240915],[0.15869576594179613,0.4644265933240915],[0.3560301340694253,0.4644265933240915],[0.7088679714710461,0.4644265933240915],[0.5324797516965024,0.4644265933240915],[0.5324797516965024,0.5324797516965024],[0.42664086597482787,0.4644265933240915],[0.12389046732526335,0.4644265933240915],[0.3694577704292969,0.4030728953171881],[0.3694577704292969,0.388417647624072],[0.3694577704292969,0.3694577704292969],[0.3694577704292969,0.4644265933240915],[0.3694577704292969,0.39651518609686176],[0.1331731863459878,0.4644265933240915],[0.30898003112970135,0.4644265933240915],[0.5750826143843594,0.4644265933240915],[0.27007728591199187,0.4644265933240915],[0.7452829125960218,0.4644265933240915],[0.28967045807142405,0.4644265933240915],[0.5756934843630539,0.4644265933240915],[0.4435919918519365,0.4644265933240915],[0.4644265933240915,0.29959065960548625],[0.4644265933240915,0.6386468337920613],[0.4644265933240915,0.42038396057478256],[0.4644265933240915,0.5116991430043761],[0.4644265933240915,0.697774703423627],[0.4644265933240915,0.40545765038305975],[0.4644265933240915,0.4644265933240915],[0.4644265933240915,0.21337252010202712],[0.4644265933240915,0.5140240042309399],[0.4644265933240915,0.7211525475839037],[0.4644265933240915,0.5782368882477646],[0.4644265933240915,0.20835868980238664],[0.4644265933240915,0.30163224913901937],[0.4644265933240915,0.4525379216453794],[0.4644265933240915,0.13741285746048232],[0.4644265933240915,0.4030728953171881],[0.4644265933240915,0.76402195296293],[0.4644265933240915,0.45967477884167124],[0.4644265933240915,0.32365947792215594],[0.4644265933240915,0.5162309872640686],[0.4644265933240915,0.27600443680581555],[0.4644265933240915,0.388417647624072],[0.4644265933240915,0.37719691319932325],[0.4644265933240915,0.7146508825410139],[0.4644265933240915,0.5210969333616969],[0.4644265933240915,0.4058441348357288],[0.4644265933240915,0.8528721121156967],[0.4644265933240915,0.6424909535271728],[0.4644265933240915,0.13948597135490573],[0.4644265933240915,0.3015005471981137],[0.4644265933240915,0.39651518609686176],[0.4644265933240915,0.35602008500293675],[0.5782368882477646,0.5782368882477646],[0.20835868980238664,0.13366888995334028],[0.45967477884167124,0.45967477884167124],[0.7113211289585225,0.6386468337920613],[0.5210969333616969,0.5210969333616969],[0.6386468337920613,0.6386468337920613],[0.4058441348357288,0.4058441348357288]]}},\"id\":\"ab0d71df-1008-4bd0-8ee8-b60394cda912\",\"type\":\"ColumnDataSource\"},{\"attributes\":{\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"}},\"id\":\"5adc6f1b-6f56-486a-9aee-20ea3f45dd55\",\"type\":\"ResetTool\"},{\"attributes\":{},\"id\":\"11e0143f-ef0b-4d47-9e99-898ba2130987\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"line_alpha\":{\"value\":0.1},\"line_color\":{\"value\":\"#1f77b4\"},\"line_width\":{\"value\":1.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"1a1f89ff-65f0-49a4-a490-2938aca9f648\",\"type\":\"MultiLine\"},{\"attributes\":{\"plot\":null,\"text\":null},\"id\":\"800ff3d4-6e8f-4a0b-87a3-6bc5122f7678\",\"type\":\"Title\"},{\"attributes\":{\"formatter\":{\"id\":\"f26e124b-b0b4-493f-b007-5e80685078a5\",\"type\":\"BasicTickFormatter\"},\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"9720aeca-f949-4a69-a0d8-7d5eed928666\",\"type\":\"BasicTicker\"}},\"id\":\"e43c1d7a-7174-4725-a05c-aecb2ecf6c29\",\"type\":\"LinearAxis\"},{\"attributes\":{\"callback\":null,\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"}},\"id\":\"dee07948-35c4-4872-a632-62aedee74dcf\",\"type\":\"TapTool\"},{\"attributes\":{\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"9720aeca-f949-4a69-a0d8-7d5eed928666\",\"type\":\"BasicTicker\"}},\"id\":\"7cddbcbd-7485-449e-9f4f-5bd9d4f56156\",\"type\":\"Grid\"},{\"attributes\":{\"line_alpha\":{\"field\":\"alphas\"},\"line_color\":{\"value\":\"navy\"},\"line_width\":{\"value\":1.5},\"xs\":{\"field\":\"xs\"},\"ys\":{\"field\":\"ys\"}},\"id\":\"48a529e0-49c1-4985-8d95-028503b36abd\",\"type\":\"MultiLine\"},{\"attributes\":{\"overlay\":{\"id\":\"e291121b-79c6-40c5-b081-7371926c685a\",\"type\":\"BoxAnnotation\"},\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"}},\"id\":\"60156367-73d9-4892-8324-eaa5c2ee576f\",\"type\":\"BoxZoomTool\"},{\"attributes\":{\"formatter\":{\"id\":\"11e0143f-ef0b-4d47-9e99-898ba2130987\",\"type\":\"BasicTickFormatter\"},\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"ticker\":{\"id\":\"20197a57-7180-4dba-a3f8-12a57f1aedd1\",\"type\":\"BasicTicker\"}},\"id\":\"c82cd6a8-c815-4d2a-848e-1e6052945a3c\",\"type\":\"LinearAxis\"},{\"attributes\":{\"callback\":null,\"plot\":{\"id\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"subtype\":\"Figure\",\"type\":\"Plot\"},\"tooltips\":[[\"name\",\"@name\"],[\"id\",\"$index\"]]},\"id\":\"145c024b-5fa5-4086-871c-cd25f1d1ac7a\",\"type\":\"HoverTool\"}],\"root_ids\":[\"5d5b7b93-ed51-44de-a816-c29d492b70ab\"]},\"title\":\"Bokeh Application\",\"version\":\"0.12.0\"}};\n",
       "            var render_items = [{\"docid\":\"580c0d09-670b-4531-8280-a3cb25b25660\",\"elementid\":\"69439cfc-98f6-4085-a625-e6540faa5863\",\"modelid\":\"5d5b7b93-ed51-44de-a816-c29d492b70ab\",\"notebook_comms_target\":\"cbd72e05-aa47-4444-88fa-11f227fbf05c\"}];\n",
       "            \n",
       "            Bokeh.embed.embed_items(docs_json, render_items);\n",
       "        });\n",
       "      },\n",
       "      function(Bokeh) {\n",
       "      }\n",
       "    ];\n",
       "  \n",
       "    function run_inline_js() {\n",
       "      for (var i = 0; i < inline_js.length; i++) {\n",
       "        inline_js[i](window.Bokeh);\n",
       "      }\n",
       "    }\n",
       "  \n",
       "    if (window._bokeh_is_loading === 0) {\n",
       "      console.log(\"Bokeh: BokehJS loaded, going straight to plotting\");\n",
       "      run_inline_js();\n",
       "    } else {\n",
       "      load_libs(js_urls, function() {\n",
       "        console.log(\"Bokeh: BokehJS plotting callback run at\", now());\n",
       "        run_inline_js();\n",
       "      });\n",
       "    }\n",
       "  }(this));\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<p><code>&lt;Bokeh Notebook handle for <strong>In[11]</strong>&gt;</code></p>"
      ],
      "text/plain": [
       "<bokeh.io._CommsHandle at 0x1063e8940>"
      ]
     },
     "execution_count": 11,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "show(plot)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# Step 5: Interactions"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "source": [
    "### Get Selected Nodes\n",
    "\n",
    "`ColumnDataSource.selected`\n",
    "```python\n",
    "{\n",
    " # line or patch glyph selections\n",
    " '0d': {'get_view': {}, 'glyph': None,\n",
    "        'indices': []},\n",
    " # all other glyph selections\n",
    " '1d': {'indices': [73]},\n",
    " # [multi]line or patch selections\n",
    " '2d': {'indices': []}\n",
    "}\n",
    "```"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "### Remove Node"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {
    "collapsed": true,
    "slideshow": {
     "slide_type": "fragment"
    }
   },
   "outputs": [],
   "source": [
    "def remove_node():\n",
    "    idx = nodes_source.selected['1d']['indices'][0]\n",
    "    \n",
    "    # update networkX network\n",
    "    node = nodes_source.data['name'][idx]\n",
    "    network.remove_node(node)\n",
    "    \n",
    "    # update layout\n",
    "    layout.pop(node)\n",
    "    \n",
    "    # update nodes ColumnDataSource\n",
    "    new_source_data = dict()\n",
    "    for column in nodes_source.column_names:\n",
    "        new_source_data[column] =\\\n",
    "        [e for i, e in enumerate(nodes_source.data[column])\n",
    "         if i != idx]\n",
    "    nodes_source.data = new_source_data\n",
    "\n",
    "    # update lines ColumnDataSource\n",
    "    lines_source.data = get_edges_specs(network, layout)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "### Notebook Limitations\n",
    "* no direct redraw after changing the ColumnDataSource\n",
    "* getting selected nodes is not working\n",
    "* can not run arbitrary python code started by widges, e.g. buttons\n",
    "\n",
    "<br>\n",
    "\n",
    "### Bokeh Server\n",
    "```\n",
    "bokeh serve your_app.py\n",
    "```\n",
    "\n",
    "[http://localhost:5006/bokehx_app](http://localhost:5006/bokehx_app)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# Thank You\n",
    "\n",
    "The slides and code can be found at:\n",
    "\n",
    "[https://github.com/blue-yonder/documents](https://github.com/blue-yonder/documents)\n",
    "\n",
    "<br>\n",
    "## NetworkX\n",
    "[https://networkx.github.io](https://networkx.github.io)\n",
    "\n",
    "<br>\n",
    "## Bokeh\n",
    "[http://bokeh.pydata.org](http://bokeh.pydata.org)"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Slideshow",
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.5.1"
  },
  "widgets": {
   "state": {},
   "version": "1.1.2"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 0
}
